(function ($) {
    "use strict";

    function header($scope, $) {
        var headerAnimation = gsap.timeline({ yoyo: false, reversed: true });
        headerAnimation.pause();

        headerAnimation.from($('.overlay-menu'), { autoAlpha: 0 });
        headerAnimation.from($('.overlay-menu .left-area'), { y: '100vh' }, 0.1);
        headerAnimation.from($('.overlay-menu .right-area'), { y: '-100vh' }, 0.1);
        headerAnimation.from($('.overlay-menu .right-area ul'), { autoAlpha: 0, stagger: 0.1 }, 0.5);
        headerAnimation.from($('.overlay-menu nav li:not(.overlay-menu nav ul li ul li)'), { stagger: 0.1, y: 30, autoAlpha: 0, ease: "Expo.easeInOut" }, 0.5);
        headerAnimation.from($('.overlay-menu nav li:not(.overlay-menu nav ul li ul li)'), { 'clearProps': 'all', delay: 1.3, ease: "Expo.easeInOut" }, 0.5);

        $('header .burger-menu, .overlay-menu .close').on('click', function () {
            headerAnimation.reversed() ? headerAnimation.play() : headerAnimation.reverse();
            $('.overlay-menu').toggleClass('active');
        });

        $('.overlay-menu .menu-item-has-children').each(function () {
            $(this).find('> a').attr('href', 'javascript:void(0);');
            $(this).children('ul').append('<li><a class="back" href="javascript:void(0);">back <i class="ri-corner-down-left-line"></i></a></li>');
        });

        $('.overlay-menu .menu-item-has-children > a').each(function () {
            var overlay_animation = gsap.timeline({ yoyo: false, reversed: true });

            overlay_animation.pause();
            overlay_animation.to($(this).closest('ul').children('li').children('a'), { stagger: 0.1, autoAlpha: 0, y: -50, 'pointer-events': 'none', ease: Power3.easeOut });
            overlay_animation.to($(this).next('ul'), { 'z-index': '10', 'pointer-events': 'all' }),
                overlay_animation.from($(this).next('ul').children('li').children('a'), { stagger: 0.1, autoAlpha: 0, y: 30, ease: Power3.easeOut });

            this.animation = overlay_animation;

            $(".overlay-menu .back, .overlay-menu .close").on('click', function () {
                overlay_animation.reverse();
            });
        });

        $(".overlay-menu .menu-item-has-children > a").on('click', function () {
            this.animation.reversed() ? this.animation.play() : this.animation.reverse();
        });

        if ($('#fixed').length) {
            scrollbar.addListener(({ offset }) => {
                fixed.style.top = offset.y + ($(window).height() - 90) + 'px';
            });
        }
    }

    function xboActive($scope, $) {
        if ($(".xbo").length) {
            $('.xbo').appear();
            $(document.body).on('appear', '.xbo', function (e) {
                var odo = $(".xbo");
                odo.each(function () {
                    var countNumber = $(this).attr("data-count");
                    $(this).html(countNumber);
                });
                window.xboOptions = {
                    format: 'd',
                };
            });
        }
    }
    function xboActive2($scope, $) {
        if ($(".xbo_trigger").length) {
            var odo = $(".xbo_trigger");
            odo.each(function () {
                var countNumber = $(this).attr("data-count");
                var odometerInstance = new Odometer({
                    el: this,
                    value: 0,
                    format: 'd',
                });
                odometerInstance.render();
                odometerInstance.update(countNumber);
            });

            $('.xbo_trigger').appear();
            $(document.body).on('appear', '.xboh', function (e) {
                // This event handler can be empty or used for additional functionality if needed
            });
        }
    }

    function marqueeActive($scope, $) {
        $('.marquee-left').marquee({
            speed: 50,
            gap: 0,
            delayBeforeStart: 0,
            direction: 'left',
            duplicated: true,
            pauseOnHover: false,
            startVisible: true,
        });
        $('.marquee-right').marquee({
            speed: 50,
            gap: 0,
            delayBeforeStart: 0,
            direction: 'right',
            duplicated: true,
            pauseOnHover: false,
            startVisible: true,
        });
    }

    function teamActive($scope, $) {
        var slider = new Swiper(".team-slider", {
            loop: true,
            spaceBetween: 125,
            speed: 400,
            slidesPerView: 5,
            autoplay: {
                enabled: true,
                delay: 6000
            },
            breakpoints: {
                '1600': {
                    slidesPerView: 5,
                },
                '1200': {
                    slidesPerView: 4,
                    spaceBetween: 50,
                },
                '992': {
                    slidesPerView: 4,
                    spaceBetween: 40,
                },
                '768': {
                    slidesPerView: 3,
                    spaceBetween: 30,
                },
                '576': {
                    slidesPerView: 2,
                    spaceBetween: 30,
                },
                '0': {
                    slidesPerView: 1,
                },
            },
        });
    }

    // gallery slider
    function gallerySliderActive($scope, $) {
        var slider = new Swiper('.service-gallery-slider', {
            spaceBetween: 30,
            slidesPerView: 5,
            roundLengths: true,
            loop: true,
            pagination: {
                el: ".swiper-pagination",
                clickable: true,
            },
            autoplay: {
                enabled: true,
                delay: 6000
            },
            speed: 400,
            breakpoints: {
                '1600': {
                    slidesPerView: 5,
                },
                '1200': {
                    slidesPerView: 4,
                },
                '992': {
                    slidesPerView: 3,
                },
                '768': {
                    slidesPerView: 2,
                },
                '576': {
                    slidesPerView: 2,
                },
                '0': {
                    slidesPerView: 1,
                },
            },
        });
    }
    //brand slider
    function brandSliderActive($scope, $) {
        var slider = new Swiper('.brand-slider', {
            slidesPerView: 6,
            roundLengths: true,
            loop: true,
            loopAdditionalSlides: 30,
            autoplay: {
                enabled: true,
                delay: 6000
            },
            speed: 400,
            breakpoints: {
                '1600': {
                    slidesPerView: 6,
                },
                '1200': {
                    slidesPerView: 6,
                },
                '992': {
                    slidesPerView: 5,
                },
                '768': {
                    slidesPerView: 4,
                },
                '576': {
                    slidesPerView: 3,
                },
                '0': {
                    slidesPerView: 2,
                },
            },
        });
    }
    //brand slider
    function brandSliderTwoActive($scope, $) {
        var slider = new Swiper('.dm-brand-slider', {
            spaceBetween: 100,
            slidesPerView: 6,
            roundLengths: true,
            loop: true,
            autoplay: {
                enabled: true,
                delay: 4000
            },
            speed: 400,
            breakpoints: {
                '1600': {
                    slidesPerView: 6,
                },
                '1200': {
                    slidesPerView: 6,
                },
                '992': {
                    slidesPerView: 5,
                },
                '768': {
                    slidesPerView: 4,
                    spaceBetween: 50,
                },
                '576': {
                    slidesPerView: 3,
                    spaceBetween: 40,
                },
                '0': {
                    slidesPerView: 3,
                    spaceBetween: 20,
                },
            },
        });
    }
    //service slider
    function serviceSliderActive($scope, $) {
        var slider = new Swiper('.service-slider', {
            spaceBetween: 0,
            slidesPerView: 4,
            roundLengths: true,
            loop: true,
            autoplay: {
                enabled: true,
                delay: 6000
            },
            speed: 400,
            breakpoints: {
                '1600': {
                    slidesPerView: 4,
                },
                '1200': {
                    slidesPerView: 3,
                },
                '992': {
                    slidesPerView: 3,
                },
                '768': {
                    slidesPerView: 2,
                },
                '576': {
                    slidesPerView: 2,
                },
                '0': {
                    slidesPerView: 1,
                },
            },
        });
    }
    function serviceSliderTwoActive($scope, $) {
        var slider = new Swiper('.dm-service-slider', {
            spaceBetween: 0,
            slidesPerView: 4,
            roundLengths: true,
            loop: true,
            autoplay: {
                enabled: true,
                delay: 5000
            },
            speed: 400,
            breakpoints: {
                '1600': {
                    slidesPerView: 4,
                },
                '1200': {
                    slidesPerView: 3,
                },
                '992': {
                    slidesPerView: 3,
                },
                '768': {
                    slidesPerView: 2,
                },
                '576': {
                    slidesPerView: 2,
                },
                '0': {
                    slidesPerView: 1,
                },
            },
        });
    }
    // award slider
    function awardSliderActive($scope, $) {
        var slider = new Swiper('.award-slider', {
            spaceBetween: 30,
            slidesPerView: 4,
            roundLengths: true,
            loop: true,
            navigation: {
                nextEl: '.xb-swiper-arrow-next',
                prevEl: '.xb-swiper-arrow-prev',
            },
            autoplay: {
                enabled: true,
                delay: 4000
            },
            speed: 400,
            breakpoints: {
                '1600': {
                    slidesPerView: 4,
                },
                '1200': {
                    slidesPerView: 4,
                },
                '992': {
                    slidesPerView: 3,
                },
                '768': {
                    slidesPerView: 2,
                },
                '576': {
                    slidesPerView: 2,
                },
                '0': {
                    slidesPerView: 1,
                },
            },
        });
    }

    function scrollTriggerActive($scope, $) {
        gsap.registerPlugin(ScrollTrigger);
        $('.xb_trigger').each(function () {
            gsap.to(this, {
                scrollTrigger: {
                    trigger: this,
                },
                onComplete: function () {
                    this.targets().forEach(function (target) {
                        target.classList.add('triggered');
                    });
                }
            });
        });
    }

    //team slider
    function teamSliderActive($scope, $) {
        var slider = new Swiper(".team-slider-two", {
            loop: true,
            spaceBetween: 30,
            speed: 400,
            slidesPerView: 2,
            direction: "vertical",
            pagination: {
                el: ".swiper-pagination",
                clickable: true,
            },
            autoplay: {
                enabled: true,
                delay: 6000
            },
            breakpoints: {
                '1600': {
                    slidesPerView: 2,
                },
                '768': {
                    slidesPerView: 2,
                },
                '576': {
                    slidesPerView: 3,
                },
                '0': {
                    slidesPerView: 2,
                },
            },
        });
    }

    // element parallax
    function elementParallax($scope, $) {
        $('.xb-element-parallax').each(function () {
            var $this = $(this);
            var dampingFactor = 0.1;

            function handleMouseMove(e) {
                var offset = $this.offset();
                var mouseX = e.pageX - offset.left;
                var mouseY = e.pageY - offset.top;
                var translateX = (mouseX - $this.width() / 2) * dampingFactor;
                var translateY = (mouseY - $this.height() / 2) * dampingFactor;

                var translateTransform = 'translate(' + translateX + 'px, ' + translateY + 'px)';
                $this.css({
                    'transform': translateTransform,
                    'transition': 'transform 0.1s ease-out'  // Adjust the duration and easing as needed
                });
            }

            function resetTransform() {
                $this.css({
                    'transform': 'none',
                    'transition': 'transform 0.1s ease-out'  // Adjust the duration and easing as needed
                });
            }

            if ($this.closest('.xb-parent-element-parallax').length) {
                var pare2 = $this.closest('.xb-parent-element-parallax');
                pare2.mousemove(function (e) {
                    handleMouseMove(e);
                });
                pare2.mouseleave(resetTransform);
            } else {
                $this.mousemove(handleMouseMove);
                $this.mouseleave(resetTransform);
            }
        });
    }

    // portfolio slider
    function portfolioSlider($scope, $) {
        var slider = new Swiper('.portfolio-slider', {
            spaceBetween: 30,
            slidesPerView: 2,
            roundLengths: true,
            loop: true,
            autoplay: {
                enabled: true,
                delay: 4000
            },
            speed: 400,
            breakpoints: {
                '1600': {
                    slidesPerView: 2,
                },
                '1200': {
                    slidesPerView: 2,
                },
                '992': {
                    slidesPerView: 2,
                },
                '768': {
                    slidesPerView: 2,
                },
                '576': {
                    slidesPerView: 2,
                },
                '0': {
                    slidesPerView: 1,
                },
            },
        });
    }
    function portfolioSliderTwo($scope, $) {
        var slider = new Swiper('.dm-portfolio-slider', {
            spaceBetween: 30,
            slidesPerView: 2,
            roundLengths: true,
            loop: true,
            autoplay: {
                enabled: true,
                delay: 4000
            },
            speed: 400,
            breakpoints: {
                '1600': {
                    slidesPerView: 2,
                },
                '1200': {
                    slidesPerView: 2,
                },
                '992': {
                    slidesPerView: 2,
                },
                '768': {
                    slidesPerView: 2,
                },
                '576': {
                    slidesPerView: 1,
                },
                '0': {
                    slidesPerView: 1,
                },
            },
        });
    }

    // testimonial slider
    function testimonialSlider($scope, $) {
        var slider = new Swiper('.testimonial-slider', {
            spaceBetween: 0,
            slidesPerView: 1,
            roundLengths: true,
            loop: true,
            centeredSlides: true,
            effect: 'fade',
            loopAdditionalSlides: 30,
            autoplay: {
                enabled: true,
                delay: 6000
            },
            navigation: {
                nextEl: '.xb-swiper-arrow-next',
                prevEl: '.xb-swiper-arrow-prev',
            },
            speed: 400,
        });
    }
    function testimonialSliderTwo($scope, $) {
        var slider = new Swiper('.dm-testimonial-slider', {
            spaceBetween: 30,
            slidesPerView: 3,
            roundLengths: true,
            loop: true,
            pagination: {
                el: ".swiper-pagination",
                clickable: true,
            },
            autoplay: {
                enabled: true,
                delay: 4000
            },
            speed: 400,
            breakpoints: {
                '1600': {
                    slidesPerView: 3,
                },
                '1200': {
                    slidesPerView: 3,
                },
                '992': {
                    slidesPerView: 3,
                },
                '768': {
                    slidesPerView: 2,
                },
                '576': {
                    slidesPerView: 2,
                },
                '0': {
                    slidesPerView: 1,
                },
            },
        });
    }
    function teamSliderTwo($scope, $) {
        var slider = new Swiper(".dm-team-slider", {
            loop: true,
            spaceBetween: 30,
            speed: 400,
            slidesPerView: 5,
            autoplay: {
                enabled: true,
                delay: 6000
            },
            breakpoints: {
                '1600': {
                    slidesPerView: 5,
                },
                '768': {
                    slidesPerView: 4,
                },
                '576': {
                    slidesPerView: 3,
                },
                '0': {
                    slidesPerView: 1,
                },
            },
        });
    }
    function instragramSlider($scope, $) {
        var slider = new Swiper('.instragram-slider', {
            spaceBetween: 0,
            slidesPerView: 6,
            roundLengths: true,
            loop: true,
            autoplay: {
                enabled: true,
                delay: 4000
            },
            speed: 400,
            breakpoints: {
                '1600': {
                    slidesPerView: 6,
                },
                '1200': {
                    slidesPerView: 6,
                },
                '992': {
                    slidesPerView: 5,
                },
                '768': {
                    slidesPerView: 4,
                },
                '576': {
                    slidesPerView: 3,
                },
                '0': {
                    slidesPerView: 2,
                },
            },
        });
    }
    function progressActive($scope, $) {
        if ($(".progress-bar").length) {
            var $progress_bar = $('.progress-bar');
            $progress_bar.appear();
            $(document.body).on('appear', '.progress-bar', function() {
                var current_item = $(this);
                if (!current_item.hasClass('appeared')) {
                    var percent = current_item.data('percent');
                    current_item.css('width', percent + '%').addClass('appeared').parent().append('<span>' + percent + '%' + '</span>');
                }

            });
        };
    }
    function heroImageActive($scope, $) {
        function heroImage() {
            var img1 = $('.xbh__image-wrap.one').data('xbh-hero-images1');
            var img2 = $('.xbh__image-wrap.two').data('xbh-hero-images2');
            var img3 = $('.xbh__image-wrap.three').data('xbh-hero-images3');
            function createTimeline(triggerSelector, imagesSelector) {
                const xbhTrigger = document.querySelector(triggerSelector);
                const xbhImages = document.querySelectorAll(`${imagesSelector} .xbh-image`);
                gsap.set(xbhImages, { display: "none", clipPath: "inset(100% 0% 0% 0%)" });

                const timeline = gsap.timeline({ paused: true });

                timeline.to(xbhImages, {
                    display: "block",
                    clipPath: "inset(0% 0% 0% 0%)",
                    duration: 1,
                    stagger: 0.1,
                    ease: "power4.out",
                });

                let isTimelinePlaying = false;

                $(xbhTrigger).on('mouseenter', function () {
                    if (!isTimelinePlaying) {
                        isTimelinePlaying = true;
                        timeline.play();
                    }
                });

                $(xbhTrigger).on('mouseleave', function () {
                    if (isTimelinePlaying) {
                        isTimelinePlaying = false;
                        timeline.reverse();
                    }
                });
            }
            createTimeline('[data-xbh-trigger1='+img1+']', '[data-xbh-hero-images1='+img1+']');
            createTimeline('[data-xbh-trigger2='+img2+']', '[data-xbh-hero-images2='+img2+']');
            createTimeline('[data-xbh-trigger3='+img3+']', '[data-xbh-hero-images3='+img3+']');
        }

        heroImage();
    }
    function throwableActive($scope, $) {
        ! function($) {
            "use strict";
            const restArguments = function(t, e) {
                    return e = null == e ? t.length - 1 : +e,
                        function(i, s) {
                            for (var n = Math.max(arguments.length - e, 0), o = Array(n), a = 0; a < n; a++) o[a] = arguments[a + e];
                            switch (e) {
                                case 0:
                                    return t.call(this, o);
                                case 1:
                                    return t.call(this, i, o);
                                case 2:
                                    return t.call(this, i, s, o)
                            }
                            var l = Array(e + 1);
                            for (a = 0; a < e; a++) l[a] = arguments[a];
                            return l[e] = o, t.apply(this, l)
                        }
                },
                xbDelay = restArguments((function(t, e, i) {
                    return setTimeout((function() {
                        return t.apply(null, i)
                    }), e)
                }));
            window.xbDebounce = function(t, e, i) {
                var s, n, o = function(e, i) {
                        s = null, i && (n = t.apply(e, i))
                    },
                    a = restArguments((function(a) {
                        if (s && clearTimeout(s), i) {
                            var l = !s;
                            s = setTimeout(o, e), l && (n = t.apply(this, a))
                        } else s = xbDelay(o, e, this, a);
                        return n
                    }));
                return a.cancel = function() {
                    clearTimeout(s), s = null
                }, a
            };

            const t = "xbThrowable";
            let e = {
                roundness: "sharp",
                scrollGravity: !1
            };
            class i {
                constructor(i, s) {
                    this._defaults = e, this._name = t, this.options = {
                        ...e,
                        ...s
                    }, this.DOM = {}, this.DOM.element = i, this.DOM.$element = $(i), this.DOM.throwables = this.DOM.element.querySelectorAll("[data-xb-throwable-el]"), this.onWindowResize = xbDebounce(this.onWindowResize.bind(this), 250), this.bodies = [], this.init()
                }
                init() {
                    this.createWorld(), this.createBoundries(), this.createBodies(), this.enableRunner(), this.makeItRain(), this.bindResize()
                }
                enableRunner() {
                    this.runnerObserver = new IntersectionObserver((([t]) => {
                        this.runner.enabled = t.isIntersecting
                    })).observe(this.DOM.element)
                }
                makeItRain() {
                    new IntersectionObserver((([t], e) => {
                        t.isIntersecting && (this.DOM.throwables.forEach((t => {
                            gsap.to(t, {
                                opacity: 1,
                                duration: .35,
                            })
                        })), this.startRain(), e.disconnect())
                    })).observe(this.DOM.element)
                }
                bindResize() {
                    window.addEventListener("resize", this.onWindowResize)
                }
                createWorld() {
                    this.height = this.DOM.element.offsetHeight, this.width = this.DOM.element.offsetWidth, this.engine = Matter.Engine.create(), this.runner = Matter.Runner.create(), this.mouse = Matter.Mouse.create(this.DOM.element), this.DOM.element.removeEventListener("mousewheel", this.mouse.mousewheel), this.DOM.element.addEventListener("mouseleave", this.mouse.mouseup), this.mouseConstraint = Matter.MouseConstraint.create(this.engine, {
                        mouse: this.mouse,
                        constraint: {
                            render: {
                                visible: !1
                            }
                        }
                    }), this.engine.gravity.y = .8, Matter.Composite.add(this.engine.world, [this.mouseConstraint]), Matter.Runner.start(this.runner, this.engine), Matter.Events.on(this.mouseConstraint, "mousedown", (() => {
                        this.DOM.element.style.pointerEvents = "auto"
                    })), Matter.Events.on(this.mouseConstraint, "mouseup", (() => {
                        this.DOM.element.style.pointerEvents = ""
                    })), this.runner.enabled = !1
                }
                createBoundries() {
                    this.boundStart = Matter.Bodies.rectangle(-250, this.height / 2, 500, 4 * this.height, {
                        isStatic: !0
                    }), this.boundEnd = Matter.Bodies.rectangle(this.width + 250, this.height / 2, 500, 4 * this.height, {
                        isStatic: !0
                    }), this.boundBottom = Matter.Bodies.rectangle(0, this.height + 250, 2 * this.width, 500, {
                        isStatic: !0
                    }), Matter.Composite.add(this.engine.world, [this.boundBottom, this.boundStart, this.boundEnd])
                }
                createBodies() {
                    this.DOM.throwables.forEach(((t, e) => {
                        const i = t.querySelector("span"),
                            s = t.getBoundingClientRect(),
                            n = gsap.quickSetter(t, "x", "px"),
                            o = gsap.quickSetter(t, "y", "px"),
                            h = gsap.utils.random(.2 * -Math.PI, .2 * Math.PI),
                            r = gsap.utils.random(s.width / 2, this.width - s.width / 2),
                            a = -s.width - (e * s.height + 10),
                            d = "sharp" === this.options.roundness ? 0 : s.height / 2,
                            u = Matter.Bodies.rectangle(r, a, s.width, s.height, {
                                chamfer: {
                                    radius: d
                                },
                                angle: h,
                                isStatic: !0,
                                restitution: .3
                            });
                        this.bodies.push(u), Matter.Composite.add(this.engine.world, [u]), Matter.Events.on(this.runner, "tick", (() => {
                            this.runner.enabled && (i.style.transform = "translate(-50%, -50%) rotate(" + u.angle.toFixed(2) + "rad)", o(u.position.y.toFixed(1)), n(u.position.x.toFixed(1)))
                        }))
                    }))
                }
                createTopBound() {
                    this.boundTop = Matter.Bodies.rectangle(0, 0, 2 * this.width, 500, {
                        isStatic: !0
                    }), Matter.Composite.add(this.engine.world, [this.boundTop])
                }
                makeScrollGravity() {
                    let t = 0;
                    Matter.Events.on(this.runner, "tick", (() => {
                        const e = document.documentElement.scrollTop - document.documentElement.clientTop,
                            i = e - t;
                        this.engine.gravity.y = .7 - gsap.utils.clamp(-2, 4, .1 * i), t = e
                    }))
                }
                updateBoundries() {
                    this.boundTop && Matter.Body.setVertices(this.boundTop, Matter.Bodies.rectangle(0, -250, 2 * this.width, 500, {
                        isStatic: !0
                    }).vertices), this.boundStart && (Matter.Body.setPosition(this.boundStart, {
                        x: -250,
                        y: this.height / 2
                    }), Matter.Body.setVertices(this.boundStart, Matter.Bodies.rectangle(-250, this.height / 2, 500, 4 * this.height, {
                        isStatic: !0
                    }).vertices)), this.boundEnd && (Matter.Body.setPosition(this.boundEnd, {
                        x: this.width + 250,
                        y: this.height / 2
                    }), Matter.Body.setVertices(this.boundEnd, Matter.Bodies.rectangle(this.width + 250, this.height / 2, 500, 4 * this.height, {
                        isStatic: !0
                    }).vertices)), this.boundBottom && (Matter.Body.setPosition(this.boundBottom, {
                        x: 0,
                        y: this.height + 250
                    }), Matter.Body.setVertices(this.boundBottom, Matter.Bodies.rectangle(0, this.height + 250, 2 * this.width, 500, {
                        isStatic: !0
                    }).vertices))
                }
                updateBodies() {
                    this.DOM.throwables.forEach(((t, e) => {
                        const i = this.bodies[e],
                            s = t.getBoundingClientRect(),
                            n = "sharp" === this.options.roundness ? 0 : s.height / 2,
                            o = Matter.Bodies.rectangle(i.position.x, i.position.y, s.width, s.height, {
                                chamfer: {
                                    radius: n
                                },
                                angle: i.angle
                            });
                        if (Matter.Body.setVertices(i, o.vertices), i.position.y > this.height && Matter.Body.setPosition(i, {
                            y: this.height / 2,
                            x: i.position.x
                        }), i.position.x > this.width) {
                            var h = gsap.utils.random(s.width / 2, this.width - s.width / 2);
                            Matter.Body.setPosition(i, {
                                y: i.position.y,
                                x: h
                            })
                        }
                    }))
                }
                startRain() {
                    this.bodies.forEach(((t, e) => {
                        const i = setTimeout((() => {
                            Matter.Body.setStatic(t, !1), clearTimeout(i)
                        }), 80 * e)
                    }));
                    let t = !1;
                    Matter.Events.on(this.runner, "tick", (() => {
                        !t && this.bodies[this.bodies.length - 1].position.y > this.DOM.element.offsetHeight / 2 && (this.createTopBound(), this.options.scrollGravity && this.makeScrollGravity(), t = !0)
                    }))
                }
                refresh() {
                    if (this.height === this.DOM.element.offsetHeight && this.width === this.DOM.element.offsetWidth) return !1;
                    this.height = this.DOM.element.offsetHeight, this.width = this.DOM.element.offsetWidth;
                    const t = setTimeout((() => {
                        this.updateBoundries(), this.updateBodies(), clearTimeout(t)
                    }))
                }
                onWindowResize() {
                    this.refresh()
                }
                destroy() {
                    this.runner.enabled = !1, Matter.Runner.stop(this.runner), window.removeEventListener("resize", this.onWindowResize)
                }
            }
            $.fn[t] = function(e) {
                return this.each((function() {
                    const s = {
                        ...$(this).data("throwable-options"),
                        ...e
                    };
                    $.data(this, "plugin_" + t) || $.data(this, "plugin_" + t, new i(this, s))
                }))
            }
        }(jQuery), jQuery(document).ready((function($) {
            $("[data-throwable-scene]").xbThrowable()
        }));
    }

    function dsTestimonialSlider($scope, $) {
        var slider = new Swiper('.ds-testimonial-slider', {
            spaceBetween: 30,
            slidesPerView: 4,
            roundLengths: true,
            loop: true,
            autoplay: {
                enabled: true,
                delay: 4000
            },
            speed: 400,
            breakpoints: {
                '1600': {
                    slidesPerView: 4,
                },
                '1200': {
                    slidesPerView: 4,
                },
                '992': {
                    slidesPerView: 3,
                },
                '768': {
                    slidesPerView: 2,
                },
                '576': {
                    slidesPerView: 2,
                },
                '0': {
                    slidesPerView: 1,
                },
            },
        });
    }


    $(window).on('elementor/frontend/init', function () {
        if (elementorFrontend.isEditMode()) {
            elementorFrontend.hooks.addAction('frontend/element_ready/auxa-header-1.default', header)
            elementorFrontend.hooks.addAction('frontend/element_ready/auxa-header-2.default', header)
            elementorFrontend.hooks.addAction('frontend/element_ready/auxa-header-3.default', header)
            elementorFrontend.hooks.addAction('frontend/element_ready/int-counter.default', xboActive)
            elementorFrontend.hooks.addAction('frontend/element_ready/int-marquee.default', marqueeActive)
            elementorFrontend.hooks.addAction('frontend/element_ready/int-team.default', teamActive)
            elementorFrontend.hooks.addAction('frontend/element_ready/int-gallery-slider.default', gallerySliderActive)
            elementorFrontend.hooks.addAction('frontend/element_ready/int-marquee-v2.default', marqueeActive)
            elementorFrontend.hooks.addAction('frontend/element_ready/int-brand.default', brandSliderActive)
            elementorFrontend.hooks.addAction('frontend/element_ready/int-about-img.default', xboActive)
            elementorFrontend.hooks.addAction('frontend/element_ready/int-funfact.default', xboActive)
            elementorFrontend.hooks.addAction('frontend/element_ready/int-service-v3.default', serviceSliderActive)
            elementorFrontend.hooks.addAction('frontend/element_ready/int-award-v2.default', awardSliderActive)
            elementorFrontend.hooks.addAction('frontend/element_ready/int-team-img.default', xboActive)
            elementorFrontend.hooks.addAction('frontend/element_ready/int-marquee-v3.default', marqueeActive)
            elementorFrontend.hooks.addAction('frontend/element_ready/int-hero-two.default', xboActive2)
            elementorFrontend.hooks.addAction('frontend/element_ready/int-sec-title.default', scrollTriggerActive)
            elementorFrontend.hooks.addAction('frontend/element_ready/int-counter-v2.default', xboActive)
            elementorFrontend.hooks.addAction('frontend/element_ready/int-team-v3.default', teamSliderActive)
            elementorFrontend.hooks.addAction('frontend/element_ready/int-button.default', elementParallax)
            elementorFrontend.hooks.addAction('frontend/element_ready/int-funfact-img.default', elementParallax)
            elementorFrontend.hooks.addAction('frontend/element_ready/int-portfolio-v2.default', portfolioSlider)
            elementorFrontend.hooks.addAction('frontend/element_ready/int-testimonial-v2.default', testimonialSlider)
            elementorFrontend.hooks.addAction('frontend/element_ready/int-brand-v2.default', brandSliderTwoActive)
            elementorFrontend.hooks.addAction('frontend/element_ready/int-service-v6.default', serviceSliderTwoActive)
            elementorFrontend.hooks.addAction('frontend/element_ready/int-about.default', xboActive)
            elementorFrontend.hooks.addAction('frontend/element_ready/int-portfolio-v3.default', portfolioSliderTwo)
            elementorFrontend.hooks.addAction('frontend/element_ready/int-marquee-v4.default', marqueeActive)
            elementorFrontend.hooks.addAction('frontend/element_ready/int-testimonial-v3.default', testimonialSliderTwo)
            elementorFrontend.hooks.addAction('frontend/element_ready/int-team-v4.default', teamSliderTwo)
            elementorFrontend.hooks.addAction('frontend/element_ready/int-instagram.default', instragramSlider)
            elementorFrontend.hooks.addAction('frontend/element_ready/int-skills.default', progressActive)
            elementorFrontend.hooks.addAction('frontend/element_ready/int-funfact-v2.default', xboActive)
            elementorFrontend.hooks.addAction('frontend/element_ready/int-hero-three.default', heroImageActive)
            elementorFrontend.hooks.addAction('frontend/element_ready/int-feature-v2.default', throwableActive)
            elementorFrontend.hooks.addAction('frontend/element_ready/int-testimonial-v4.default', dsTestimonialSlider)
        }
    });

})(jQuery);