<?php
/**
 * All Elementor widget init
 * @package auxa
 * @since 1.0.0
 */

if ( !defined('ABSPATH') ){
	exit(); // exit if access directly
}

if ( !class_exists('Auxa_Elementor_Widget_Init') ){

	class Auxa_Elementor_Widget_Init{
		/*
		* $instance
		* @since 1.0.0
		* */
		private static $instance;
		/*
		* construct()
		* @since 1.0.0
		* */
		public function __construct() {
			add_action( 'elementor/elements/categories_registered', array($this,'_widget_categories') );
			//elementor widget registered
			add_action('elementor/widgets/register',array($this,'_widget_registered'));
			add_action('elementor/editor/after_enqueue_styles',array($this,'editor_style'));
			add_action('elementor/documents/register_controls',array($this,'register_document_controls'));
		}
		/*
	   * getInstance()
	   * @since 1.0.0
	   * */
		public static function getInstance(){
			if ( null == self::$instance ){
				self::$instance = new self();
			}
			return self::$instance;
		}
		/**
		 * _widget_categories()
		 * @since 1.0.0
		 * */
		public function _widget_categories($elements_manager){
			$elements_manager->add_category(
				'auxa_widgets',
				[
					'title' => __( 'Auxa Addons', 'auxa-core' ),
					'icon' => 'fa fa-plug'
				]
			);
			$elements_manager->add_category(
				'auxa_hf_widgets',
				[
					'title' => __( 'Auxa Header & Footer', 'auxa-core' ),
					'icon' => 'fa fa-plug'
				]
			);
		}
		

		/**
		 * _widget_registered()
		 * @since 1.0.0
		 * */
		public function _widget_registered(){
			if( !class_exists('Elementor\Widget_Base') ){
				return;
			}
			$elementor_widgets = array(	
				
				// auxa Theme Widgets
				'hero-one',
				'xb-logo',
				'sec-title',
				'xb-button',
				'about',
				'about-img',
				'about-tab',
				'service',
				'xb-blur',
				'counter',
				'portfolio',
				'marquee',
				'team',
				'cta',
				'award',
				'testimonial',
				'blog',
				'ukiyo-img',
				'gallery-slider',
				'marquee-v2',
				'team-info',
				'xb-social',
				'team-skills',
				'career',
				'brand',
				'brand-v2',
				'xb-list',
				'xb-form',
				'funfact',
				'experience',
				'service-v2',
				'service-v3',
				'service-tags',
				'faq',
				'award-v2',
				'team-title',
				'team-img',
				'marquee-v3',
				'team-v2',
				'faq-v2',
				'contact-info',
				'hero-two',
				'career-v2',
				'career-cta',
				'service-v4',
				'feature',
				'feature-v2',
				'counter-v2',
				'story',
				'team-v3',
				'hero-three',
				'service-v5',
				'funfact-img',
				'portfolio-v2',
				'portfolio-v3',
				'testimonial-v2',
				'service-v6',
				'xb-link',
				'marquee-v4',
				'xb-video',
				'testimonial-v3',
				'team-v4',
				'instagram',
				'service-v7',
				'about-title',
				'xb-video-v2',
				'skills',
				'portfolio-v4',
				'portfolio-v5',
				'team-v5',
				'cta-v2',
				'brand-v3',
				'brand-v4',
				'parallax-video',
				'service-v8',
				'faq-v3',
				'funfact-v2',
				'feature-v2',
				'pricing',
				'testimonial-v4',

				// header
				'01-header',
				'02-header',
				'03-header',

                // footer
				'01-footer',

			);

			$elementor_widgets = apply_filters('auxa_elementor_widget',$elementor_widgets);

			if ( is_array($elementor_widgets) && !empty($elementor_widgets) ) {
				foreach ( $elementor_widgets as $widget ){
					$widget_file = 'plugins/elementor/widget/'.$widget.'.php';
					$template_file = locate_template($widget_file);
					if ( !$template_file || !is_readable( $template_file ) ) {
						$template_file = AUXA_DIR_PATH.'/elementor/widgets/'.$widget.'.php';
					}
					if ( $template_file && is_readable( $template_file ) ) {
						include_once $template_file;
					}
				}
			}
		}

		public function editor_style(){
			$cs_icon = plugins_url( 'icons.png', __FILE__ );
			wp_add_inline_style( 'elementor-editor', '.elementor-element .icon .auxa-custom-icon{content: url( '.$cs_icon.');width: 28px;}' );
		}

		/**
		 * Register additional document controls.
		 *
		 * @param \Elementor\Core\DocumentTypes\PageBase $document The PageBase document instance.
		 */
		public function register_document_controls( $document ) {

			if ( ! $document instanceof \Elementor\Core\DocumentTypes\PageBase || ! $document::get_property( 'has_elements' ) ) {
				return;
			}

			$document->start_controls_section(
				'body_typography',
				[
					'label' => esc_html__( 'Body Typography', 'auxa-core' ),
					'tab' => \Elementor\Controls_Manager::TAB_STYLE,
				]
			);

			$document->add_group_control(
				\Elementor\Group_Control_Typography::get_type(),
				[
					'name' => 'page_body_font',
					'selector' => '{{WRAPPER}}',
				]
			);
			$document->add_control(
				'body_color',
				[
					'label' => esc_html__( 'Body Color', 'auxa-core' ),
					'type' => \Elementor\Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}}' => 'color: {{VALUE}}',
					],
				]
			);
			$document->add_control(
				'heading_color',
				[
					'label' => esc_html__( 'Heading Color', 'auxa-core' ),
					'type' => \Elementor\Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} h1, h2, h3, h4, h5, h6' => 'color: {{VALUE}}',
					],
				]
			);
			$document->add_group_control(
				\Elementor\Group_Control_Typography::get_type(),
				[
					'name' => 'page_heading_font',
					'selector' => '{{WRAPPER}} h1, {{WRAPPER}} h2, {{WRAPPER}} h3, {{WRAPPER}} h4, {{WRAPPER}} h5, {{WRAPPER}} h6',
				]
			);

			$document->end_controls_section();
		}
	}

	if ( class_exists('Auxa_Elementor_Widget_Init') ){
		Auxa_Elementor_Widget_Init::getInstance();
	}

}//end if