<?php

/**
 * Elementor Single Widget
 * @package auxa-core
 * @since 1.0.0
 */

namespace Elementor;

if (!defined('ABSPATH')) exit; // Exit if accessed directly.

class Auxa_Footer_One extends Widget_Base
{

    /**
     * Get widget name.
     *
     * Retrieve Elementor widget name.
     *
     * @return string Widget name.
     * @since 1.0.0
     * @access public
     *
     */
    public function get_name()
    {
        return 'auxa-footer-1';
    }

    /**
     * Get widget title.
     *
     * Retrieve Elementor widget title.
     *
     * @return string Widget title.
     * @since 1.0.0
     * @access public
     *
     */
    public function get_title()
    {
        return esc_html__('Footer One', 'auxa-core');
    }

    /**
     * Get widget icon.
     *
     * Retrieve Elementor widget icon.
     *
     * @return string Widget icon.
     * @since 1.0.0
     * @access public
     *
     */
    public function get_icon()
    {
        return 'auxa-custom-icon';
    }

    /**
     * Get widget categories.
     *
     * Retrieve the list of categories the Elementor widget belongs to.
     *
     * @return array Widget categories.
     * @since 1.0.0
     * @access public
     *
     */
    public function get_categories()
    {
        return ['auxa_hf_widgets'];
    }


    protected function register_controls()
    {

        $this->start_controls_section(
            'container_otpion',
            [
                'label' => esc_html__('Container', 'auxa-core'),
                'tab' => Controls_Manager::TAB_CONTENT,
            ]
        );
        $this->add_control(
            'bg_image',
            [
                'label' => esc_html__('Background Image', 'auxa-core'),
                'type' => \Elementor\Controls_Manager::MEDIA,
            ]
        );
        $this->end_controls_section();

        $this->start_controls_section(
            'btn_option',
            [
                'label' => esc_html__('Button Option', 'auxa-core'),
                'tab' => Controls_Manager::TAB_CONTENT,
            ]
        );
        $this->add_control(
            'btn_label', [
                'label' => esc_html__('Button Label', 'auxa-core'),
                'type' => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        $this->add_control(
            'icon',
            [
                'label' => esc_html__('Icon', 'auxa-core'),
                'type' => \Elementor\Controls_Manager::ICONS,
            ]
        );
        $this->add_control(
            'btn_link',
            [
                'label' => esc_html__('Button Link', 'xprss-core'),
                'type' => \Elementor\Controls_Manager::URL,
                'options' => ['url'],
                'default' => [
                    'url' => '#',
                ],
                'label_block' => true,
            ]
        );

        $this->end_controls_section();

        $this->start_controls_section(
            'social_option',
            [
                'label' => esc_html__('Social Media', 'auxa-core'),
                'tab' => Controls_Manager::TAB_CONTENT,
            ]
        );
        $this->add_control(
            's_title',
            [
                'type' => Controls_Manager::TEXT,
                'label' => esc_html__('Title', 'auxa-core'),
                'label_block' => true,
            ]
        );
        $repeater = new \Elementor\Repeater();

        $repeater->add_control(
            'text',
            [
                'type' => Controls_Manager::TEXT,
                'label' => esc_html__('Social Text', 'auxa-core'),
                'label_block' => true,
            ]
        );
        $repeater->add_control(
            'link',
            [
                'label' => esc_html__('Link', 'xprss-core'),
                'type' => \Elementor\Controls_Manager::URL,
                'options' => ['url'],
                'default' => [
                    'url' => '#',
                ],
                'label_block' => true,
            ]
        );
        $this->add_control(
            'socials',
            [
                'type' => Controls_Manager::REPEATER,
                'fields' => $repeater->get_controls(),
                'title_field' => '{{{ text }}}',
            ]
        );
        $this->end_controls_section();

        $this->start_controls_section(
            'contact_info_option',
            [
                'label' => esc_html__('Contact Info', 'auxa-core'),
                'tab' => Controls_Manager::TAB_CONTENT,
            ]
        );
        $this->add_control(
            'c_title',
            [
                'type' => Controls_Manager::TEXT,
                'label' => esc_html__('Title', 'auxa-core'),
                'label_block' => true,
            ]
        );
        $this->add_control(
            'address',
            [
                'type' => Controls_Manager::TEXTAREA,
                'label' => esc_html__('Title', 'auxa-core'),
                'label_block' => true,
            ]
        );
        $this->end_controls_section();

        $this->start_controls_section(
            'useful_link_option',
            [
                'label' => esc_html__('Useful Link', 'auxa-core'),
                'tab' => Controls_Manager::TAB_CONTENT,
            ]
        );
        $this->add_control(
            'u_title',
            [
                'type' => Controls_Manager::TEXT,
                'label' => esc_html__('Title', 'auxa-core'),
                'label_block' => true,
            ]
        );
        $repeater = new \Elementor\Repeater();

        $repeater->add_control(
            'text',
            [
                'type' => Controls_Manager::TEXT,
                'label' => esc_html__('Text', 'auxa-core'),
                'label_block' => true,
            ]
        );
        $repeater->add_control(
            'link',
            [
                'label' => esc_html__('Link', 'xprss-core'),
                'type' => \Elementor\Controls_Manager::URL,
                'options' => ['url'],
                'default' => [
                    'url' => '#',
                ],
                'label_block' => true,
            ]
        );
        $this->add_control(
            'links',
            [
                'type' => Controls_Manager::REPEATER,
                'fields' => $repeater->get_controls(),
                'title_field' => '{{{ text }}}',
            ]
        );
        $this->end_controls_section();

        $this->start_controls_section(
            'more_info_link_option',
            [
                'label' => esc_html__('More Info Link', 'auxa-core'),
                'tab' => Controls_Manager::TAB_CONTENT,
            ]
        );
        $this->add_control(
            'i_title',
            [
                'type' => Controls_Manager::TEXT,
                'label' => esc_html__('Title', 'auxa-core'),
                'label_block' => true,
            ]
        );
        $repeater = new \Elementor\Repeater();

        $repeater->add_control(
            'text',
            [
                'type' => Controls_Manager::TEXT,
                'label' => esc_html__('Text', 'auxa-core'),
                'label_block' => true,
            ]
        );
        $repeater->add_control(
            'link',
            [
                'label' => esc_html__('Link', 'xprss-core'),
                'type' => \Elementor\Controls_Manager::URL,
                'options' => ['url'],
                'default' => [
                    'url' => '#',
                ],
                'label_block' => true,
            ]
        );
        $this->add_control(
            'infos',
            [
                'type' => Controls_Manager::REPEATER,
                'fields' => $repeater->get_controls(),
                'title_field' => '{{{ text }}}',
            ]
        );
        $this->end_controls_section();

        $this->start_controls_section(
            'copyright_option',
            [
                'label' => esc_html__('Copyright', 'auxa-core'),
                'tab' => Controls_Manager::TAB_CONTENT,
            ]
        );
        $this->add_control(
            'copyright_text',
            [
                'type' => Controls_Manager::WYSIWYG,
                'label' => esc_html__('Copyright Text', 'auxa-core'),
                'label_block' => true,
            ]
        );
        $this->end_controls_section();

        $this->start_controls_section(
            'footer_link_option',
            [
                'label' => esc_html__('Footer Link', 'auxa-core'),
                'tab' => Controls_Manager::TAB_CONTENT,
            ]
        );
        $repeater = new \Elementor\Repeater();

        $repeater->add_control(
            'text',
            [
                'type' => Controls_Manager::TEXT,
                'label' => esc_html__('Text', 'auxa-core'),
                'label_block' => true,
            ]
        );
        $repeater->add_control(
            'link',
            [
                'label' => esc_html__('Link', 'xprss-core'),
                'type' => \Elementor\Controls_Manager::URL,
                'options' => ['url'],
                'default' => [
                    'url' => '#',
                ],
                'label_block' => true,
            ]
        );
        $this->add_control(
            'f_links',
            [
                'type' => Controls_Manager::REPEATER,
                'fields' => $repeater->get_controls(),
                'title_field' => '{{{ text }}}',
            ]
        );
        $this->end_controls_section();

        $this->start_controls_section(
            'btn_style',
            [
                'label' => esc_html__('Button Style', 'auxa-core'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );
        $this->add_control(
            'btn_size',
            [
                'label' => esc_html__('Button Size', 'auxa-core'),
                'type' => \Elementor\Controls_Manager::SLIDER,
                'size_units' => ['px', '%', 'em', 'rem', 'custom'],
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 1000,
                        'step' => 5,
                    ],
                    '%' => [
                        'min' => 0,
                        'max' => 100,
                    ],
                ],
                'selectors' => [
                    '{{WRAPPER}} .xb-footer .xb-item--left' => 'width: {{SIZE}}{{UNIT}};',
                    '{{WRAPPER}} .xb-item--left' => 'height: {{SIZE}}{{UNIT}};',
                ],
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'btn_typography',
                'selector' => '{{WRAPPER}} .xb-footer .xb-item--head',
            ]
        );
        $this->start_controls_tabs(
            'style_tabs'
        );

        $this->start_controls_tab(
            'style_normal_tab',
            [
                'label' => esc_html__('Normal', 'auxa-core'),
            ]
        );

        $this->add_control(
            'btn-c',
            [
                'label' => esc_html__('Button Color', 'auxa-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .xb-footer .xb-item--head' => 'color: {{VALUE}}',
                    '{{WRAPPER}} .xb-footer .xb-item--icon svg path' => 'stroke: {{VALUE}}',
                ],
            ]
        );
        $this->add_control(
            'btn_bg-c',
            [
                'label' => esc_html__('Button BG Color', 'auxa-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .button__bg' => 'background-color: {{VALUE}}',
                ],
            ]
        );
        $this->end_controls_tab();

        $this->start_controls_tab(
            'style_hover_tab',
            [
                'label' => esc_html__('Hover', 'auxa-core'),
            ]
        );

        $this->add_control(
            'hbtn-c',
            [
                'label' => esc_html__('Button Color', 'auxa-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .xb-footer .xb-item--left:hover .xb-item--head' => 'color: {{VALUE}}',
                    '{{WRAPPER}} .xb-footer .xb-item--left:hover .xb-item--icon svg path' => 'stroke: {{VALUE}}',
                ],
            ]
        );
        $this->add_control(
            'hbtn_bg-c',
            [
                'label' => esc_html__('Button BG Color', 'auxa-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .circle-btn .button__bg::before' => 'background: {{VALUE}}',
                    '{{WRAPPER}} .circle-btn .button__bg::after' => 'background: {{VALUE}}',
                ],
            ]
        );

        $this->end_controls_tab();

        $this->end_controls_tabs();
        $this->end_controls_section();

        $this->start_controls_section(
            'widget_style',
            [
                'label' => esc_html__('Widget Style', 'auxa-core'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );
        $this->add_control(
            'w_title-c',
            [
                'label' => esc_html__('Title Color', 'auxa-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .footer-widget .widget-title' => 'color: {{VALUE}}',
                ],
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'w_title_typography',
                'selector' => '{{WRAPPER}} .footer-widget .widget-title',
            ]
        );
        $this->add_control(
            'social_style',
            [
                'label' => esc_html__('Social Style', 'auxa-core'),
                'type' => \Elementor\Controls_Manager::HEADING,
                'separator' => 'before',
            ]
        );
        $this->add_control(
            's_text-c',
            [
                'label' => esc_html__('Social Text Color', 'auxa-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .xb-footer .xb-item--social li a' => 'color: {{VALUE}}',
                ],
            ]
        );
        $this->add_control(
            'h_s_text-c',
            [
                'label' => esc_html__('Social Hover Color', 'auxa-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .xb-footer .xb-item--social li a:hover' => 'color: {{VALUE}}',
                ],
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'social_typography',
                'selector' => '{{WRAPPER}} .xb-footer .xb-item--social li a',
            ]
        );
        $this->add_control(
            'address_style',
            [
                'label' => esc_html__('Address Style', 'auxa-core'),
                'type' => \Elementor\Controls_Manager::HEADING,
                'separator' => 'before',
            ]
        );
        $this->add_control(
            'add-c',
            [
                'label' => esc_html__('Address Color', 'auxa-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .xb-footer .xb-item--content' => 'color: {{VALUE}}',
                ],
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'address_typography',
                'selector' => '{{WRAPPER}} .xb-footer .xb-item--content',
            ]
        );
        $this->add_control(
            'widget_link_style',
            [
                'label' => esc_html__('Widget Link Style', 'auxa-core'),
                'type' => \Elementor\Controls_Manager::HEADING,
                'separator' => 'before',
            ]
        );
        $this->add_control(
            'w_link-c',
            [
                'label' => esc_html__('Link Color', 'auxa-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .footer-links li a' => 'color: {{VALUE}}',
                ],
            ]
        );
        $this->add_control(
            'h_w_link-c',
            [
                'label' => esc_html__('Link Hover Color', 'auxa-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .footer-links li a:hover' => 'color: {{VALUE}}',
                ],
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'link_typography',
                'selector' => '{{WRAPPER}} .footer-links li a',
            ]
        );

        $this->end_controls_section();
        $this->start_controls_section(
            'copyright_style',
            [
                'label' => esc_html__('Copyright Style', 'auxa-core'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );
        $this->add_control(
            'border_top_c',
            [
                'label' => esc_html__('Border Top Color', 'auxa-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .footer-bottom' => 'border-color: {{VALUE}}',
                ],
            ]
        );
        $this->add_control(
            'copyright_text_hr',
            [
                'type' => \Elementor\Controls_Manager::DIVIDER,
            ]
        );
        $this->add_control(
            'copyright_text-c',
            [
                'label' => esc_html__('Copyright Text Color', 'auxa-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .footer-bottom .copyright' => 'color: {{VALUE}}',
                ],
            ]
        );
        $this->add_control(
            'copyright_link-c',
            [
                'label' => esc_html__('Copyright Link Color', 'auxa-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .footer-bottom .copyright a' => 'color: {{VALUE}}',
                ],
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'copyright_text_typography',
                'selector' => '{{WRAPPER}} .footer-bottom .copyright',
            ]
        );
        $this->add_control(
            'link_style',
            [
                'label' => esc_html__('Link Style', 'auxa-core'),
                'type' => \Elementor\Controls_Manager::HEADING,
                'separator' => 'before',
            ]
        );
        $this->add_control(
            'c_link-c',
            [
                'label' => esc_html__('Link Color', 'auxa-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .footer-nav li a' => 'color: {{VALUE}}',
                ],
            ]
        );
        $this->add_control(
            'h_c_link-c',
            [
                'label' => esc_html__('Link Hover Color', 'auxa-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .footer-nav li a:hover' => 'color: {{VALUE}}',
                ],
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'f_link_typography',
                'selector' => '{{WRAPPER}} .footer-nav li a',
            ]
        );
        $this->end_controls_section();


    }


    protected function render()
    {
        $settings = $this->get_settings_for_display();
        ?>

        <footer class="footer xb-footer-bg bg_img ukiyo"
                data-u-speed="1.5" <?php if (!empty($settings['bg_image']['url'])): ?>
                style="background-image: url('<?php echo esc_url($settings['bg_image']['url']); ?>') <?php endif; ?>">
            <div class="xb-footer-wrap pt-120 pb-80">
                <div class="container">
                    <div class="xb-footer-inner">
                        <div class="xb-footer ul_li pb-75">
                            <div class="row align-items-center mt-none-30">
                                <?php if (!empty($settings['btn_label'])): ?>
                                    <div class="col-lg-6 col-md-6 mt-30">
                                        <a class="circle-btn xb-item--left xb-element-parallax pos-rel"
                                           href="<?php echo esc_url($settings['btn_link']['url']); ?>">
                                            <div class="button__bg"></div>
                                            <div class="xb-item--icon">
                                                <?php \Elementor\Icons_Manager::render_icon($settings['icon'], ['aria-hidden' => 'true']); ?>
                                            </div>
                                            <span class="xb-item--head"><?php echo esc_html($settings['btn_label']); ?></span>
                                        </a>
                                    </div>
                                <?php endif; ?>
                                <div class="col-lg-3 col-md-6 mt-30">
                                    <div class="footer-widget xb-item--con">
                                        <?php if (!empty($settings['s_title'])): ?>
                                            <h4 class="widget-title"><?php echo esc_html($settings['s_title']); ?></h4>
                                        <?php endif; ?>
                                        <ul class="xb-item--social">
                                            <?php
                                            foreach ($settings['socials'] as $social):
                                                ?>
                                                <li>
                                                    <a href="<?php echo esc_url($social['link']['url']) ?>"><?php echo esc_html($social['text']); ?></a>
                                                </li>
                                            <?php endforeach; ?>
                                        </ul>
                                        <?php if (!empty($settings['u_title'])): ?>
                                            <h4 class="widget-title"><?php echo esc_html($settings['u_title']); ?></h4>
                                        <?php endif; ?>
                                        <ul class="footer-links">
                                            <?php
                                            foreach ($settings['links'] as $link):
                                                ?>
                                                <li>
                                                    <a href="<?php echo esc_url($link['link']['url']) ?>"><?php echo esc_html($link['text']); ?></a>
                                                </li>
                                            <?php endforeach; ?>
                                        </ul>
                                    </div>
                                </div>
                                <div class="col-lg-3 col-md-12 mt-30">
                                    <div class="row">
                                        <div class="col-lg-12 col-md-6">
                                            <div class="footer-widget">
                                                <?php if (!empty($settings['c_title'])): ?>
                                                    <h4 class="widget-title"><?php echo esc_html($settings['c_title']); ?></h4>
                                                <?php endif; ?>
                                                <?php if (!empty($settings['address'])): ?>
                                                    <h3 class="xb-item--content"><?php echo wp_kses($settings['address'], true); ?>
                                                    </h3>
                                                <?php endif; ?>
                                            </div>
                                        </div>
                                        <div class="col-lg-12 col-md-6">
                                            <div class="footer-widget">
                                                <?php if (!empty($settings['i_title'])): ?>
                                                    <h4 class="widget-title"><?php echo esc_html($settings['i_title']); ?></h4>
                                                <?php endif; ?>
                                                <ul class="footer-links">
                                                    <?php
                                                    foreach ($settings['infos'] as $info):
                                                        ?>
                                                        <li>
                                                            <a href="<?php echo esc_url($info['link']['url']) ?>"><?php echo esc_html($info['text']); ?></a>
                                                        </li>
                                                    <?php endforeach; ?>
                                                </ul>
                                            </div>
                                        </div>
                                    </div>
                                </div>
                            </div>
                        </div>
                        <div class="footer-bottom ul_li_between">
                            <?php if (!empty($settings['copyright_text'])): ?>
                                <div class="copyright">
                                    <?php echo wp_kses($settings['copyright_text'], true); ?>
                                </div>
                            <?php endif; ?>
                            <ul class="footer-nav ul_li_right">
                                <?php foreach ($settings['f_links'] as $link): ?>
                                    <li><a href="<?php echo esc_url($link['link']['url']) ?>"><?php echo esc_html($link['text']); ?></a></li>
                                <?php endforeach; ?>
                            </ul>
                        </div>
                    </div>
                </div>
            </div>
        </footer>

        <?php
    }
}


Plugin::instance()->widgets_manager->register(new Auxa_Footer_One());