<?php

/**
 * Elementor Single Widget
 * @package auxa-core
 * @since 1.0.0
 */

namespace Elementor;

if (!defined('ABSPATH')) exit; // Exit if accessed directly.

class Auxa_Header_Two extends Widget_Base
{

    /**
     * Get widget name.
     *
     * Retrieve Elementor widget name.
     *
     * @return string Widget name.
     * @since 1.0.0
     * @access public
     *
     */
    public function get_name()
    {
        return 'auxa-header-2';
    }

    /**
     * Get widget title.
     *
     * Retrieve Elementor widget title.
     *
     * @return string Widget title.
     * @since 1.0.0
     * @access public
     *
     */
    public function get_title()
    {
        return esc_html__('Header Two', 'auxa-core');
    }

    /**
     * Get widget icon.
     *
     * Retrieve Elementor widget icon.
     *
     * @return string Widget icon.
     * @since 1.0.0
     * @access public
     *
     */
    public function get_icon()
    {
        return 'auxa-custom-icon';
    }

    /**
     * Get widget categories.
     *
     * Retrieve the list of categories the Elementor widget belongs to.
     *
     * @return array Widget categories.
     * @since 1.0.0
     * @access public
     *
     */
    public function get_categories()
    {
        return ['auxa_hf_widgets'];
    }


    protected function register_controls()
    {

        $this->start_controls_section(
            'logoop',
            [
                'label' => esc_html__('Logo Option', 'auxa-core'),
                'tab' => Controls_Manager::TAB_CONTENT,
            ]
        );

        $this->add_control(
            'logo', [
                'label' => esc_html__('Logo', 'auxa-core'),
                'type' => Controls_Manager::MEDIA,
                'label_block' => true,
            ]
        );
        $this->add_responsive_control(
            'logo_max_width',
            [
                'label' => esc_html__('Max Width', 'auxa-core'),
                'type' => \Elementor\Controls_Manager::SLIDER,
                'size_units' => ['px', '%', 'em', 'rem', 'custom'],
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 5000,
                    ]
                ],

                'selectors' => [
                    '{{WRAPPER}} .header-logo img' => 'max-width: {{SIZE}}{{UNIT}};',
                ],
            ]
        );

        $this->end_controls_section();

        $this->start_controls_section(
            'menu_select',
            [
                'label' => esc_html__('Menu Option', 'auxa-core'),
                'tab' => Controls_Manager::TAB_CONTENT,
            ]
        );
        $this->add_control(
            'choose-menu',
            [
                'label' => esc_html__('Choose menu', 'auxa-core'),
                'type' => \Elementor\Controls_Manager::SELECT2,
                'options' => auxa_menu_selector(),
                'multiple' => false
            ]
        );

        $this->end_controls_section();

        $this->start_controls_section(
            'hamburger_option',
            [
                'label' => esc_html__('Hamburger Option', 'auxa-core'),
                'tab' => Controls_Manager::TAB_CONTENT,
            ]
        );
        $this->add_control(
            'hamburger_active',
            [
                'label' => esc_html__('Active', 'auxa-core'),
                'type' => \Elementor\Controls_Manager::SWITCHER,
                'label_on' => esc_html__('Show', 'auxa-core'),
                'label_off' => esc_html__('Hide', 'auxa-core'),
                'return_value' => 'yes',
                'default' => 'yes',
            ]
        );
        $this->add_control(
            'hamburger_text',
            [
                'type' => Controls_Manager::TEXT,
                'label' => esc_html__('Hamburger Text', 'auxa-core'),
                'label_block' => true,
            ]
        );
        $this->end_controls_section();

        $this->start_controls_section(
            'button_style',
            [
                'label' => esc_html__('Button Style', 'auxa-core'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );
        $this->add_control(
            'stroke_btn_style',
            [
                'label' => esc_html__('Stroke Button', 'auxa-core'),
                'type' => \Elementor\Controls_Manager::HEADING,
                'separator' => 'before',
            ]
        );
        $this->add_control(
            'st_btn_padding',
            [
                'label' => esc_html__('Padding', 'auxa-core'),
                'type' => \Elementor\Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em', 'rem', 'custom'],
                'selectors' => [
                    '{{WRAPPER}} .thm-btn--stroke' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'st_btn_typography',
                'selector' => '{{WRAPPER}} .thm-btn--stroke',
            ]
        );
        $this->add_control(
            'st_text-c',
            [
                'label' => esc_html__('Text Color', 'auxa-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .thm-btn--stroke' => 'color: {{VALUE}}',
                ],
            ]
        );
        $this->add_control(
            'st_text_border-c',
            [
                'label' => esc_html__('Border Color', 'auxa-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .thm-btn--stroke svg path' => 'stroke: {{VALUE}}',
                ],
            ]
        );
        $this->add_control(
            'btn_2_style',
            [
                'label' => esc_html__('Button Two', 'auxa-core'),
                'type' => \Elementor\Controls_Manager::HEADING,
                'separator' => 'before',
            ]
        );
        $this->add_control(
            'btn_padding',
            [
                'label' => esc_html__('Padding', 'auxa-core'),
                'type' => \Elementor\Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em', 'rem', 'custom'],
                'selectors' => [
                    '{{WRAPPER}} .thm-btn--anim' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'btn_typography',
                'selector' => '{{WRAPPER}} .thm-btn--anim',
            ]
        );
        $this->add_control(
            'btn-bg-c',
            [
                'label' => esc_html__('Background Color', 'auxa-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .thm-btn--anim svg path' => 'fill: {{VALUE}}',
                ],
            ]
        );
        $this->add_control(
            'btn_text-c',
            [
                'label' => esc_html__('Text Color', 'auxa-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .thm-btn--anim' => 'color: {{VALUE}}',
                ],
            ]
        );
        $this->add_control(
            'hamburger_style',
            [
                'label' => esc_html__('Hamburger Style', 'auxa-core'),
                'type' => \Elementor\Controls_Manager::HEADING,
                'separator' => 'before',
            ]
        );
        $this->add_control(
            'hamburger_bg-c',
            [
                'label' => esc_html__('Hamburger BG Color', 'auxa-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .burger-menu svg path' => 'fill: {{VALUE}}',
                ],
            ]
        );
        $this->add_control(
            'hamburger_text-c',
            [
                'label' => esc_html__('Hamburger Text Color', 'auxa-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .side-menu a span' => 'color: {{VALUE}}',
                ],
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'hamburger_text_typography',
                'selector' => '{{WRAPPER}} .side-menu a span',
            ]
        );
        $this->end_controls_section();

    }

    protected function render()
    {
        $settings = $this->get_settings_for_display();
        $sticky_header_enable = auxa_option('sticky_header_enable');
        ?>

        <header id="xb-header-area"
                class="header-area <?php if ($sticky_header_enable == true): ?> is-sticky <?php endif; ?>">
            <div class="xb-header">
                <div class="container">
                    <div class="header__wrap ul_li_between">
                        <div class="header-logo">
                            <a href="<?php if (!empty($settings['logolink']['url'])) {
                                echo esc_url($settings['logolink']['url']);
                            } else {
                                echo esc_url(home_url('/'));
                            } ?>"><img src="<?php echo esc_url($settings['logo']['url']); ?>" alt=""></a>
                        </div>
                        <div class="main-menu__wrap ul_li navbar navbar-expand-lg">
                            <nav class="main-menu collapse navbar-collapse">
                                <?php
                                wp_nav_menu(array(
                                    'menu' => $settings['choose-menu'],
                                    'menu_id' => 'main-nav',
                                    'link_before' => '<span>', 'link_after' => '</span>',
                                    'container' => false,
                                    'fallback_cb' => 'Auxa_Bootstrap_Navwalker::fallback',
                                ));
                                ?>
                            </nav>
                            <div class="xb-header-wrap">
                                <div class="xb-header-menu">
                                    <div class="xb-header-menu-scroll">
                                        <div class="xb-menu-close xb-hide-xl xb-close"></div>
                                        <div class="xb-logo-mobile xb-hide-xl">
                                            <a href="<?php if (!empty($settings['logolink']['url'])) {
                                                echo esc_url($settings['logolink']['url']);
                                            } else {
                                                echo esc_url(home_url('/'));
                                            } ?>"><img src="<?php echo esc_url($settings['logo']['url']); ?>" alt=""></a>
                                        </div>
                                        <?php
                                        auxa_moble_search();
                                        ?>
                                        <nav class="xb-header-nav">
                                            <?php
                                            wp_nav_menu(array(
                                                'menu' => $settings['choose-menu'],
                                                'menu_id' => 'mobile-main-nav',
                                                'menu_class' => 'xb-menu-primary clearfix',
                                                'link_before' => '<span>', 'link_after' => '</span>',
                                                'container' => false,
                                                'fallback_cb' => 'Auxa_Bootstrap_Navwalker::fallback',
                                            ));
                                            ?>
                                        </nav>
                                    </div>
                                </div>
                                <div class="xb-header-menu-backdrop"></div>
                            </div>
                        </div>
                        <?php if ($settings['hamburger_active'] === 'yes'): ?>
                            <div class="header-menu d-none d-lg-block">
                                <a class="burger-menu" href="javascript:void(0);"><span
                                            class="br-header_menu"><?php echo esc_html($settings['hamburger_text']); ?></span>
                                    <svg width="18" height="16" viewBox="0 0 18 16" fill="none"
                                         xmlns="http://www.w3.org/2000/svg">
                                        <path d="M13 14V16H2V14H13ZM18 7V9H0V7H18ZM16 0V2H5V0H16Z" fill="white"/>
                                    </svg>
                                </a>
                            </div>
                        <?php endif; ?>
                        <div class="header-bar-mobile side-menu d-lg-none">
                            <a class="xb-nav-mobile" href="javascript:void(0);">
                                <svg width="30" height="30" viewBox="0 0 30 30" fill="none"
                                     xmlns="http://www.w3.org/2000/svg">
                                    <path d="M6.25 12.5H8.75C11.25 12.5 12.5 11.25 12.5 8.75V6.25C12.5 3.75 11.25 2.5 8.75 2.5H6.25C3.75 2.5 2.5 3.75 2.5 6.25V8.75C2.5 11.25 3.75 12.5 6.25 12.5Z"
                                          stroke="white" stroke-width="1.5" stroke-miterlimit="10"
                                          stroke-linecap="round" stroke-linejoin="round"/>
                                    <path d="M21.25 12.5H23.75C26.25 12.5 27.5 11.25 27.5 8.75V6.25C27.5 3.75 26.25 2.5 23.75 2.5H21.25C18.75 2.5 17.5 3.75 17.5 6.25V8.75C17.5 11.25 18.75 12.5 21.25 12.5Z"
                                          stroke="white" stroke-width="1.5" stroke-miterlimit="10"
                                          stroke-linecap="round" stroke-linejoin="round"/>
                                    <path d="M21.25 27.5H23.75C26.25 27.5 27.5 26.25 27.5 23.75V21.25C27.5 18.75 26.25 17.5 23.75 17.5H21.25C18.75 17.5 17.5 18.75 17.5 21.25V23.75C17.5 26.25 18.75 27.5 21.25 27.5Z"
                                          stroke="white" stroke-width="1.5" stroke-miterlimit="10"
                                          stroke-linecap="round" stroke-linejoin="round"/>
                                    <path d="M6.25 27.5H8.75C11.25 27.5 12.5 26.25 12.5 23.75V21.25C12.5 18.75 11.25 17.5 8.75 17.5H6.25C3.75 17.5 2.5 18.75 2.5 21.25V23.75C2.5 26.25 3.75 27.5 6.25 27.5Z"
                                          stroke="white" stroke-width="1.5" stroke-miterlimit="10"
                                          stroke-linecap="round" stroke-linejoin="round"/>
                                </svg>
                            </a>
                        </div>
                    </div>
                </div>
            </div>
        </header>

        <div class="overlay-menu">
            <?php auxa_overlay_menu(); ?>
        </div>
        <?php
    }
}


Plugin::instance()->widgets_manager->register(new Auxa_Header_Two());