<?php

/**
 * Elementor Single Widget
 * @package auxa-core
 * @since 1.0.0
 */

namespace Elementor;

if (!defined('ABSPATH')) exit; // Exit if accessed directly.

class Auxa_Career_CTA extends Widget_Base
{

    /**
     * Get widget name.
     *
     * Retrieve Elementor widget name.
     *
     * @return string Widget name.
     * @since 1.0.0
     * @access public
     *
     */
    public function get_name()
    {
        return 'int-career-cta';
    }

    /**
     * Get widget title.
     *
     * Retrieve Elementor widget title.
     *
     * @return string Widget title.
     * @since 1.0.0
     * @access public
     *
     */
    public function get_title()
    {
        return esc_html__('Career CTA', 'auxa-core');
    }

    /**
     * Get widget icon.
     *
     * Retrieve Elementor widget icon.
     *
     * @return string Widget icon.
     * @since 1.0.0
     * @access public
     *
     */
    public function get_icon()
    {
        return 'auxa-custom-icon';
    }

    /**
     * Get widget categories.
     *
     * Retrieve the list of categories the Elementor widget belongs to.
     *
     * @return array Widget categories.
     * @since 1.0.0
     * @access public
     *
     */
    public function get_categories()
    {
        return ['auxa_widgets'];
    }


    protected function register_controls()
    {

        $this->start_controls_section(
            'content_option',
            [
                'label' => esc_html__('Content', 'auxa-core'),
                'tab' => Controls_Manager::TAB_CONTENT,
            ]
        );
        $this->add_control(
            'title',
            [
                'type' => Controls_Manager::TEXTAREA,
                'label' => esc_html__('Title', 'auxa-core'),
                'label_block' => true,
            ]
        );
        $this->add_control(
            'content',
            [
                'type' => Controls_Manager::TEXTAREA,
                'label' => esc_html__('Content', 'auxa-core'),
                'label_block' => true,
            ]
        );
        $this->add_control(
            'link',
            [
                'label' => esc_html__('Link', 'xprss-core'),
                'type' => \Elementor\Controls_Manager::URL,
                'options' => ['url'],
                'default' => [
                    'url' => '#',
                ],
                'label_block' => true,
            ]
        );

        $this->end_controls_section();


        $this->start_controls_section(
            'color_option',
            [
                'label' => esc_html__('Style', 'auxa-core'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );
        $this->add_control(
            'bg-c',
            [
                'label' => esc_html__('Background Color', 'auxa-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .xb-careear .xb-item--shape svg path' => 'fill: {{VALUE}}',
                ],
            ]
        );
        $this->add_control(
            'padding',
            [
                'label' => esc_html__('Padding', 'auxa-core'),
                'type' => \Elementor\Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em', 'rem', 'custom'],
                'selectors' => [
                    '{{WRAPPER}} .xb-careear' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );
        $this->add_control(
            'title_hr',
            [
                'type' => \Elementor\Controls_Manager::DIVIDER,
            ]
        );
        $this->add_control(
            'title-c',
            [
                'label' => esc_html__('Title Color', 'auxa-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .xb-careear .xb-item--content' => 'color: {{VALUE}}',
                ],
            ]
        );
        $this->add_control(
            'title_bg-c',
            [
                'label' => esc_html__('Title BG Color', 'auxa-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .xb-careear .xb-item--content' => 'background: {{VALUE}}',
                ],
            ]
        );
        $this->add_control(
            'title_border_c',
            [
                'label' => esc_html__('Title Border Color', 'auxa-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .xb-careear .xb-item--content' => 'border-color: {{VALUE}}',
                ],
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'title_typography',
                'selector' => '{{WRAPPER}} .xb-careear .xb-item--content',
            ]
        );
        $this->add_control(
            'title_padding',
            [
                'label' => esc_html__('Title Padding', 'auxa-core'),
                'type' => \Elementor\Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em', 'rem', 'custom'],
                'selectors' => [
                    '{{WRAPPER}} .xb-careear .xb-item--content' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );
        $this->add_control(
            'content_hr',
            [
                'type' => \Elementor\Controls_Manager::DIVIDER,
            ]
        );
        $this->add_control(
            'content-c',
            [
                'label' => esc_html__('Content Color', 'auxa-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .xb-careear .xb-item--title' => 'color: {{VALUE}}',
                ],
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'content_typography',
                'selector' => '{{WRAPPER}} .xb-careear .xb-item--title',
            ]
        );
        $this->add_control(
            'link_hr',
            [
                'type' => \Elementor\Controls_Manager::DIVIDER,
            ]
        );
        $this->add_control(
            'link-border-c',
            [
                'label' => esc_html__('Link Border Color', 'auxa-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .xb-careear .xb-item--link span svg path' => 'stroke: {{VALUE}}',
                ],
            ]
        );
        $this->add_control(
            'link-hover-c',
            [
                'label' => esc_html__('Link Hover BG Color', 'auxa-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .xb-careear .xb-item--link:hover svg path' => 'stroke: {{VALUE}}',
                    '{{WRAPPER}} .xb-careear .xb-item--link span span svg path' => 'fill: {{VALUE}}',
                ],
            ]
        );
        $this->end_controls_section();

    }


    protected function render()
    {
        $settings = $this->get_settings_for_display();
        $star = AUXA_DIR_URL . 'assets/img/star.svg';
        $arrow_up = AUXA_DIR_URL . 'assets/img/arrow-up.svg';
        $shape = AUXA_DIR_URL . 'assets/img/car_shape.png';
        ?>
        <div class="xb-careear style-two text-center">
            <div class="xb-item--shape">
                <svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 300 438" fill="none" preserveAspectRatio="none">
                    <path d="M0 52.1692C0 38.4305 8.75643 26.1562 21.8837 22.1032C118.596 -7.75683 181.216 -7.00738 277.87 22.1985C291.115 26.2009 300 38.5351 300 52.3721V386.607C300 400.624 290.879 413.077 277.399 416.922C181.234 444.35 118.711 444.541 22.5356 416.949C9.08653 413.09 0 400.652 0 386.661V52.1692Z" fill="#1D2026"/>
                </svg>
            </div>
            <div class="xb-item--line-shape">
                <img src="<?php echo esc_url($shape); ?>" alt="">
            </div>
            <div class="xb-item--holder">
                <?php if (!empty($settings['title'])): ?>
                    <p class="xb-item--content"><img src="<?php echo esc_url($star); ?>" alt=""><?php echo wp_kses($settings['title'], true); ?>
                    </p>
                <?php endif; ?>
                <?php if (!empty($settings['content'])): ?>
                    <h3 class="xb-item--title"><?php echo wp_kses($settings['content'], true); ?></h3>
                <?php endif; ?>
                <a href="<?php echo esc_url($settings['link']['url']); ?>" class="xb-item--link"><img src="<?php echo esc_url($arrow_up); ?>" alt=""><span><svg
                                xmlns="http://www.w3.org/2000/svg" viewBox="0 0 59 48" fill="none"
                                preserveAspectRatio="none">
                                    <path d="M5.02153 4.43458C5.96248 2.03868 8.31753 0.5 10.9116 0.5H49.3176C52.0998 0.5 54.5817 2.26162 55.3669 4.9041C59.4723 18.7196 59.1586 28.358 55.2626 42.8516C54.5201 45.6138 51.9784 47.5 49.101 47.5H10.777C8.24614 47.5 5.93564 46.0375 4.96528 43.7247C2.01951 36.7035 0.516219 30.7738 0.500131 24.6691C0.484037 18.5621 1.95611 12.24 5.02153 4.43458Z"
                                          stroke="#1D2026"/>
                                  </svg><span><svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 59 48" fill="none"
                                                   preserveAspectRatio="none">
                                    <path d="M10.9116 0.5H49.3176C52.0998 0.5 54.5817 2.26162 55.3669 4.9041C59.4723 18.7196 59.1586 28.358 55.2626 42.8516C54.5201 45.6138 51.9784 47.5 49.101 47.5H10.777C8.24614 47.5 5.93564 46.0375 4.96528 43.7247C2.01951 36.7035 0.516219 30.7738 0.500131 24.6691C0.484037 18.5621 1.95611 12.24 5.02153 4.43458C5.96248 2.03868 8.31753 0.5 10.9116 0.5Z"
                                          fill="#C4EF17" stroke="#C4EF17"/>
                                  </svg></span></span></a>
            </div>
        </div>
        <?php
    }

}


Plugin::instance()->widgets_manager->register(new Auxa_Career_CTA());