<?php

/**
 * Elementor Single Widget
 * @package auxa-core
 * @since 1.0.0
 */

namespace Elementor;

if (!defined('ABSPATH')) exit; // Exit if accessed directly.

class Auxa_Career extends Widget_Base
{

    /**
     * Get widget name.
     *
     * Retrieve Elementor widget name.
     *
     * @return string Widget name.
     * @since 1.0.0
     * @access public
     *
     */
    public function get_name()
    {
        return 'int-career';
    }

    /**
     * Get widget title.
     *
     * Retrieve Elementor widget title.
     *
     * @return string Widget title.
     * @since 1.0.0
     * @access public
     *
     */
    public function get_title()
    {
        return esc_html__('Career', 'auxa-core');
    }

    /**
     * Get widget icon.
     *
     * Retrieve Elementor widget icon.
     *
     * @return string Widget icon.
     * @since 1.0.0
     * @access public
     *
     */
    public function get_icon()
    {
        return 'auxa-custom-icon';
    }

    /**
     * Get widget categories.
     *
     * Retrieve the list of categories the Elementor widget belongs to.
     *
     * @return array Widget categories.
     * @since 1.0.0
     * @access public
     *
     */
    public function get_categories()
    {
        return ['auxa_widgets'];
    }


    protected function register_controls()
    {

        $this->start_controls_section(
            'content_option',
            [
                'label' => esc_html__('Content', 'auxa-core'),
                'tab' => Controls_Manager::TAB_CONTENT,
            ]
        );
        $repeater = new \Elementor\Repeater();

        $repeater->add_control(
            'template',
            [
                'type' => Controls_Manager::SELECT2,
                'options' => $this->template_select(),
                'multiple' => false,
                'label' => esc_html__('Team', 'auxa-core'),
                'label_block' => true,
            ]
        );

        $this->add_control(
            'lists',
            [
                'type' => Controls_Manager::REPEATER,
                'fields' => $repeater->get_controls(),
                'prevent_empty' => false,
            ]
        );

        $this->end_controls_section();


        $this->start_controls_section(
            'color_option',
            [
                'label' => esc_html__('Style', 'auxa-core'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );
        $this->add_control(
            'padding',
            [
                'label' => esc_html__('Padding', 'auxa-core'),
                'type' => \Elementor\Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em', 'rem', 'custom'],
                'selectors' => [
                    '{{WRAPPER}} .xb-career' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );
        $this->add_control(
            'border_c',
            [
                'label' => esc_html__('Border Color', 'auxa-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .xb-career' => 'border-color: {{VALUE}}',
                ],
            ]
        );
        $this->add_control(
            'title_hr',
            [
                'type' => \Elementor\Controls_Manager::DIVIDER,
            ]
        );
        $this->add_control(
            'title-c',
            [
                'label' => esc_html__('Title Color', 'auxa-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .xb-career .xb-item--title' => 'color: {{VALUE}}',
                ],
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'title_typography',
                'selector' => '{{WRAPPER}} .xb-career .xb-item--title',
            ]
        );
        $this->add_control(
            'price_hr',
            [
                'type' => \Elementor\Controls_Manager::DIVIDER,
            ]
        );
        $this->add_control(
            'price-c',
            [
                'label' => esc_html__('Price Color', 'auxa-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .xb-career .xb-item--price' => 'color: {{VALUE}}',
                ],
            ]
        );
        $this->add_control(
            'price-text-c',
            [
                'label' => esc_html__('Price Text Color', 'auxa-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .xb-career .xb-item--price span' => 'color: {{VALUE}}',
                ],
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'price_typography',
                'selector' => '{{WRAPPER}} .xb-career .xb-item--price',
            ]
        );
        $this->add_control(
            'location_text_hr',
            [
                'type' => \Elementor\Controls_Manager::DIVIDER,
            ]
        );
        $this->add_control(
            'location_text_c',
            [
                'label' => esc_html__('Location Title Color', 'auxa-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .xb-career .xb-item--location' => 'color: {{VALUE}}',
                ],
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'location_text_typography',
                'selector' => '{{WRAPPER}} .xb-career .xb-item--location',
            ]
        );
        $this->add_control(
            'location_hr',
            [
                'type' => \Elementor\Controls_Manager::DIVIDER,
            ]
        );
        $this->add_control(
            'location_c',
            [
                'label' => esc_html__('Location Color', 'auxa-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .xb-career .xb-item--holder p' => 'color: {{VALUE}}',
                ],
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'location_typography',
                'selector' => '{{WRAPPER}} .xb-career .xb-item--holder p',
            ]
        );
        $this->end_controls_section();

    }


    protected function render()
    {
        $settings = $this->get_settings_for_display();

        // Check if 'lists' is not empty
        if (!empty($settings['lists'])) {
            echo '<div class="xb-career-inner">';

            foreach ($settings['lists'] as $a) {
                // Check if 'template' key is set in the array and is not empty
                if (isset($a['template']) && !empty($a['template'])) {
                    $career_post = get_post($a['template']);

                    // Check if $career_post is not empty and is a valid post object
                    if ($career_post instanceof \WP_Post) {
                        $career_title = esc_html($career_post->post_title);
                        $career_permalink = esc_url(get_permalink($career_post));

                        // Use $career_post->ID instead of get_the_ID()
                        $idd = $career_post->ID;

                        if (get_post_meta($idd, 'auxa_career_meta', true)) {
                            $career_meta = get_post_meta($idd, 'auxa_career_meta', true);
                        } else {
                            $career_meta = array();
                        }
                        if (array_key_exists('career_price', $career_meta)) {
                            $career_price = $career_meta['career_price'];
                        } else {
                            $career_price = '';
                        }
                        if (array_key_exists('career_location', $career_meta)) {
                            $career_location = $career_meta['career_location'];
                        } else {
                            $career_location = '';
                        }
                        ?>
                        <div class="xb-career ul_li_between">
                            <h3 class="xb-item--title"><a href="<?php echo $career_permalink; ?>"><?php echo $career_title; ?></a></h3>
                            <div class="xb-item--content ul_li">
                                <span class="xb-item--price"><?php echo esc_html($career_price['price']); ?> <span><?php echo esc_html($career_price['hour']); ?></span></span>
                                <div class="xb-item--holder">
                                    <h4 class="xb-item--location"><?php echo esc_html($career_location['location_title']); ?></h4>
                                    <p><?php echo esc_html($career_location['location']); ?></p>
                                </div>
                            </div>
                        </div>
                        <?php
                    }
                }
            }
            echo '</div>';
        }
    }


    protected function template_select()
    {
        $type = 'auxa_career';
        global $post;
        $args = array('numberposts' => -1, 'post_type' => $type,);
        $posts = get_posts($args);
        $categories = array(
            '' => __('Select', 'auxa-core'),
        );
        foreach ($posts as $pn_cat) {
            $categories[$pn_cat->ID] = get_the_title($pn_cat->ID);
        }
        return $categories;
    }

    protected function render_template($id)
    {
        return Plugin::instance()->frontend->get_builder_content_for_display($id);
    }

}


Plugin::instance()->widgets_manager->register(new Auxa_Career());