<?php

/**
 * Elementor Single Widget
 * @package auxa-core
 * @since 1.0.0
 */

namespace Elementor;

if (!defined('ABSPATH')) exit; // Exit if accessed directly.

class Auxa_Counter_V2 extends Widget_Base
{

    /**
     * Get widget name.
     *
     * Retrieve Elementor widget name.
     *
     * @return string Widget name.
     * @since 1.0.0
     * @access public
     *
     */
    public function get_name()
    {
        return 'int-counter-v2';
    }

    /**
     * Get widget title.
     *
     * Retrieve Elementor widget title.
     *
     * @return string Widget title.
     * @since 1.0.0
     * @access public
     *
     */
    public function get_title()
    {
        return esc_html__('Counter V2', 'auxa-core');
    }

    /**
     * Get widget icon.
     *
     * Retrieve Elementor widget icon.
     *
     * @return string Widget icon.
     * @since 1.0.0
     * @access public
     *
     */
    public function get_icon()
    {
        return 'auxa-custom-icon';
    }

    /**
     * Get widget categories.
     *
     * Retrieve the list of categories the Elementor widget belongs to.
     *
     * @return array Widget categories.
     * @since 1.0.0
     * @access public
     *
     */
    public function get_categories()
    {
        return ['auxa_widgets'];
    }

    protected function register_controls()
    {

        $this->start_controls_section(
            'content_option',
            [
                'label' => esc_html__('Content', 'auxa-core'),
                'tab' => Controls_Manager::TAB_CONTENT,
            ]
        );

        $repeater = new \Elementor\Repeater();

        $repeater->add_control(
            'number',
            [
                'type' => Controls_Manager::TEXT,
                'label' => esc_html__('Number', 'auxa-core'),
                'label_block' => true,
            ]
        );
        $repeater->add_control(
            'suffix',
            [
                'type' => Controls_Manager::TEXT,
                'label' => esc_html__('Suffix', 'auxa-core'),
                'label_block' => true,
            ]
        );
        $repeater->add_control(
            'title',
            [
                'type' => Controls_Manager::TEXT,
                'label' => esc_html__('Title', 'auxa-core'),
                'label_block' => true,
            ]
        );
        $repeater->add_control(
            'image',
            [
                'label' => esc_html__('Image', 'auxa-core'),
                'type' => \Elementor\Controls_Manager::MEDIA,
            ]
        );
        $this->add_control(
            'lists',
            [
                'type' => Controls_Manager::REPEATER,
                'fields' => $repeater->get_controls(),
                'title_field' => '{{{ title }}}',
            ]
        );

        $this->end_controls_section();


        $this->start_controls_section(
            'color_option',
            [
                'label' => esc_html__('Style', 'auxa-core'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );
        $this->add_control(
            'bg-c',
            [
                'label' => esc_html__('Background Color', 'auxa-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .xb-svg svg path' => 'fill: {{VALUE}}',
                ],
            ]
        );
        $this->add_control(
            'padding',
            [
                'label' => esc_html__('Padding', 'auxa-core'),
                'type' => \Elementor\Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em', 'rem', 'custom'],
                'selectors' => [
                    '{{WRAPPER}} .xb-counter' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );
        $this->add_control(
            'number_hr',
            [
                'type' => \Elementor\Controls_Manager::DIVIDER,
            ]
        );
        $this->add_control(
            'number-c',
            [
                'label' => esc_html__('Number Color', 'auxa-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .xb-counter .xb-item--count' => 'color: {{VALUE}}',
                ],
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'number_typography',
                'selector' => '{{WRAPPER}} .xb-counter .xb-item--count',
            ]
        );

        $this->add_control(
            'title_hr',
            [
                'type' => \Elementor\Controls_Manager::DIVIDER,
            ]
        );
        $this->add_control(
            'title-c',
            [
                'label' => esc_html__('Title Color', 'auxa-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .xb-counter .xb-item--content' => 'color: {{VALUE}}',
                ],
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'title_typography',
                'selector' => '{{WRAPPER}} .xb-counter .xb-item--content',
            ]
        );

        $this->end_controls_section();

    }


    protected function render()
    {
        $settings = $this->get_settings_for_display();
        ?>

        <div class="row mt-none-30 justify-content-center">
            <?php
            foreach ($settings['lists'] as $index => $list):
                $cnt_bg_id = 'cnt_bg_' . $index;
                ?>
                <div class="col-lg-4 col-md-6 mt-30">
                    <div class="xb-counter text-center pos-rel wow fadeInUp" data-wow-duration=".7s"  data-wow-delay="<?php echo esc_attr($index * 2); ?>00ms">
                        <div class="xb-item--shape xb-svg">
                            <svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 410 395" fill="none"
                                 preserveAspectRatio="none">
                                <path d="M0.5 51.7485C0.5 36.7596 11.0946 23.813 25.8125 21.0053C163.686 -5.2961 250.204 -7.23222 384.81 20.6521C399.241 23.6417 409.5 36.4574 409.5 51.2039V342.538C409.5 357.467 398.962 370.387 384.312 373.233C231.59 402.904 147.03 399.414 25.0986 373.569C10.7029 370.518 0.5 357.724 0.5 343V51.7485Z"
                                      fill="#16171B" stroke="url(#<?php echo esc_attr($cnt_bg_id); ?>)"/>
                                <defs>
                                    <linearGradient id="<?php echo esc_attr($cnt_bg_id); ?>" x1="0" y1="192.83"
                                                    x2="450.976" y2="192.83" gradientUnits="userSpaceOnUse">
                                        <stop offset="0" stop-color="white" stop-opacity="0.12"/>
                                        <stop offset="0.528433" stop-color="#010314" stop-opacity="0"/>
                                        <stop offset="1" stop-color="white" stop-opacity="0.12"/>
                                    </linearGradient>
                                </defs>
                            </svg>
                        </div>
                        <div class="xb-item--holder">
                            <h3 class="xb-item--count xb-odm"><span
                                        class="suffix"><?php echo esc_html($list['suffix']); ?></span><span class="xbo"
                                                                                                            data-count="<?php echo esc_attr($list['number']); ?>">00</span>
                            </h3>
                            <p class="xb-item--content"><?php echo esc_html($list['title']); ?></p>
                            <?php if (!empty($list['image']['id'])): ?>
                                <div class="xb-item--image">
                                    <?php echo wp_get_attachment_image($list['image']['id'], 'full'); ?>
                                </div>
                            <?php endif; ?>
                        </div>
                    </div>
                </div>
            <?php endforeach; ?>
        </div>
        <?php
    }

}


Plugin::instance()->widgets_manager->register(new Auxa_Counter_V2());