<?php

/**
 * Elementor Single Widget
 * @package auxa-core
 * @since 1.0.0
 */

namespace Elementor;

if (!defined('ABSPATH')) exit; // Exit if accessed directly.

class Auxa_Hero_one extends Widget_Base
{

    /**
     * Get widget name.
     *
     * Retrieve Elementor widget name.
     *
     * @return string Widget name.
     * @since 1.0.0
     * @access public
     *
     */
    public function get_name()
    {
        return 'int-hero-one';
    }

    /**
     * Get widget title.
     *
     * Retrieve Elementor widget title.
     *
     * @return string Widget title.
     * @since 1.0.0
     * @access public
     *
     */
    public function get_title()
    {
        return esc_html__('Hero One', 'auxa-core');
    }

    /**
     * Get widget icon.
     *
     * Retrieve Elementor widget icon.
     *
     * @return string Widget icon.
     * @since 1.0.0
     * @access public
     *
     */
    public function get_icon()
    {
        return 'auxa-custom-icon';
    }

    /**
     * Get widget categories.
     *
     * Retrieve the list of categories the Elementor widget belongs to.
     *
     * @return array Widget categories.
     * @since 1.0.0
     * @access public
     *
     */
    public function get_categories()
    {
        return ['auxa_widgets'];
    }


    protected function register_controls()
    {

        $this->start_controls_section(
            'Section-Content',
            [
                'label' => esc_html__('Section Content', 'textdomain'),
                'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
            ]
        );
        $this->add_control(
            'hero_main_img',
            [
                'label' => esc_html__( 'Hero Main Image', 'textdomain' ),
                'type' => \Elementor\Controls_Manager::MEDIA,
            ]
        );
        $this->add_control(
            'hero_left_img',
            [
                'label' => esc_html__( 'Hero Left Image', 'textdomain' ),
                'type' => \Elementor\Controls_Manager::MEDIA,
            ]
        );
        $this->add_control(
            'heading',
            [
                'label' => esc_html__('Hero heading', 'textdomain'),
                'type' => \Elementor\Controls_Manager::WYSIWYG,
                'default' => __('Take Your <br> <span class="sp-two">Online</span> <span class="sp-one">Journey</span>', 'textdomain'),
                'placeholder' => esc_html__('Type your heading here', 'textdomain'),
            ]
        );
        $this->add_control(
            'item_icon',
            [
                'label' => esc_html__( 'Item Icon', 'textdomain' ),
                'type' => \Elementor\Controls_Manager::ICONS,
                'default' => [
                    'value' => 'fas fa-circle',
                    'library' => 'fa-solid',
                ],
            ]
        );
        $this->add_control(
            'item_text',
            [
                'label' => esc_html__( 'Item Text', 'textdomain' ),
                'type' => \Elementor\Controls_Manager::TEXTAREA,
                'rows' => 10,
                'default' => __( 'Over 200 specialist Marketer. <br> 14 offices worldwide. <br> Landmark cases for the world’s largest firms.', 'textdomain' ),
                'placeholder' => esc_html__( 'Type your item description here', 'textdomain' ),
            ]
        );
        $this->add_control(
            'button_text',
            [
                'label' => esc_html__('Button Text', 'textdomain'),
                'type' => \Elementor\Controls_Manager::TEXT,
                'default' => __('Show <br> PROJECTS', 'textdomain'),
                'placeholder' => esc_html__('Type your button title here', 'textdomain'),
                'label_block' => true,
            ]
        );
        $this->add_control(
            'button_link',
            [
                'label' => esc_html__('Button Link', 'textdomain'),
                'type' => \Elementor\Controls_Manager::URL,
                'options' => ['url', 'is_external', 'nofollow'],
                'default' => [
                    'url' => '#',
                    'is_external' => false,
                    'nofollow' => true,
                    // 'custom_attributes' => '',
                ],
                'label_block' => true,
            ]
        );
        $this->add_control(
            'hero_bottom_img',
            [
                'label' => esc_html__('Hero Bottom Image', 'textdomain'),
                'type' => \Elementor\Controls_Manager::MEDIA,
            ]
        );
        $this->end_controls_section();
        $this->start_controls_section(
            'Heading-Style',
            [
                'label' => esc_html__('Heading Style', 'textdomain'),
                'tab' => \Elementor\Controls_Manager::TAB_STYLE,
            ]
        );
        $this->add_control(
            'Heading-color',
            [
                'label' => esc_html__('Heading Color', 'textdomain'),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .xb-item--title' => 'color: {{VALUE}}',
                ],
            ]
        );

        $this->add_group_control(
            \Elementor\Group_Control_Typography::get_type(),
            [
                'name' => 'Heading-typography',
                'label' => esc_html__('Heading typography', 'textdomain'),
                'selector' => '{{WRAPPER}} .xb-item--title',
            ]
        );
        $this->add_control(
            'List-Item-options',
            [
                'label' => esc_html__( 'List Item Options', 'textdomain' ),
                'type' => \Elementor\Controls_Manager::HEADING,
                'separator' => 'before',
            ]
        );
        $this->add_control(
            'List-Before-Icon-color',
            [
                'label' => esc_html__('List Before Icon Color', 'textdomain'),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .xb-item--dm-icon i' => 'color: {{VALUE}}',
                    '{{WRAPPER}} .xb-item--dm-icon path' => 'fill: {{VALUE}}',
                ],
            ]
        );
        $this->add_control(
            'List-Text-color',
            [
                'label' => esc_html__('List Text Color', 'textdomain'),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .dm-hero-content .xb-item--content' => 'color: {{VALUE}}',
                ],
            ]
        );

        $this->add_group_control(
            \Elementor\Group_Control_Typography::get_type(),
            [
                'name' => 'List-Text-typography',
                'label' => esc_html__('List Text typography', 'textdomain'),
                'selector' => '{{WRAPPER}} .dm-hero-content .xb-item--content',
            ]
        );
        $this->end_controls_section();
        $this->start_controls_section(
            'Button-Style',
            [
                'label' => esc_html__('Button Style', 'textdomain'),
                'tab' => \Elementor\Controls_Manager::TAB_STYLE,
            ]
        );
        $this->start_controls_tabs(
            'style_tabs'
        );

        $this->start_controls_tab(
            'style_normal_tab',
            [
                'label' => esc_html__('Normal', 'textdomain'),
            ]
        );
        $this->add_control(
            'Button-color',
            [
                'label' => esc_html__('Button Color', 'textdomain'),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .port-btn' => 'color: {{VALUE}}',
                ],
            ]
        );

        $this->add_group_control(
            \Elementor\Group_Control_Typography::get_type(),
            [
                'name' => 'Button-typography',
                'label' => esc_html__('Button typography', 'textdomain'),
                'selector' => '{{WRAPPER}} .port-btn',
            ]
        );
        $this->add_control(
            'Button-BG-color',
            [
                'label' => esc_html__('Button BG Color', 'textdomain'),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .dm-btn .button__bg' => 'background-color: {{VALUE}}',
                ],
            ]
        );
        $this->end_controls_tab();
        $this->start_controls_tab(
            'style_hover_tab',
            [
                'label' => esc_html__('Hover', 'textdomain'),
            ]
        );

        $this->add_control(
            'Button-Hover-color',
            [
                'label' => esc_html__('Button Hover Color', 'textdomain'),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .port-btn:hover' => 'color: {{VALUE}}',
                ],
            ]
        );
        $this->add_control(
            'Button-Hover-BG-color',
            [
                'label' => esc_html__('Button Hover BG Color', 'textdomain'),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .circle-btn .button__bg::before, {{WRAPPER}} .circle-btn .button__bg::after' => 'background-color: {{VALUE}}',
                ],
            ]
        );

        $this->end_controls_tab();
        $this->end_controls_tabs();
        $this->end_controls_section();


    }


    protected function render()
    {
        $settings = $this->get_settings_for_display();
        ?>
        <!-- hero section start  -->
        <section class="hero-digital-marketing pos-rel">
            <?php if (!empty($settings['hero_main_img']['url'])) { ?>
                <div class="dm-hero-img wow skewIn" data-wow-delay="250ms">
                    <img src="<?php echo $settings['hero_main_img']['url']; ?>" alt="">
                </div>
            <?php } ?>
            <div class="container">
                <div class="dm-hero-content pos-rel">
                    <?php if ($settings['hero_left_img']['url']){ ?>
                    <div class="xb-item--dm-image wow skewIn" data-wow-duration=".7s">
                        <img src="<?php echo $settings['hero_left_img']['url']; ?>" alt="">
                    </div>
                    <?php } ?>
                    <?php if ($settings['heading']){ ?>
                    <h1 class="xb-item--title wow fadeInUp">
                        <?php echo $settings['heading']; ?>
                    </h1>
                    <?php } ?>
                    <div class="hero-inner ul_li_between mt-40">
                        <div class="xb-item--holder mt-20 wow fadeInUp" data-wow-delay="350ms" data-wow-duration=".7s">
                            <?php if ($settings['item_icon']){ ?>
                            <div class="xb-item--dm-icon">
                                <?php \Elementor\Icons_Manager::render_icon( $settings['item_icon'], [ 'aria-hidden' => 'true' ] ); ?>
                            </div>
                            <?php } ?>
                            <?php if ($settings['item_text']){ ?>
                            <p class="xb-item--content">
                                <?php echo $settings['item_text']; ?>
                            </p>
                            <?php } ?>
                        </div>
                        <?php if ($settings['button_text']){ ?>
                        <div class="dm-button xb-element-parallax mt-20">
                            <a href="<?php echo $settings['button_link']['url']; ?>" class="circle-btn port-btn dm-btn wow fadeInUp"
                               data-wow-delay="450ms" data-wow-duration=".7s" target="<?php if ($settings['button_link']['is_external']) echo '_blank' ; ?>">
                                <div class="button__bg"></div>
                                <?php echo $settings['button_text']; ?>
                            </a>
                        </div>
                        <?php } ?>
                        <div class="dm-img mt-20 wow skewIn" data-wow-delay="250ms">
                            <img src="<?php echo $settings['hero_bottom_img']['url']; ?>" alt="">
                        </div>
                    </div>
                </div>
            </div>
        </section>
        <!-- hero section end  -->
        <?php
    }

}


Plugin::instance()->widgets_manager->register(new Auxa_Hero_one());