<?php

/**
 * Elementor Single Widget
 * @package auxa-core
 * @since 1.0.0
 */

namespace Elementor;

if (!defined('ABSPATH')) exit; // Exit if accessed directly.

class Auxa_Hero_Three extends Widget_Base
{

    /**
     * Get widget name.
     *
     * Retrieve Elementor widget name.
     *
     * @return string Widget name.
     * @since 1.0.0
     * @access public
     *
     */
    public function get_name()
    {
        return 'int-hero-three';
    }

    /**
     * Get widget title.
     *
     * Retrieve Elementor widget title.
     *
     * @return string Widget title.
     * @since 1.0.0
     * @access public
     *
     */
    public function get_title()
    {
        return esc_html__('Hero Three', 'auxa-core');
    }

    /**
     * Get widget icon.
     *
     * Retrieve Elementor widget icon.
     *
     * @return string Widget icon.
     * @since 1.0.0
     * @access public
     *
     */
    public function get_icon()
    {
        return 'auxa-custom-icon';
    }

    /**
     * Get widget categories.
     *
     * Retrieve the list of categories the Elementor widget belongs to.
     *
     * @return array Widget categories.
     * @since 1.0.0
     * @access public
     *
     */
    public function get_categories()
    {
        return ['auxa_widgets'];
    }


    protected function register_controls()
    {

        $this->start_controls_section(
            'hero_content_option',
            [
                'label' => esc_html__('Content', 'auxa-core'),
                'tab' => Controls_Manager::TAB_CONTENT,
            ]
        );
        $this->add_control(
            'header_title',
            [
                'type' => Controls_Manager::TEXT,
                'label' => esc_html__('Header Title', 'purefit-core'),
                'label_block' => true,
            ]
        );
        $this->start_controls_tabs(
            'style_tabs'
        );

        $this->start_controls_tab(
            'style_normal_tab',
            [
                'label' => esc_html__('Tab 1', 'purefit-core'),
            ]
        );

        $this->add_control(
            'title',
            [
                'type' => Controls_Manager::TEXT,
                'label' => esc_html__('Title', 'auxa-core'),
                'label_block' => true,
            ]
        );
        $this->add_control(
            'subtitle',
            [
                'type' => Controls_Manager::TEXT,
                'label' => esc_html__('Sub Title', 'auxa-core'),
                'label_block' => true,
            ]
        );
        $this->add_control(
            'image1',
            [
                'label' => esc_html__('Image 1', 'ovix-core'),
                'type' => \Elementor\Controls_Manager::MEDIA,
            ]
        );
        $this->add_control(
            'image2',
            [
                'label' => esc_html__('Image 2', 'ovix-core'),
                'type' => \Elementor\Controls_Manager::MEDIA,
            ]
        );
        $this->add_control(
            'image3',
            [
                'label' => esc_html__('Image 3', 'ovix-core'),
                'type' => \Elementor\Controls_Manager::MEDIA,
            ]
        );
        $this->add_control(
            'image4',
            [
                'label' => esc_html__('Image 4', 'ovix-core'),
                'type' => \Elementor\Controls_Manager::MEDIA,
            ]
        );

        $this->end_controls_tab();

        $this->start_controls_tab(
            'style_hover_tab',
            [
                'label' => esc_html__('Tab 2', 'purefit-core'),
            ]
        );

        $this->add_control(
            'title2',
            [
                'type' => Controls_Manager::TEXT,
                'label' => esc_html__('Title', 'auxa-core'),
                'label_block' => true,
            ]
        );
        $this->add_control(
            'subtitle2',
            [
                'type' => Controls_Manager::TEXT,
                'label' => esc_html__('Sub Title', 'auxa-core'),
                'label_block' => true,
            ]
        );
        $this->add_control(
            'image11',
            [
                'label' => esc_html__('Image 1', 'ovix-core'),
                'type' => \Elementor\Controls_Manager::MEDIA,
            ]
        );
        $this->add_control(
            'image22',
            [
                'label' => esc_html__('Image 2', 'ovix-core'),
                'type' => \Elementor\Controls_Manager::MEDIA,
            ]
        );
        $this->add_control(
            'image33',
            [
                'label' => esc_html__('Image 3', 'ovix-core'),
                'type' => \Elementor\Controls_Manager::MEDIA,
            ]
        );
        $this->add_control(
            'image44',
            [
                'label' => esc_html__('Image 4', 'ovix-core'),
                'type' => \Elementor\Controls_Manager::MEDIA,
            ]
        );

        $this->end_controls_tab();

        $this->start_controls_tab(
            'style_3_tab',
            [
                'label' => esc_html__('Tab 3', 'purefit-core'),
            ]
        );

        $this->add_control(
            'title3',
            [
                'type' => Controls_Manager::TEXT,
                'label' => esc_html__('Title', 'auxa-core'),
                'label_block' => true,
            ]
        );
        $this->add_control(
            'subtitle3',
            [
                'type' => Controls_Manager::TEXT,
                'label' => esc_html__('Sub Title', 'auxa-core'),
                'label_block' => true,
            ]
        );
        $this->add_control(
            'image111',
            [
                'label' => esc_html__('Image 1', 'ovix-core'),
                'type' => \Elementor\Controls_Manager::MEDIA,
            ]
        );
        $this->add_control(
            'image222',
            [
                'label' => esc_html__('Image 2', 'ovix-core'),
                'type' => \Elementor\Controls_Manager::MEDIA,
            ]
        );
        $this->add_control(
            'image333',
            [
                'label' => esc_html__('Image 3', 'ovix-core'),
                'type' => \Elementor\Controls_Manager::MEDIA,
            ]
        );
        $this->add_control(
            'image444',
            [
                'label' => esc_html__('Image 4', 'ovix-core'),
                'type' => \Elementor\Controls_Manager::MEDIA,
            ]
        );

        $this->end_controls_tab();

        $this->end_controls_tabs();
        $this->end_controls_section();

        $this->start_controls_section(
            'content_style',
            [
                'label' => esc_html__('Style', 'auxa-core'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );
        $this->add_control(
            'h_title-c',
            [
                'label' => esc_html__('Header Title Color', 'auxa-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .sd-sub_title' => 'color: {{VALUE}}',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'h_title_typography',
                'selector' => '{{WRAPPER}} .sd-sub_title',
            ]
        );
        $this->add_control(
            'content_style',
            [
                'label' => esc_html__('Content Style', 'purefit-core'),
                'type' => \Elementor\Controls_Manager::HEADING,
                'separator' => 'before',
            ]
        );
        $this->add_control(
            'border_c',
            [
                'label' => esc_html__('Border Color', 'ovix-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .xbh-header__inner' => 'border-color: {{VALUE}}',
                    '{{WRAPPER}} .xbh__border-wrap .xbh-col' => 'border-color: {{VALUE}}',
                    '{{WRAPPER}} .xbh__border-wrap .xbh-col::before' => 'border-color: {{VALUE}}',
                ],
            ]
        );
        $this->add_control(
            'title_hr',
            [
                'type' => \Elementor\Controls_Manager::DIVIDER,
            ]
        );
        $this->add_control(
            'title-c',
            [
                'label' => esc_html__('Title Color', 'auxa-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .xbh__border-wrap .xbh-h1' => 'color: {{VALUE}}',
                ],
            ]
        );
        $this->add_control(
            'htitle-c',
            [
                'label' => esc_html__('Title Hover Color', 'auxa-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .xbh__border-wrap .xbh-col:hover .xbh-h1' => 'color: {{VALUE}}',
                ],
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'title_typography',
                'selector' => '{{WRAPPER}} .xbh__border-wrap .xbh-h1',
            ]
        );
        $this->add_control(
            'subtitle_hr',
            [
                'type' => \Elementor\Controls_Manager::DIVIDER,
            ]
        );
        $this->add_control(
            'subtitle-c',
            [
                'label' => esc_html__('Sub Title Color', 'auxa-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .xbh-blurb-inner p' => 'color: {{VALUE}}',
                ],
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'subtitle_typography',
                'selector' => '{{WRAPPER}} .xbh-blurb-inner p',
            ]
        );

        $this->end_controls_section();

    }

    protected function render()
    {
        $settings = $this->get_settings_for_display();
        ?>
        <section class="hero pos-rel pt-80 pb-130">
            <?php if (!empty($settings['header_title'])): ?>
                <div class="container">
                    <samp class="sd-sub_title text-center"><?php echo esc_html($settings['header_title']); ?></samp>
                </div>
            <?php endif; ?>
            <div class="xbh-header__inner">
                <div class="xbh__image-wrap one" data-xbh-hero-images1="<?php echo esc_attr($settings['title']); ?>">
                    <div class="xbh-image">
                        <div class="ratio__75"><?php echo wp_get_attachment_image($settings['image1']['id'], 'full'); ?></div>
                    </div>
                    <div class="xbh-image is--02">
                        <div class="ratio__75"><?php echo wp_get_attachment_image($settings['image2']['id'], 'full'); ?></div>
                    </div>
                    <div class="xbh-image is--03">
                        <div class="ratio__150"><?php echo wp_get_attachment_image($settings['image3']['id'], 'full'); ?></div>
                    </div>
                    <div class="xbh-image is--04">
                        <div class="ratio__100"><?php echo wp_get_attachment_image($settings['image4']['id'], 'full'); ?></div>
                    </div>
                </div>
                <div class="xbh__image-wrap two" data-xbh-hero-images2="<?php echo esc_attr($settings['title2']); ?>">
                    <div class="xbh-image">
                        <div class="ratio__75"><?php echo wp_get_attachment_image($settings['image11']['id'], 'full'); ?></div>
                    </div>
                    <div class="xbh-image is--02">
                        <div class="ratio__75"><?php echo wp_get_attachment_image($settings['image22']['id'], 'full'); ?></div>
                    </div>
                    <div class="xbh-image is--03">
                        <div class="ratio__150"><?php echo wp_get_attachment_image($settings['image33']['id'], 'full'); ?></div>
                    </div>
                    <div class="xbh-image is--04">
                        <div class="ratio__100"><?php echo wp_get_attachment_image($settings['image44']['id'], 'full'); ?></div>
                    </div>
                </div>
                <div class="xbh__image-wrap three" data-xbh-hero-images3="<?php echo esc_attr($settings['title3']); ?>">
                    <div class="xbh-image">
                        <div class="ratio__75"><?php echo wp_get_attachment_image($settings['image111']['id'], 'full'); ?></div>
                    </div>
                    <div class="xbh-image is--02">
                        <div class="ratio__75"><?php echo wp_get_attachment_image($settings['image222']['id'], 'full'); ?></div>
                    </div>
                    <div class="xbh-image is--03">
                        <div class="ratio__150"><?php echo wp_get_attachment_image($settings['image333']['id'], 'full'); ?></div>
                    </div>
                    <div class="xbh-image is--04">
                        <div class="ratio__100"><?php echo wp_get_attachment_image($settings['image444']['id'], 'full'); ?></div>
                    </div>
                </div>
                <div class="xbh__border is--first">
                    <div class="xbh__border-wrap">
                        <div data-xbh-trigger1="<?php echo esc_attr($settings['title']); ?>" class="xbh-col">
                            <div class="xbh-content">
                                <p class="xbh-h1"><?php echo esc_html($settings['title']); ?></p>
                                <div class="xbh-blurb">
                                    <div class="xbh-blurb-inner">
                                        <p><?php echo esc_html($settings['subtitle']); ?></p>
                                    </div>
                                </div>
                            </div>
                        </div>
                        <div data-xbh-trigger2="<?php echo esc_attr($settings['title2']); ?>" class="xbh-col">
                            <div class="xbh-content">
                                <p class="xbh-h1"><?php echo esc_html($settings['title2']); ?></p>
                                <div class="xbh-blurb">
                                    <div class="xbh-blurb-inner">
                                        <p><?php echo esc_html($settings['subtitle2']); ?></p>
                                    </div>
                                </div>
                            </div>
                        </div>
                        <div data-xbh-trigger3="<?php echo esc_attr($settings['title3']); ?>" class="xbh-col last-col">
                            <div class="xbh-content">
                                <p class="xbh-h1"><?php echo esc_html($settings['title3']); ?></p>
                                <div class="xbh-blurb">
                                    <div class="xbh-blurb-inner">
                                        <p><?php echo esc_html($settings['subtitle3']); ?></p>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        </section>
        <?php
    }
}


Plugin::instance()->widgets_manager->register(new Auxa_Hero_Three());