<?php

/**
 * Elementor Single Widget
 * @package auxa-core
 * @since 1.0.0
 */

namespace Elementor;

if (!defined('ABSPATH')) exit; // Exit if accessed directly.

class Auxa_Hero_Two extends Widget_Base
{

    /**
     * Get widget name.
     *
     * Retrieve Elementor widget name.
     *
     * @return string Widget name.
     * @since 1.0.0
     * @access public
     *
     */
    public function get_name()
    {
        return 'int-hero-two';
    }

    /**
     * Get widget title.
     *
     * Retrieve Elementor widget title.
     *
     * @return string Widget title.
     * @since 1.0.0
     * @access public
     *
     */
    public function get_title()
    {
        return esc_html__('Hero Two', 'auxa-core');
    }

    /**
     * Get widget icon.
     *
     * Retrieve Elementor widget icon.
     *
     * @return string Widget icon.
     * @since 1.0.0
     * @access public
     *
     */
    public function get_icon()
    {
        return 'auxa-custom-icon';
    }

    /**
     * Get widget categories.
     *
     * Retrieve the list of categories the Elementor widget belongs to.
     *
     * @return array Widget categories.
     * @since 1.0.0
     * @access public
     *
     */
    public function get_categories()
    {
        return ['auxa_widgets'];
    }


    protected function register_controls()
    {

        $this->start_controls_section(
            'hero_content_option',
            [
                'label' => esc_html__('Content', 'auxa-core'),
                'tab' => Controls_Manager::TAB_CONTENT,
            ]
        );
        $this->add_control(
            'heading',
            [
                'label' => esc_html__('Hero heading', 'textdomain'),
                'type' => \Elementor\Controls_Manager::WYSIWYG,
                'default' => __('Achieve <br> <span class="sp-one">More with</span> <span class="sp-two">Less Effort</span>', 'textdomain'),
                'placeholder' => esc_html__('Type your heading here', 'textdomain'),
            ]
        );
        $this->add_control(
            'item_icon',
            [
                'label' => esc_html__('Item Icon', 'textdomain'),
                'type' => \Elementor\Controls_Manager::ICONS,
                'default' => [
                    'value' => 'fas fa-circle',
                    'library' => 'fa-solid',
                ],
            ]
        );
        $this->add_control(
            'item_text',
            [
                'label' => esc_html__('Item Text', 'textdomain'),
                'type' => \Elementor\Controls_Manager::TEXTAREA,
                'rows' => 10,
                'default' => __('Over 200 specialist Marketer. <br> 14 offices worldwide. <br> Landmark cases for the world’s largest firms.', 'textdomain'),
                'placeholder' => esc_html__('Type your item description here', 'textdomain'),
            ]
        );
        $this->add_control(
            'btn_text',
            [
                'label' => esc_html__('Button Text', 'textdomain'),
                'type' => \Elementor\Controls_Manager::TEXT,
                'default' => __('Show <br> PROJECTS', 'textdomain'),
                'placeholder' => esc_html__('Type your button title here', 'textdomain'),
                'label_block' => true,
            ]
        );
        $this->add_control(
            'btn_link',
            [
                'label' => esc_html__('Button Link', 'textdomain'),
                'type' => \Elementor\Controls_Manager::URL,
                'options' => ['url', 'is_external', 'nofollow'],
                'default' => [
                    'url' => '#',
                    'is_external' => false,
                    'nofollow' => true,
                    // 'custom_attributes' => '',
                ],
                'label_block' => true,
            ]
        );
        $this->add_control(
            'btn_icon',
            [
                'label' => esc_html__('Icon', 'purefit-core'),
                'type' => \Elementor\Controls_Manager::ICONS,
            ]
        );
        $this->end_controls_section();

        $this->start_controls_section(
            'image_option',
            [
                'label' => esc_html__('Image', 'auxa-core'),
                'tab' => Controls_Manager::TAB_CONTENT,
            ]
        );
        $this->add_control(
            'image1',
            [
                'label' => esc_html__('Image One', 'ovix-core'),
                'type' => \Elementor\Controls_Manager::MEDIA,
            ]
        );
        $this->add_control(
            'image2',
            [
                'label' => esc_html__('Image Two', 'ovix-core'),
                'type' => \Elementor\Controls_Manager::MEDIA,
            ]
        );
        $this->add_control(
            'shape',
            [
                'label' => esc_html__('Shape', 'ovix-core'),
                'type' => \Elementor\Controls_Manager::MEDIA,
            ]
        );
        $this->end_controls_section();

        $this->start_controls_section(
            'Heading-Style',
            [
                'label' => esc_html__('Heading Style', 'textdomain'),
                'tab' => \Elementor\Controls_Manager::TAB_STYLE,
            ]
        );
        $this->add_control(
            'Heading-color',
            [
                'label' => esc_html__('Heading Color', 'textdomain'),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .branding-title .title' => 'color: {{VALUE}}',
                ],
            ]
        );

        $this->add_group_control(
            \Elementor\Group_Control_Typography::get_type(),
            [
                'name' => 'Heading-typography',
                'label' => esc_html__('Heading typography', 'textdomain'),
                'selector' => '{{WRAPPER}} .branding-title .title',
            ]
        );
        $this->end_controls_section();

        $this->start_controls_section(
            'Button-Style',
            [
                'label' => esc_html__('Button Style', 'textdomain'),
                'tab' => \Elementor\Controls_Manager::TAB_STYLE,
            ]
        );
        $this->start_controls_tabs(
            'style_tabs'
        );

        $this->start_controls_tab(
            'style_normal_tab',
            [
                'label' => esc_html__('Normal', 'textdomain'),
            ]
        );
        $this->add_control(
            'Button-color',
            [
                'label' => esc_html__('Button Color', 'textdomain'),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .port-btn' => 'color: {{VALUE}}',
                ],
            ]
        );

        $this->add_group_control(
            \Elementor\Group_Control_Typography::get_type(),
            [
                'name' => 'Button-typography',
                'label' => esc_html__('Button typography', 'textdomain'),
                'selector' => '{{WRAPPER}} .port-btn',
            ]
        );
        $this->add_control(
            'Button-BG-color',
            [
                'label' => esc_html__('Button BG Color', 'textdomain'),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .dm-btn .button__bg' => 'background-color: {{VALUE}}',
                ],
            ]
        );
        $this->end_controls_tab();
        $this->start_controls_tab(
            'style_hover_tab',
            [
                'label' => esc_html__('Hover', 'textdomain'),
            ]
        );

        $this->add_control(
            'Button-Hover-color',
            [
                'label' => esc_html__('Button Hover Color', 'textdomain'),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .port-btn:hover' => 'color: {{VALUE}}',
                ],
            ]
        );
        $this->add_control(
            'Button-Hover-BG-color',
            [
                'label' => esc_html__('Button Hover BG Color', 'textdomain'),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .circle-btn .button__bg::before, {{WRAPPER}} .circle-btn .button__bg::after' => 'background-color: {{VALUE}}',
                ],
            ]
        );

        $this->end_controls_tab();
        $this->end_controls_tabs();
        $this->end_controls_section();

        $this->start_controls_section(
            'content-Style',
            [
                'label' => esc_html__('Content', 'textdomain'),
                'tab' => \Elementor\Controls_Manager::TAB_STYLE,
            ]
        );
        $this->add_control(
            'b_content-c',
            [
                'label' => esc_html__('Content Color', 'purefit-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .branding-content .xb-item--content' => 'color: {{VALUE}}',
                ],
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'content_typography',
                'selector' => '{{WRAPPER}} .branding-content .xb-item--content',
            ]
        );

        $this->end_controls_section();


    }


    protected function render()
    {
        $settings = $this->get_settings_for_display();
        ?>
        <section class="hero hero-three pt-130">
            <div class="container">
                <div class="row">
                    <div class="col-lg-5">
                        <div class="br-hero-content">
                            <?php if (!empty($settings['heading'])): ?>
                                <div class="branding-title mb-55 wow skewIn">
                                    <h1 class="title"><?php echo wp_kses($settings['heading'], true); ?></h1>
                                </div>
                            <?php endif; ?>
                            <?php if(!empty($settings['btn_text'])): ?>
                            <div class="br-button pos-rel">
                                <a href="<?php echo esc_url($settings['btn_link']['url']); ?>"
                                   class="circle-btn port-btn dm-btn xb-element-parallax wow fadeInUp"
                                   data-wow-delay="200ms" data-wow-duration=".7s">
                                    <div class="button__bg"></div><?php echo wp_kses($settings['btn_text'], true); ?>
                                </a>
                                <div class="br-hero-arrow">
                                    <div class="wow fadeInRight" data-wow-delay="400ms" data-wow-duration=".7s">
                                        <?php \Elementor\Icons_Manager::render_icon($settings['btn_icon'], ['aria-hidden' => 'true']); ?>
                                    </div>
                                </div>
                            </div>
                            <?php endif; ?>
                        </div>
                    </div>
                    <div class="col-lg-7">
                        <div class="branding-image pos-rel">
                            <div class="xb-item--left_img pos-rel wow fadeInUp" data-wow-delay="200ms"
                                 data-wow-duration=".7s">
                                <?php echo wp_get_attachment_image($settings['image1']['id'], 'full'); ?>
                            </div>
                            <div class="xb-item--right_img">
                                <img class="img1 wow fadeInUp" data-wow-delay="300ms" data-wow-duration=".7s"
                                     src="<?php echo esc_url($settings['image2']['url']); ?>" alt="">
                                <img class="img2 wow fadeInUp" data-wow-delay="300ms" data-wow-duration=".7s"
                                     src="<?php echo esc_url($settings['shape']['url']); ?>" alt="">
                            </div>
                        </div>
                    </div>
                </div>
                <div class="branding-content">
                    <div class="xb-item--dm-icon">
                        <?php \Elementor\Icons_Manager::render_icon($settings['item_icon'], ['aria-hidden' => 'true']); ?>
                    </div>

                        <p class="xb-item--content">
                            <?php echo wp_kses($settings['item_text'], true); ?>
                        </p>

                </div>
            </div>
        </section>
        <?php
    }
}


Plugin::instance()->widgets_manager->register(new Auxa_Hero_Two());