<?php

/**
 * Elementor Single Widget
 * @package auxa-core
 * @since 1.0.0
 */

namespace Elementor;

if (!defined('ABSPATH')) exit; // Exit if accessed directly.

class Auxa_Portfolio_V2 extends Widget_Base
{

    /**
     * Get widget name.
     *
     * Retrieve Elementor widget name.
     *
     * @return string Widget name.
     * @since 1.0.0
     * @access public
     *
     */
    public function get_name()
    {
        return 'int-portfolio-v2';
    }

    /**
     * Get widget title.
     *
     * Retrieve Elementor widget title.
     *
     * @return string Widget title.
     * @since 1.0.0
     * @access public
     *
     */
    public function get_title()
    {
        return esc_html__('Portfolio V2', 'auxa-core');
    }

    /**
     * Get widget icon.
     *
     * Retrieve Elementor widget icon.
     *
     * @return string Widget icon.
     * @since 1.0.0
     * @access public
     *
     */
    public function get_icon()
    {
        return 'auxa-custom-icon';
    }

    /**
     * Get widget categories.
     *
     * Retrieve the list of categories the Elementor widget belongs to.
     *
     * @return array Widget categories.
     * @since 1.0.0
     * @access public
     *
     */
    public function get_categories()
    {
        return ['auxa_widgets'];
    }


    protected function register_controls()
    {


        $this->start_controls_section(
            'portfolio_option',
            [
                'label' => esc_html__('Portfolio', 'auxa-core'),
                'tab' => Controls_Manager::TAB_CONTENT,
            ]
        );
        $repeater = new \Elementor\Repeater();

        $repeater->add_control(
            'template',
            [
                'type' => Controls_Manager::SELECT2,
                'options' => $this->template_select(),
                'multiple' => false,
                'label' => esc_html__('Portfolio', 'auxa-core'),
                'label_block' => true,
            ]
        );

        $this->add_control(
            'lists',
            [
                'type' => Controls_Manager::REPEATER,
                'fields' => $repeater->get_controls(),
                'prevent_empty' => false,
            ]
        );
        $this->add_control(
            'note_label',
            [
                'type' => Controls_Manager::RAW_HTML,
                'raw' => sprintf(
                    '<div class="elementor-panel-alert elementor-panel-alert-info">
                <p>%s</p>
            </div>',
                    sprintf(
                        __('Please note! Customize your selected Portfolio using Elementor. You can find it under <a href="%s" target="_blank">Portfolio</a>.', 'auxa-core'),
                        admin_url('edit.php?post_type=auxa_portfolio')
                    )
                ),
                'content_classes' => 'elementor-notice-container',
            ]
        );
        $this->end_controls_section();

        $this->start_controls_section(
            'style_option',
            [
                'label' => esc_html__('Style', 'auxa-core'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );
        $this->add_control(
            'border_c',
            [
                'label' => esc_html__('Hover Border Color', 'auxa-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .xb-portfolio:hover .xb-item--img' => 'outline-color: {{VALUE}}',
                ],
            ]
        );
        $this->add_control(
            'title_style_hr',
            [
                'type' => \Elementor\Controls_Manager::DIVIDER,
            ]
        );
        $this->add_control(
            'title-c',
            [
                'label' => esc_html__('Title Color', 'auxa-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .xb-portfolio .xb-item--title' => 'color: {{VALUE}}',
                ],
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'title_typography',
                'selector' => '{{WRAPPER}} .xb-portfolio .xb-item--title',
            ]
        );
        $this->end_controls_section();

    }

    protected function render()
    {
        $settings = $this->get_settings_for_display();

        if (!empty($settings['lists'])) {
            echo '<div class="portfolio-slider swiper-container">';
            echo '<div class="swiper-wrapper">';

            foreach ($settings['lists'] as $a) {
                if (isset($a['template']) && !empty($a['template'])) {
                    $portfolio_post = get_post($a['template']);

                    if ($portfolio_post instanceof \WP_Post) {
                        $portfolio_title = esc_html($portfolio_post->post_title);
                        $portfolio_permalink = esc_url(get_permalink($portfolio_post));
                        $featured_image_url = get_the_post_thumbnail_url($portfolio_post, 'auxa-portfolio-2');
                        ?>
                        <div class="swiper-slide xb-portfolio">
                            <div class="xb-item--img">
                                <a href="<?php echo $portfolio_permalink; ?>"> <img src="<?php echo esc_url($featured_image_url); ?>" alt=""></a>
                            </div>
                            <h3 class="xb-item--title border-effect-2"><a href="<?php echo $portfolio_permalink; ?>"><?php echo $portfolio_title; ?></a></h3>
                            <a class="xb-overlay" href="<?php echo $portfolio_permalink; ?>"></a>
                        </div>
                        <?php
                    }
                }
            }
            echo '</div>';
            echo '</div>';
        }
    }

    protected function template_select()
    {
        $type = 'auxa_portfolio';
        global $post;
        $args = array('numberposts' => -1, 'post_type' => $type,);
        $posts = get_posts($args);
        $categories = array(
            '' => __('Select', 'auxa-core'),
        );
        foreach ($posts as $pn_cat) {
            $categories[$pn_cat->ID] = get_the_title($pn_cat->ID);
        }
        return $categories;
    }

    protected function render_template($id)
    {
        return Plugin::instance()->frontend->get_builder_content_for_display($id);
    }

}


Plugin::instance()->widgets_manager->register(new Auxa_Portfolio_V2());