<?php

/**
 * Elementor Single Widget
 * @package auxa-core
 * @since 1.0.0
 */

namespace Elementor;

if (!defined('ABSPATH')) exit; // Exit if accessed directly.

class Auxa_Portfolio_V4 extends Widget_Base
{

    /**
     * Get widget name.
     *
     * Retrieve Elementor widget name.
     *
     * @return string Widget name.
     * @since 1.0.0
     * @access public
     *
     */
    public function get_name()
    {
        return 'int-portfolio-v4';
    }

    /**
     * Get widget title.
     *
     * Retrieve Elementor widget title.
     *
     * @return string Widget title.
     * @since 1.0.0
     * @access public
     *
     */
    public function get_title()
    {
        return esc_html__('Portfolio V4', 'auxa-core');
    }

    /**
     * Get widget icon.
     *
     * Retrieve Elementor widget icon.
     *
     * @return string Widget icon.
     * @since 1.0.0
     * @access public
     *
     */
    public function get_icon()
    {
        return 'auxa-custom-icon';
    }

    /**
     * Get widget categories.
     *
     * Retrieve the list of categories the Elementor widget belongs to.
     *
     * @return array Widget categories.
     * @since 1.0.0
     * @access public
     *
     */
    public function get_categories()
    {
        return ['auxa_widgets'];
    }


    protected function register_controls()
    {

        $this->start_controls_section(
            'portfolio_option',
            [
                'label' => esc_html__('Portfolio', 'auxa-core'),
                'tab' => Controls_Manager::TAB_CONTENT,
            ]
        );
        $repeater = new \Elementor\Repeater();

        $repeater->add_control(
            'template',
            [
                'type' => Controls_Manager::SELECT2,
                'options' => $this->template_select(),
                'multiple' => false,
                'label' => esc_html__('Portfolio', 'auxa-core'),
                'label_block' => true,
            ]
        );
        $repeater->add_control(
            'tags',
            [
                'type' => Controls_Manager::TEXTAREA,
                'label' => esc_html__('Tags', 'purefit-core'),
                'label_block' => true,
            ]
        );

        $this->add_control(
            'lists',
            [
                'type' => Controls_Manager::REPEATER,
                'fields' => $repeater->get_controls(),
                'prevent_empty' => false,
            ]
        );
        $this->add_control(
            'note_label',
            [
                'type' => Controls_Manager::RAW_HTML,
                'raw' => sprintf(
                    '<div class="elementor-panel-alert elementor-panel-alert-info">
                <p>%s</p>
            </div>',
                    sprintf(
                        __('Please note! Customize your selected Portfolio using Elementor. You can find it under <a href="%s" target="_blank">Portfolio</a>.', 'auxa-core'),
                        admin_url('edit.php?post_type=auxa_portfolio')
                    )
                ),
                'content_classes' => 'elementor-notice-container',
            ]
        );
        $this->end_controls_section();

        $this->start_controls_section(
            'style_option',
            [
                'label' => esc_html__('Style', 'auxa-core'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );
        $this->add_control(
            'filter-img',
            [
                'label' => esc_html__('Filter Image', 'auxa-core'),
                'type' => \Elementor\Controls_Manager::SLIDER,
                'size_units' => ['%'],
                'range' => [
                    '%' => [
                        'min' => 0,
                        'max' => 100,
                    ],
                ],
                'default' => [
                    'unit' => '%',
                    'size' => 100,
                ],
                'selectors' => [
                    '{{WRAPPER}} .br-portfolio .xb-item--img img' => 'filter: grayscale({{SIZE}}{{UNIT}});',
                ],
            ]
        );
        $this->add_control(
            'filter-hover-img',
            [
                'label' => esc_html__('Filter Hover Image', 'auxa-core'),
                'type' => \Elementor\Controls_Manager::SLIDER,
                'size_units' => ['%'],
                'range' => [
                    '%' => [
                        'min' => 0,
                        'max' => 100,
                    ],
                ],
                'default' => [
                    'unit' => '%',
                    'size' => 0,
                ],
                'selectors' => [
                    '{{WRAPPER}} .br-portfolio:hover .xb-item--img img' => 'filter: grayscale({{SIZE}}{{UNIT}});',
                ],
            ]
        );
        $this->add_control(
            'border_hr',
            [
                'type' => \Elementor\Controls_Manager::DIVIDER,
            ]
        );
        $this->add_control(
            'border_c',
            [
                'label' => esc_html__('Border Color', 'ovix-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .br-portfolio' => 'border-color: {{VALUE}}',
                    '{{WRAPPER}} .br-portfolio-inner::before' => 'background: {{VALUE}}',
                ],
            ]
        );
        $this->add_control(
            'title_hr',
            [
                'type' => \Elementor\Controls_Manager::DIVIDER,
            ]
        );
        $this->add_control(
            'title-c',
            [
                'label' => esc_html__('Title Color', 'auxa-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .br-portfolio .xb-item--name' => 'color: {{VALUE}}',
                ],
            ]
        );
        $this->add_control(
            'hover-title-c',
            [
                'label' => esc_html__('Title Hover Color', 'auxa-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .br-portfolio .xb-item--name:hover' => 'color: {{VALUE}}',
                ],
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'title_typography',
                'selector' => '{{WRAPPER}} .br-portfolio .xb-item--name',
            ]
        );
        $this->add_control(
            'tags_hr',
            [
                'type' => \Elementor\Controls_Manager::DIVIDER,
            ]
        );
        $this->add_control(
            'tag-c',
            [
                'label' => esc_html__('Tag Color', 'auxa-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .br-portfolio .xb-item--btn span' => 'color: {{VALUE}}',
                ],
            ]
        );
        $this->add_control(
            'tag-hover-c',
            [
                'label' => esc_html__('Tag Hover Color', 'auxa-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .br-portfolio .xb-item--btn span' => 'color: {{VALUE}}',
                ],
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'tag_typography',
                'selector' => '{{WRAPPER}} .br-portfolio .xb-item--btn span',
            ]
        );
        $this->end_controls_section();

    }

    protected function render()
    {
        $settings = $this->get_settings_for_display();

        if (!empty($settings['lists'])) {
            echo '<div class="br-portfolio-inner pos-rel">';
            echo '<div class="row g-50">';

            foreach ($settings['lists'] as $a) {
                if (isset($a['template']) && !empty($a['template'])) {
                    $portfolio_post = get_post($a['template']);

                    if ($portfolio_post instanceof \WP_Post) {
                        $portfolio_title = esc_html($portfolio_post->post_title);
                        $portfolio_permalink = esc_url(get_permalink($portfolio_post));
                        $featured_image_url = get_the_post_thumbnail_url($portfolio_post, 'auxa-portfolio-4');
                        ?>
                        <div class="col-lg-6 col-md-6 mt-30">
                            <div class="br-portfolio xb-hover-zoom pos-rel">
                                <div class="xb-item--img">
                                    <a href="<?php echo $portfolio_permalink; ?>"><img
                                                src="<?php echo esc_url($featured_image_url); ?>" alt=""></a>
                                </div>
                                <div class="xb-item--holder ul_li_between">
                                    <a class="xb-item--name mt-25"
                                       href="<?php echo $portfolio_permalink; ?>"><?php echo $portfolio_title; ?></a>

                                    <?php $features_list = $a['tags'];
                                    if (!empty($features_list)) {
                                        $features_list = explode("\n", ($features_list));
                                        ?>
                                        <div class="xb-item--btn mt-25">
                                            <?php foreach ($features_list as $features): ?>
                                                <span><?php echo wp_kses($features, true); ?></span>
                                            <?php endforeach; ?>
                                        </div>
                                    <?php } ?>
                                </div>
                            </div>
                        </div>
                        <?php
                    }
                }
            }
            echo '</div>';
            echo '</div>';
        }
    }

    protected function template_select()
    {
        $type = 'auxa_portfolio';
        global $post;
        $args = array('numberposts' => -1, 'post_type' => $type,);
        $posts = get_posts($args);
        $categories = array(
            '' => __('Select', 'auxa-core'),
        );
        foreach ($posts as $pn_cat) {
            $categories[$pn_cat->ID] = get_the_title($pn_cat->ID);
        }
        return $categories;
    }

    protected function render_template($id)
    {
        return Plugin::instance()->frontend->get_builder_content_for_display($id);
    }

}


Plugin::instance()->widgets_manager->register(new Auxa_Portfolio_V4());