<?php

/**
 * Elementor Single Widget
 * @package auxa-core
 * @since 1.0.0
 */

namespace Elementor;

if (!defined('ABSPATH')) exit; // Exit if accessed directly.

class Auxa_Portfolio_V5 extends Widget_Base
{

    /**
     * Get widget name.
     *
     * Retrieve Elementor widget name.
     *
     * @return string Widget name.
     * @since 1.0.0
     * @access public
     *
     */
    public function get_name()
    {
        return 'int-portfolio-v5';
    }

    /**
     * Get widget title.
     *
     * Retrieve Elementor widget title.
     *
     * @return string Widget title.
     * @since 1.0.0
     * @access public
     *
     */
    public function get_title()
    {
        return esc_html__('Portfolio V5', 'auxa-core');
    }

    /**
     * Get widget icon.
     *
     * Retrieve Elementor widget icon.
     *
     * @return string Widget icon.
     * @since 1.0.0
     * @access public
     *
     */
    public function get_icon()
    {
        return 'auxa-custom-icon';
    }

    /**
     * Get widget categories.
     *
     * Retrieve the list of categories the Elementor widget belongs to.
     *
     * @return array Widget categories.
     * @since 1.0.0
     * @access public
     *
     */
    public function get_categories()
    {
        return ['auxa_widgets'];
    }


    protected function register_controls()
    {

        $this->start_controls_section(
            'portfolio_option',
            [
                'label' => esc_html__('Portfolio', 'auxa-core'),
                'tab' => Controls_Manager::TAB_CONTENT,
            ]
        );


        $this->add_control(
            'template',
            [
                'type' => Controls_Manager::SELECT2,
                'options' => $this->template_select(),
                'multiple' => false,
                'label' => esc_html__('Portfolio', 'auxa-core'),
                'label_block' => true,
            ]
        );
        $this->add_control(
            'desc',
            [
                'type' => Controls_Manager::TEXTAREA,
                'label' => esc_html__('Button Label', 'purefit-core'),
                'label_block' => true,
            ]
        );
        $this->add_control(
            'btn_label',
            [
                'type' => Controls_Manager::TEXT,
                'label' => esc_html__('Button Label', 'purefit-core'),
                'label_block' => true,
            ]
        );
        $this->add_control(
            'date',
            [
                'type' => Controls_Manager::TEXT,
                'label' => esc_html__('Date', 'purefit-core'),
                'label_block' => true,
            ]
        );
        $this->add_control(
            'style_two',
            [
                'label' => esc_html__('Style Two', 'ovix-core'),
                'type' => \Elementor\Controls_Manager::SWITCHER,
                'label_on' => esc_html__('Show', 'ovix-core'),
                'label_off' => esc_html__('Hide', 'ovix-core'),
                'return_value' => 'yes',
                'default' => 'yes',
            ]
        );

        $this->add_control(
            'note_label',
            [
                'type' => Controls_Manager::RAW_HTML,
                'raw' => sprintf(
                    '<div class="elementor-panel-alert elementor-panel-alert-info">
                <p>%s</p>
            </div>',
                    sprintf(
                        __('Please note! Customize your selected Portfolio using Elementor. You can find it under <a href="%s" target="_blank">Portfolio</a>.', 'auxa-core'),
                        admin_url('edit.php?post_type=auxa_portfolio')
                    )
                ),
                'content_classes' => 'elementor-notice-container',
            ]
        );
        $this->end_controls_section();

        $this->start_controls_section(
            'style_option',
            [
                'label' => esc_html__('Style', 'auxa-core'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );
        $this->add_control(
            'border_c',
            [
                'label' => esc_html__('Border Color', 'ovix-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .ds-work' => 'border-color: {{VALUE}}',
                ],
            ]
        );
        $this->add_control(
            'date-c',
            [
                'label' => esc_html__('Date Color', 'purefit-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .ds-work .xb-item--year' => 'color: {{VALUE}}',
                ],
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'date_typography',
                'selector' => '{{WRAPPER}} .ds-work .xb-item--year',
            ]
        );

        $this->add_control(
            'title_hr',
            [
                'type' => \Elementor\Controls_Manager::DIVIDER,
            ]
        );
        $this->add_control(
            'title-c',
            [
                'label' => esc_html__('Title Color', 'auxa-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .ds-work .xb-item--title' => 'color: {{VALUE}}',
                ],
            ]
        );
        $this->add_control(
            'hover-title-c',
            [
                'label' => esc_html__('Title Hover Color', 'auxa-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .ds-work .xb-item--title:hover' => 'color: {{VALUE}}',
                ],
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'title_typography',
                'selector' => '{{WRAPPER}} .ds-work .xb-item--title',
            ]
        );
        $this->add_control(
            'desc_hr',
            [
                'type' => \Elementor\Controls_Manager::DIVIDER,
            ]
        );
        $this->add_control(
            'desc-c',
            [
                'label' => esc_html__('Content Color', 'auxa-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .ds-work .xb-item--content' => 'color: {{VALUE}}',
                ],
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'content_typography',
                'selector' => '{{WRAPPER}} .ds-work .xb-item--content',
            ]
        );
        $this->add_control(
            'btn_hr',
            [
                'type' => \Elementor\Controls_Manager::DIVIDER,
            ]
        );
        $this->add_control(
            'btn-c',
            [
                'label' => esc_html__('Button Color', 'auxa-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .ds-work .xb-item--learn span' => 'color: {{VALUE}}',
                ],
            ]
        );
        $this->add_control(
            'btn-hover-c',
            [
                'label' => esc_html__('Button Hover Color', 'auxa-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .ds-work .xb-item--learn:hover span' => 'color: {{VALUE}}',
                ],
            ]
        );
        $this->add_control(
            'btn-border-c',
            [
                'label' => esc_html__('Button Border Color', 'auxa-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .ds-work .xb-item--learn' => 'color: {{VALUE}}',
                ],
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'btn_typography',
                'selector' => '{{WRAPPER}} .ds-work .xb-item--learn span',
            ]
        );
        $this->end_controls_section();

    }

    protected function render()
    {
        $settings = $this->get_settings_for_display();
        $icon = AUXA_DIR_URL . 'assets/img/wrk_icon.png';
        if (isset($settings['template']) && !empty($settings['template'])) {
            $portfolio_post = get_post($settings['template']);

            if ($portfolio_post instanceof \WP_Post) {
                $portfolio_title = esc_html($portfolio_post->post_title);
                $portfolio_permalink = esc_url(get_permalink($portfolio_post));
                $featured_image_url = get_the_post_thumbnail_url($portfolio_post, 'large');
                ?>

                <div class="ds-work-inner">
                    <div class="row g-0 <?php echo ($settings['style_two'] === 'yes') ? 'flex-row-reverse' : ''; ?>">
                        <div class="col-lg-7">
                            <div class="work-image bg_img">
                                <img src="<?php echo esc_url($featured_image_url); ?>" alt="">
                            </div>
                        </div>
                        <div class="col-lg-5">
                            <div class="ds-work pos-rel">
                                <span class="xb-item--year"><?php echo esc_html($settings['date']); ?></span>
                                <div class="xb-item--holder">
                                    <h2 class="xb-item--title border-effect"><a href="<?php echo $portfolio_permalink; ?>"><?php echo $portfolio_title; ?></a></h2>
                                    <p class="xb-item--content mb-55"><?php echo wp_kses($settings['desc'], true); ?></p>
                                    <a class="xb-item--learn ul_li_between" href="<?php echo $portfolio_permalink; ?>">
                                        <span><?php echo esc_html($settings['btn_label']); ?></span>
                                        <img src="<?php echo esc_url($icon); ?>" alt="">
                                    </a>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>
                <?php
            }
        }
    }

    protected function template_select()
    {
        $type = 'auxa_portfolio';
        global $post;
        $args = array('numberposts' => -1, 'post_type' => $type,);
        $posts = get_posts($args);
        $categories = array(
            '' => __('Select', 'auxa-core'),
        );
        foreach ($posts as $pn_cat) {
            $categories[$pn_cat->ID] = get_the_title($pn_cat->ID);
        }
        return $categories;
    }

    protected function render_template($id)
    {
        return Plugin::instance()->frontend->get_builder_content_for_display($id);
    }

}


Plugin::instance()->widgets_manager->register(new Auxa_Portfolio_V5());