<?php

/**
 * Elementor Single Widget
 * @package auxa-core
 * @since 1.0.0
 */

namespace Elementor;

if (!defined('ABSPATH')) exit; // Exit if accessed directly.

class Auxa_Portfolio extends Widget_Base
{

    /**
     * Get widget name.
     *
     * Retrieve Elementor widget name.
     *
     * @return string Widget name.
     * @since 1.0.0
     * @access public
     *
     */
    public function get_name()
    {
        return 'int-portfolio';
    }

    /**
     * Get widget title.
     *
     * Retrieve Elementor widget title.
     *
     * @return string Widget title.
     * @since 1.0.0
     * @access public
     *
     */
    public function get_title()
    {
        return esc_html__('Portfolio', 'auxa-core');
    }

    /**
     * Get widget icon.
     *
     * Retrieve Elementor widget icon.
     *
     * @return string Widget icon.
     * @since 1.0.0
     * @access public
     *
     */
    public function get_icon()
    {
        return 'auxa-custom-icon';
    }

    /**
     * Get widget categories.
     *
     * Retrieve the list of categories the Elementor widget belongs to.
     *
     * @return array Widget categories.
     * @since 1.0.0
     * @access public
     *
     */
    public function get_categories()
    {
        return ['auxa_widgets'];
    }


    protected function register_controls()
    {

        $this->start_controls_section(
            'sec_title_option',
            [
                'label' => esc_html__('Section Title', 'auxa-core'),
                'tab' => Controls_Manager::TAB_CONTENT,
            ]
        );
        $this->add_control(
            'sub_title', [
                'label' => esc_html__('Sub Title', 'auxa-core'),
                'type' => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        $this->add_control(
            'title', [
                'label' => esc_html__('Title', 'auxa-core'),
                'type' => Controls_Manager::TEXTAREA,
                'label_block' => true,
            ]
        );
        $this->end_controls_section();

        $this->start_controls_section(
            'portfolio_option',
            [
                'label' => esc_html__('Portfolio', 'auxa-core'),
                'tab' => Controls_Manager::TAB_CONTENT,
            ]
        );
        $this->add_control(
            'portfolioorder',
            [
                'label' => esc_html__('Portfolio Order', 'auxa-core'),
                'type' => Controls_Manager::SELECT,
                'default' => 'ASC',
                'options' => [
                    'ASC' => esc_html__('Ascending', 'auxa-core'),
                    'DESC' => esc_html__('Descending', 'auxa-core'),
                ],
            ]
        );
        $this->add_control(
            'portfolio_per_page',
            [
                'label' => __('Portfolio Per Page', 'auxa-core'),
                'type' => Controls_Manager::NUMBER,
                'min' => 1,
                'default' => 4,
            ]
        );
        $this->add_control(
            'portfolio_categories',
            [
                'type' => Controls_Manager::SELECT2,
                'label' => esc_html__('Select Portfolio Categories', 'auxa-core'),
                'options' => auxa_portfolio_category(),
                'label_block' => true,
                'multiple' => true,
            ]
        );
        $this->end_controls_section();

        $this->start_controls_section(
            'sec_title_style',
            [
                'label' => esc_html__('Section Style', 'auxa-core'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_control(
            'sub-title-c',
            [
                'label' => esc_html__('Sub Title Color', 'auxa-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .section-title .sub-title' => 'color: {{VALUE}}',
                ],
            ]
        );

        $this->add_control(
            'sub-title-dot-c',
            [
                'label' => esc_html__('Sub Title Dot Color', 'auxa-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .section-title .sub-title::before' => 'background-color: {{VALUE}}',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'sub_title_typography',
                'selector' => '{{WRAPPER}} .section-title .sub-title',
            ]
        );

        $this->add_control(
            'cta-box-styl',
            [
                'label' => esc_html__('Title Style', 'auxa-core'),
                'type' => \Elementor\Controls_Manager::HEADING,
                'separator' => 'before',
            ]
        );

        $this->add_control(
            'title-c',
            [
                'label' => esc_html__('Title Color', 'auxa-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .section-title .title' => 'color: {{VALUE}}',
                ],
            ]
        );
        $this->add_control(
            'title-highlight-c',
            [
                'label' => esc_html__('Title Highlight Color', 'auxa-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .section-title .title span' => 'color: {{VALUE}}',
                ],
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 's_title_typography',
                'selector' => '{{WRAPPER}} .section-title .title',
            ]
        );
        $this->add_control(
            's_title_padding',
            [
                'label' => esc_html__('Padding', 'auxa-core'),
                'type' => \Elementor\Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em', 'rem', 'custom'],
                'selectors' => [
                    '{{WRAPPER}} .section-title .title' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );
        $this->end_controls_section();

        $this->start_controls_section(
            'portfolio_cat_style',
            [
                'label' => esc_html__('Portfolio Category', 'auxa-core'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_control(
            'nav_padding',
            [
                'label' => esc_html__('Nav Padding', 'auxa-core'),
                'type' => \Elementor\Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em', 'rem', 'custom'],
                'selectors' => [
                    '{{WRAPPER}} .portfolio-menu button' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'nav_typography',
                'selector' => '{{WRAPPER}} .portfolio-menu button',
            ]
        );

        $this->start_controls_tabs(
            'style_tabs'
        );

        $this->start_controls_tab(
            'style_normal_tab',
            [
                'label' => esc_html__('Normal', 'auxa-core'),
            ]
        );

        $this->add_control(
            'nav-c',
            [
                'label' => esc_html__('Nav Color', 'auxa-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .portfolio-menu button' => 'color: {{VALUE}}',
                ],
            ]
        );

        $this->end_controls_tab();

        $this->start_controls_tab(
            'style_hover_tab',
            [
                'label' => esc_html__('Hover', 'auxa-core'),
            ]
        );

        $this->add_control(
            'h-nav-c',
            [
                'label' => esc_html__('Nav Color', 'auxa-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .portfolio-menu button.active' => 'color: {{VALUE}}',
                    '{{WRAPPER}} .portfolio-menu button:hover' => 'color: {{VALUE}}',
                ],
            ]
        );
        $this->add_control(
            'h-border-c',
            [
                'label' => esc_html__('Nav Border Color', 'auxa-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .portfolio-menu button::before' => 'background-color: {{VALUE}}',
                ],
            ]
        );

        $this->end_controls_tab();

        $this->end_controls_tabs();

        $this->end_controls_section();

        $this->start_controls_section(
            'portfolio_list_style',
            [
                'label' => esc_html__('Portfolio List', 'auxa-core'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_control(
            'cat_color',
            [
                'label' => esc_html__('Category Color', 'auxa-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .xb-hover-wrapper .xb-hover-cat' => 'color: {{VALUE}}',
                ],
            ]
        );
        $this->add_control(
            'cat_bg_color',
            [
                'label' => esc_html__('Category BG Color', 'auxa-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .xb-hover-wrapper .xb-hover-cat' => 'background-color: {{VALUE}}',
                ],
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'cat_typography',
                'selector' => '{{WRAPPER}} .xb-hover-wrapper .xb-hover-cat',
            ]
        );
        $this->add_control(
            'port_title_hr',
            [
                'type' => \Elementor\Controls_Manager::DIVIDER,
            ]
        );
        $this->add_control(
            'port_title_color',
            [
                'label' => esc_html__('Title Color', 'auxa-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .xb-hover-wrapper .xb-hover-title' => 'color: {{VALUE}}',
                ],
            ]
        );
        $this->add_control(
            'port_title_bg-c',
            [
                'label' => esc_html__('Title BG Color', 'auxa-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .xb-hover-wrapper .xb-hover-title' => 'background-color: {{VALUE}}',
                ],
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'port_title_typography',
                'selector' => '{{WRAPPER}} .xb-hover-wrapper .xb-hover-title',
            ]
        );
        $this->end_controls_section();

    }

    protected function render()
    {
        $settings = $this->get_settings_for_display();
        $portfolioCategory = get_terms('portfolio_cat');
        ?>
        <div class="row align-items-end mb-20">
        <?php if (!empty($settings['sub_title']) || !empty($settings['title'])): ?>
            <div class="col-lg-5">
                <div class="section-title mb-30">
                    <?php if (!empty($settings['sub_title'])): ?>
                        <h5 class="sub-title wow fadeInRight" data-wow-duration=".7s"><?php echo esc_html($settings['sub_title']); ?></h5>
                        <?php endif; ?>
                        <div class="clearfix"></div>
                        <?php
                        if (!empty($settings['title'])): ?>
                            <h2 class="title wow skewIn"><?php echo wp_kses($settings['title'], true); ?></h2>
                        <?php endif; ?>
                </div>
            </div>
        <?php endif; ?>
            <div class="col-lg-7">
                <div class="portfolio-menu mb-65 text-lg-end">
                    <button class="active" data-filter="*"><?php esc_html_e('SEE ALL', 'auxa-core') ?></button>
                    <?php
                    if (!empty($portfolioCategory) && !is_wp_error($portfolioCategory)):
                        foreach ($portfolioCategory as $cate):
                            ?>
                            <button data-filter=".<?php echo esc_attr($cate->slug) ?>"
                                    class=""><?php echo esc_html($cate->name) ?></button>
                        <?php endforeach; endif; ?>
                </div>
            </div>
        </div>
        <div class="row grid g-150 mt-none-60">

            <?php
            $args = array(
                'post_type' => 'auxa_portfolio',
                'posts_per_page' => !empty($settings['portfolio_per_page']) ? $settings['portfolio_per_page'] : 1,
                'ignore_sticky_posts' => true,
                'post_status' => 'publish',
                'suppress_filters' => false,
                'order' => $settings['portfolioorder'],
            );
            if (!empty($settings['portfolio_categories'])) {
                $args['portfolio_cat'] = implode(',', $settings['portfolio_categories']);
            }
            $query = new \WP_Query($args);
            if ($query->have_posts()):

                while ($query->have_posts()) {
                    $query->the_post();
                    $idd = get_the_ID();

                    $portfolioInerCates = get_the_terms($idd, 'portfolio_cat');
                    if ($portfolioInerCates && !is_wp_error($portfolioInerCates)) {
                        $portfolio_cat_list = array();
                        foreach ($portfolioInerCates as $cate) {
                            $portfolio_cat_list[] = $cate->slug;
                        }
                        $portfolio_cate_asign_list = join(' ', $portfolio_cat_list);
                    } else {
                        $portfolio_cate_asign_list = '';
                    }
                    ?>
                    <div class="col-lg-6 col-md-6 grid-item <?php echo esc_attr($portfolio_cate_asign_list) ?>">
                        <div class="portfolio-item xb-img-reveal-item mt-60" data-cat="<?php echo esc_attr($cate->name); ?>"
                             data-title="<?php the_title(); ?>" data-fx="1">
                            <div class="xbImage__hover">
                                <a href="<?php the_permalink(); ?>"><?php the_post_thumbnail('auxa-portfolio'); ?></a>
                            </div>
                        </div>
                    </div>
                    <?php
                }
                wp_reset_query();
            endif;
            ?>
        </div>
        <?php
    }

}


Plugin::instance()->widgets_manager->register(new Auxa_Portfolio());