<?php

/**
 * Elementor Single Widget
 * @package auxa-core
 * @since 1.0.0
 */

namespace Elementor;

if (!defined('ABSPATH')) exit; // Exit if accessed directly.

class Auxa_Pricing extends Widget_Base
{

    /**
     * Get widget name.
     *
     * Retrieve Elementor widget name.
     *
     * @return string Widget name.
     * @since 1.0.0
     * @access public
     *
     */
    public function get_name()
    {
        return 'int-pricing';
    }

    /**
     * Get widget title.
     *
     * Retrieve Elementor widget title.
     *
     * @return string Widget title.
     * @since 1.0.0
     * @access public
     *
     */
    public function get_title()
    {
        return esc_html__('Pricing', 'auxa-core');
    }

    /**
     * Get widget icon.
     *
     * Retrieve Elementor widget icon.
     *
     * @return string Widget icon.
     * @since 1.0.0
     * @access public
     *
     */
    public function get_icon()
    {
        return 'auxa-custom-icon';
    }

    /**
     * Get widget categories.
     *
     * Retrieve the list of categories the Elementor widget belongs to.
     *
     * @return array Widget categories.
     * @since 1.0.0
     * @access public
     *
     */
    public function get_categories()
    {
        return ['auxa_widgets'];
    }


    protected function register_controls()
    {

        $this->start_controls_section(
            'content_option',
            [
                'label' => esc_html__('Content', 'auxa-core'),
                'tab' => Controls_Manager::TAB_CONTENT,
            ]
        );
        $this->add_control(
            'title',
            [
                'type' => Controls_Manager::TEXT,
                'label' => esc_html__('Title', 'purefit-core'),
                'label_block' => true,
            ]
        );
        $this->add_control(
            'content',
            [
                'type' => Controls_Manager::TEXTAREA,
                'label' => esc_html__('Content', 'purefit-core'),
                'label_block' => true,
            ]
        );

        $this->add_control(
            'list_hr',
            [
                'label' => esc_html__('List Options', 'purefit-core'),
                'type' => \Elementor\Controls_Manager::HEADING,
                'separator' => 'before',
            ]
        );
        $repeater = new \Elementor\Repeater();
        $repeater->add_control(
            'list',
            [
                'type' => Controls_Manager::TEXT,
                'label' => esc_html__('List Text', 'auxa-core'),
                'label_block' => true,
            ]
        );

        $this->add_control(
            'lists',
            [
                'type' => Controls_Manager::REPEATER,
                'fields' => $repeater->get_controls(),
                'title_field' => '{{{ list }}}',
            ]
        );

        $this->add_control(
            'pricing_hr',
            [
                'label' => esc_html__('Pricing', 'purefit-core'),
                'type' => \Elementor\Controls_Manager::HEADING,
                'separator' => 'before',
            ]
        );
        $repeater = new \Elementor\Repeater();

        $repeater->add_control(
            'active',
            [
                'label' => esc_html__('Active', 'ovix-core'),
                'type' => \Elementor\Controls_Manager::SWITCHER,
                'label_on' => esc_html__('Show', 'ovix-core'),
                'label_off' => esc_html__('Hide', 'ovix-core'),
                'return_value' => 'yes',
                'default' => 'yes',
            ]
        );
        $repeater->add_control(
            'title',
            [
                'type' => Controls_Manager::TEXT,
                'label' => esc_html__('Title', 'auxa-core'),
                'label_block' => true,
            ]
        );
        $repeater->add_control(
            'price',
            [
                'type' => Controls_Manager::TEXT,
                'label' => esc_html__('Price', 'auxa-core'),
                'label_block' => true,
            ]
        );
        $repeater->add_control(
            'content',
            [
                'type' => Controls_Manager::TEXT,
                'label' => esc_html__('Content', 'auxa-core'),
                'label_block' => true,
            ]
        );
        $repeater->add_control(
            'btn_label',
            [
                'type' => Controls_Manager::TEXT,
                'label' => esc_html__('Button Label', 'purefit-core'),
                'label_block' => true,
            ]
        );
        $repeater->add_control(
            'btn_link',
            [
                'label' => esc_html__('Link', 'purefit-core'),
                'type' => \Elementor\Controls_Manager::URL,
                'options' => ['url'],
                'default' => [
                    'url' => '#',
                ],
                'label_block' => true,
            ]
        );

        $this->add_control(
            'prices',
            [
                'type' => Controls_Manager::REPEATER,
                'fields' => $repeater->get_controls(),
                'title_field' => '{{{ title }}}',
            ]
        );

        $this->end_controls_section();


        $this->start_controls_section(
            'color_option',
            [
                'label' => esc_html__('Style', 'auxa-core'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );
        $this->add_control(
            'bg-c',
            [
                'label' => esc_html__('Background Color', 'ovix-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .ds-pricing-plan' => 'background-color: {{VALUE}}',
                ],
            ]
        );
        $this->add_control(
            'title-c',
            [
                'label' => esc_html__('Title Color', 'auxa-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .ds-pricing-plan .xb-item--title' => 'color: {{VALUE}}',
                ],
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'title_typography',
                'selector' => '{{WRAPPER}} .ds-pricing-plan .xb-item--title',
            ]
        );
        $this->add_control(
            'title_hr',
            [
                'type' => \Elementor\Controls_Manager::DIVIDER,
            ]
        );
        $this->add_control(
            'content-c',
            [
                'label' => esc_html__('Content Color', 'auxa-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .ds-pricing-plan .xb-item--content' => 'color: {{VALUE}}',
                ],
            ]
        );
        $this->add_control(
            'border_c',
            [
                'label' => esc_html__('Border Color', 'ovix-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .ds-pricing-plan .xb-item--content' => 'border-color: {{VALUE}}',
                ],
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'content_typography',
                'selector' => '{{WRAPPER}} .ds-pricing-plan .xb-item--content',
            ]
        );
        $this->add_control(
            'list_hr',
            [
                'type' => \Elementor\Controls_Manager::DIVIDER,
            ]
        );
        $this->add_control(
            'list-c',
            [
                'label' => esc_html__('List Color', 'auxa-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .ds-pricing-plan .xb-item--list li' => 'color: {{VALUE}}',
                ],
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'list_typography',
                'selector' => '{{WRAPPER}} .ds-pricing-plan .xb-item--list li',
            ]
        );
        $this->add_control(
            'pricing_style',
            [
                'label' => esc_html__('Pricing Style', 'purefit-core'),
                'type' => \Elementor\Controls_Manager::HEADING,
                'separator' => 'before',
            ]
        );
        $this->start_controls_tabs(
            'style_tabs'
        );

        $this->start_controls_tab(
            'style_normal_tab',
            [
                'label' => esc_html__('Normal', 'purefit-core'),
            ]
        );
        $this->add_control(
            'p-bg-c',
            [
                'label' => esc_html__('Background Color', 'ovix-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .ds-pricing-info' => 'background-color: {{VALUE}}',
                ],
            ]
        );
        $this->add_control(
            'p-padding',
            [
                'label' => esc_html__('Padding', 'ovix-core'),
                'type' => \Elementor\Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em', 'rem', 'custom'],
                'selectors' => [
                    '{{WRAPPER}} .ds-pricing-info' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );
        $this->add_control(
            'p-title-c',
            [
                'label' => esc_html__('Title Color', 'purefit-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .ds-pricing-info .xb-item--title' => 'color: {{VALUE}}',
                ],
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'p-title_typography',
                'selector' => '{{WRAPPER}} .ds-pricing-info .xb-item--title',
            ]
        );
        $this->add_control(
            'p-price-hr',
            [
                'type' => \Elementor\Controls_Manager::DIVIDER,
            ]
        );
        $this->add_control(
            'p-price-c',
            [
                'label' => esc_html__('Price Color', 'purefit-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .ds-pricing-info .xb-item--number' => 'color: {{VALUE}}',
                ],
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'p-price_typography',
                'selector' => '{{WRAPPER}} .ds-pricing-info .xb-item--number',
            ]
        );
        $this->add_control(
            'p_content_hr',
            [
                'type' => \Elementor\Controls_Manager::DIVIDER,
            ]
        );
        $this->add_control(
            'p-content-c',
            [
                'label' => esc_html__('Content Color', 'purefit-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .ds-pricing-info .xb-item--content' => 'color: {{VALUE}}',
                ],
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'p-content_typography',
                'selector' => '{{WRAPPER}} .ds-pricing-info .xb-item--content',
            ]
        );
        $this->add_control(
            'btn_hr',
            [
                'type' => \Elementor\Controls_Manager::DIVIDER,
            ]
        );
        $this->add_control(
            'btn-padding',
            [
                'label' => esc_html__('Button Padding', 'ovix-core'),
                'type' => \Elementor\Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em', 'rem', 'custom'],
                'selectors' => [
                    '{{WRAPPER}} .ds-pricing-info .xb-item--btn' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'p-btn_typography',
                'selector' => '{{WRAPPER}} .ds-pricing-info .xb-item--btn',
            ]
        );
        $this->add_control(
            'p-btn-c',
            [
                'label' => esc_html__('Button Color', 'purefit-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .ds-pricing-info .xb-item--btn' => 'color: {{VALUE}}',
                ],
            ]
        );
        $this->add_control(
            'h-p-btn-c',
            [
                'label' => esc_html__('Button Hover Color', 'purefit-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .ds-pricing-info .xb-item--btn:hover' => 'color: {{VALUE}}',
                ],
            ]
        );
        $this->add_control(
            'p-btn-bg-c',
            [
                'label' => esc_html__('Button BG Color', 'purefit-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .ds-pricing-info .xb-item--btn' => 'background-color: {{VALUE}}',
                ],
            ]
        );
        $this->add_control(
            'h-p-btn-bg-c',
            [
                'label' => esc_html__('Button Hover BG Color', 'purefit-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .ds-pricing-info .xb-item--btn:hover' => 'background-color: {{VALUE}}',
                ],
            ]
        );
        $this->end_controls_tab();

        $this->start_controls_tab(
            'style_hover_tab',
            [
                'label' => esc_html__('Active', 'purefit-core'),
            ]
        );

        $this->add_control(
            'ap-bg-c',
            [
                'label' => esc_html__('Background Color', 'ovix-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .ds-pricing-info.active' => 'background-color: {{VALUE}}',
                ],
            ]
        );
        $this->add_control(
            'ap-title-c',
            [
                'label' => esc_html__('Title Color', 'purefit-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .ds-pricing-info.active .xb-item--title' => 'color: {{VALUE}}',
                ],
            ]
        );
        $this->add_control(
            'ap-price-hr',
            [
                'type' => \Elementor\Controls_Manager::DIVIDER,
            ]
        );
        $this->add_control(
            'ap-price-c',
            [
                'label' => esc_html__('Price Color', 'purefit-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .ds-pricing-info.active .xb-item--number' => 'color: {{VALUE}}',
                ],
            ]
        );
        $this->add_control(
            'ap_content_hr',
            [
                'type' => \Elementor\Controls_Manager::DIVIDER,
            ]
        );
        $this->add_control(
            'ap-content-c',
            [
                'label' => esc_html__('Content Color', 'purefit-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .ds-pricing-info.active .xb-item--content' => 'color: {{VALUE}}',
                ],
            ]
        );

        $this->add_control(
            'abtn_hr',
            [
                'type' => \Elementor\Controls_Manager::DIVIDER,
            ]
        );
        $this->add_control(
            'ap-btn-c',
            [
                'label' => esc_html__('Button Color', 'purefit-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .ds-pricing-info.active .xb-item--btn' => 'color: {{VALUE}}',
                ],
            ]
        );
        $this->add_control(
            'ah-p-btn-c',
            [
                'label' => esc_html__('Button Hover Color', 'purefit-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .ds-pricing-info.active .xb-item--btn:hover' => 'color: {{VALUE}}',
                ],
            ]
        );
        $this->add_control(
            'ap-btn-bg-c',
            [
                'label' => esc_html__('Button BG Color', 'purefit-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .ds-pricing-info.active .xb-item--btn' => 'background-color: {{VALUE}}',
                ],
            ]
        );
        $this->add_control(
            'ah-p-btn-bg-c',
            [
                'label' => esc_html__('Button Hover BG Color', 'purefit-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .ds-pricing-info.active .xb-item--btn:hover' => 'background-color: {{VALUE}}',
                ],
            ]
        );
        
        $this->end_controls_tab();

        $this->end_controls_tabs();
        $this->end_controls_section();

    }

    protected function render()
    {
        $settings = $this->get_settings_for_display();
        ?>
        <div class="row g-0">
            <div class="col-lg-6">
                <div class="ds-pricing-plan">
                    <div class="xb-item--holder">
                        <?php if (!empty($settings['title'])): ?>
                            <h2 class="xb-item--title"><?php echo esc_html($settings['title']); ?></h2>
                        <?php endif; ?>
                        <?php if (!empty($settings['content'])): ?>
                            <p class="xb-item--content"><?php echo wp_kses($settings['content'], true); ?></p>
                        <?php endif; ?>
                    </div>
                    <ul class="xb-item--list ul_li">
                        <?php
                        foreach ($settings['lists'] as $list):
                            ?>
                            <li class="pos-rel"><?php echo esc_html($list['list']); ?></li>
                        <?php endforeach; ?>
                    </ul>
                </div>
            </div>

            <?php
            foreach ($settings['prices'] as $price):
                ?>
                <div class="col-lg-3">
                    <div class="ds-pricing-info <?php echo ($price['active'] === 'yes') ? 'active' : ''; ?>">
                        <div class="xb-item--holder">
                            <h3 class="xb-item--title"><?php echo esc_html($price['title']); ?></h3>
                            <span class="xb-item--number"><?php echo esc_html($price['price']); ?></span>
                            <p class="xb-item--content"><?php echo esc_html($price['content']); ?></p>
                        </div>
                        <a class="xb-item--btn" href="<?php echo esc_html($price['btn_link']['url']); ?>"><?php echo esc_html($price['btn_label']); ?></a>
                    </div>
                </div>
            <?php endforeach; ?>
        </div>
        <?php
    }
}


Plugin::instance()->widgets_manager->register(new Auxa_Pricing());