<?php

/**
 * Elementor Single Widget
 * @package auxa-core
 * @since 1.0.0
 */

namespace Elementor;

if (!defined('ABSPATH')) exit; // Exit if accessed directly.

class Auxa_Service_V4 extends Widget_Base
{

    /**
     * Get widget name.
     *
     * Retrieve Elementor widget name.
     *
     * @return string Widget name.
     * @since 1.0.0
     * @access public
     *
     */
    public function get_name()
    {
        return 'int-service-v4';
    }

    /**
     * Get widget title.
     *
     * Retrieve Elementor widget title.
     *
     * @return string Widget title.
     * @since 1.0.0
     * @access public
     *
     */
    public function get_title()
    {
        return esc_html__('Service V4', 'auxa-core');
    }

    /**
     * Get widget icon.
     *
     * Retrieve Elementor widget icon.
     *
     * @return string Widget icon.
     * @since 1.0.0
     * @access public
     *
     */
    public function get_icon()
    {
        return 'auxa-custom-icon';
    }

    /**
     * Get widget categories.
     *
     * Retrieve the list of categories the Elementor widget belongs to.
     *
     * @return array Widget categories.
     * @since 1.0.0
     * @access public
     *
     */
    public function get_categories()
    {
        return ['auxa_widgets'];
    }


    protected function register_controls()
    {
        $this->start_controls_section(
            'service_option',
            [
                'label' => esc_html__('Service', 'auxa-core'),
                'tab' => Controls_Manager::TAB_CONTENT,
            ]
        );

        $repeater = new \Elementor\Repeater();

        $repeater->add_control(
            'template',
            [
                'type' => Controls_Manager::SELECT2,
                'options' => $this->template_select(),
                'multiple' => false,
                'label' => esc_html__('Service', 'auxa-core'),
                'label_block' => true,
            ]
        );

        $repeater->add_control(
            'content', [
                'label' => esc_html__('Content', 'auxa-core'),
                'type' => Controls_Manager::TEXTAREA,
                'label_block' => true,
            ]
        );
        $repeater->add_control(
            'btn_label',
            [
                'type' => Controls_Manager::TEXT,
                'label' => esc_html__('Button Label', 'auxa-core'),
                'label_block' => true,
            ]
        );

        $this->add_control(
            'lists',
            [
                'type' => Controls_Manager::REPEATER,
                'fields' => $repeater->get_controls(),
                'prevent_empty' => false,
            ]
        );
        $this->add_control(
            'note_label',
            [
                'type' => Controls_Manager::RAW_HTML,
                'raw' => sprintf(
                    '<div class="elementor-panel-alert elementor-panel-alert-info">
                <p>%s</p>
            </div>',
                    sprintf(
                        __('Please note! Customize your selected Service using Elementor. You can find it under <a href="%s" target="_blank">Services</a>.', 'auxa-core'),
                        admin_url('edit.php?post_type=auxa_service')
                    )
                ),
                'content_classes' => 'elementor-notice-container',
            ]
        );
        $this->end_controls_section();


        $this->start_controls_section(
            'color_option',
            [
                'label' => esc_html__('Style', 'auxa-core'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );
        $this->add_control(
            'bg-c',
            [
                'label' => esc_html__('Background Color', 'auxa-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .service-wrapper .xb-item--shape svg path' => 'fill: {{VALUE}}',
                ],
            ]
        );
        $this->add_control(
            'padding',
            [
                'label' => esc_html__('Padding', 'auxa-core'),
                'type' => \Elementor\Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em', 'rem', 'custom'],
                'selectors' => [
                    '{{WRAPPER}} .service-wrapper' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );
        $this->add_control(
            'title_hr',
            [
                'type' => \Elementor\Controls_Manager::DIVIDER,
            ]
        );
        $this->add_control(
            'title-c',
            [
                'label' => esc_html__('Title Color', 'auxa-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .service-wrapper .xb-item--title' => 'color: {{VALUE}}',
                ],
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'title_typography',
                'selector' => '{{WRAPPER}} .service-wrapper .xb-item--title',
            ]
        );
        $this->add_control(
            'content_hr',
            [
                'type' => \Elementor\Controls_Manager::DIVIDER,
            ]
        );
        $this->add_control(
            'content-c',
            [
                'label' => esc_html__('Content Color', 'auxa-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .service-wrapper .xb-item--content' => 'color: {{VALUE}}',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'content_typography',
                'selector' => '{{WRAPPER}} .service-wrapper .xb-item--content',
            ]
        );
        $this->add_control(
            'btn_style',
            [
                'label' => esc_html__('Button Style', 'auxa-core'),
                'type' => \Elementor\Controls_Manager::HEADING,
                'separator' => 'before',
            ]
        );
        $this->add_control(
            'btn_padding',
            [
                'label' => esc_html__('Padding', 'auxa-core'),
                'type' => \Elementor\Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em', 'rem', 'custom'],
                'selectors' => [
                    '{{WRAPPER}} .service-wrapper .xb-item--button' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'btn_typography',
                'selector' => '{{WRAPPER}} .service-wrapper .xb-item--button',
            ]
        );
        $this->start_controls_tabs(
            'style_tabs'
        );

        $this->start_controls_tab(
            'style_normal_tab',
            [
                'label' => esc_html__('Normal', 'auxa-core'),
            ]
        );

        $this->add_control(
            'btn-c',
            [
                'label' => esc_html__('Button Color', 'auxa-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .service-wrapper .xb-item--button' => 'color: {{VALUE}}',
                ],
            ]
        );

        $this->add_control(
            'btn-border-c',
            [
                'label' => esc_html__('Border Color', 'auxa-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .service-wrapper .xb-item--button' => 'border-color: {{VALUE}}',
                ],
            ]
        );

        $this->end_controls_tab();

        $this->start_controls_tab(
            'style_hover_tab',
            [
                'label' => esc_html__('Hover', 'auxa-core'),
            ]
        );

        $this->add_control(
            'hbtn-c',
            [
                'label' => esc_html__('Button Color', 'auxa-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .service-wrapper .xb-item--button:hover' => 'color: {{VALUE}}',
                ],
            ]
        );

        $this->add_control(
            'hbtn-border-c',
            [
                'label' => esc_html__('Border Color', 'auxa-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .service-wrapper .xb-item--button:hover' => 'border-color: {{VALUE}}',
                ],
            ]
        );
        $this->end_controls_tab();

        $this->end_controls_tabs();

        $this->end_controls_section();


    }

    protected function render()
    {
        $settings = $this->get_settings_for_display();
        $shape = AUXA_DIR_URL . 'assets/img/srv_shape.png';

        if (!empty($settings['lists'])) {
            echo '<div class="fd-service-inner">';

            foreach ($settings['lists'] as $index => $a) {
                if (isset($a['template']) && !empty($a['template'])) {
                    $service_post = get_post($a['template']);

                    if ($service_post instanceof \WP_Post) {
                        $service_title = esc_html($service_post->post_title);
                        $service_permalink = esc_url(get_permalink($service_post));
                        $featured_image_url = get_the_post_thumbnail_url($service_post, 'auxa-medium');

                        // Dynamically generate the ID with a number based on the loop index
                        $bg_stroke_id = 'srv_bg_stroke_' . $index;
                        ?>
                        <div class="service-wrapper ul_li wow fadeInUp" data-wow-duration=".7s">
                            <div class="xb-item--shape">
                                <svg xmlns="http://www.w3.org/2000/svg" width="1290" height="479" viewBox="0 0 1290 479"
                                     fill="none" preserveAspectRatio="none">
                                    <path d="M55.8579 11.6972C59.0513 4.59071 66.1822 0 73.9732 0H1224.6C1233.11 0 1240.72 5.43591 1243.45 13.4977C1304.19 192.576 1306.74 296.292 1243.69 466.083C1240.81 473.85 1233.35 479 1225.06 479H74.6973C66.539 479 59.1702 474.001 56.1664 466.415C-11.5557 295.406 -25.4489 192.635 55.8579 11.6972Z"
                                          fill="url(#<?php echo esc_attr($bg_stroke_id); ?>)"/>
                                    <path d="M56.3139 11.9021C59.4262 4.97613 66.3781 0.5 73.9732 0.5H1224.6C1232.9 0.5 1240.32 5.80011 1242.98 13.6583C1273.34 103.174 1289.15 173.815 1289.49 243.276C1289.84 312.733 1274.73 381.047 1243.22 465.909C1240.41 473.479 1233.14 478.5 1225.06 478.5H74.6973C66.7437 478.5 59.5595 473.625 56.6312 466.231C22.7761 380.741 2.39907 312.363 0.62616 242.766C-1.14654 173.179 15.6799 102.328 56.3139 11.9021Z"
                                          stroke="url(#<?php echo esc_attr($bg_stroke_id); ?>)" stroke-opacity="0.1"/>
                                    <defs>
                                        <linearGradient id="<?php echo esc_attr($bg_stroke_id); ?>" x1="645" y1="0" x2="645" y2="479"
                                                        gradientUnits="userSpaceOnUse">
                                            <stop offset="0" stop-color="#060613"/>
                                            <stop offset="1" stop-color="#151521"/>
                                        </linearGradient>
                                    </defs>
                                </svg>
                            </div>
                            <div class="xb-item--shape-border">
                                <img src="<?php echo esc_url($shape); ?>" alt="">
                            </div>
                            <div class="xb-item--holder">
                                <div class="service-left">
                                    <h2 class="xb-item--title border-effect"><a
                                                href="<?php echo $service_permalink; ?>"><?php echo $service_title; ?></a></h2>
                                    <div class="xb-item--content"><?php echo wp_kses($a['content'], true); ?></div>
                                    <?php if (!empty($a['btn_label'])): ?>
                                        <a href="<?php echo $service_permalink; ?>"
                                           class="btn xb-item--button"><?php echo esc_html($a['btn_label']); ?></a>
                                    <?php endif; ?>
                                </div>
                                <div class="service-right">
                                    <img src="<?php echo esc_url($featured_image_url); ?>" alt="">
                                </div>
                            </div>
                        </div>
                        <?php
                    }
                }
            }
            echo '</div>';
        }
    }


    protected function template_select()
    {
        $type = 'auxa_service';
        global $post;
        $args = array('numberposts' => -1, 'post_type' => $type,);
        $posts = get_posts($args);
        $categories = array(
            '' => __('Select', 'auxa-core'),
        );
        foreach ($posts as $pn_cat) {
            $categories[$pn_cat->ID] = get_the_title($pn_cat->ID);
        }
        return $categories;
    }

    protected function render_template($id)
    {
        return Plugin::instance()->frontend->get_builder_content_for_display($id);
    }

}


Plugin::instance()->widgets_manager->register(new Auxa_Service_V4());