<?php

/**
 * Elementor Single Widget
 * @package auxa-core
 * @since 1.0.0
 */

namespace Elementor;

if (!defined('ABSPATH')) exit; // Exit if accessed directly.

class Auxa_Service_V6 extends Widget_Base
{

    /**
     * Get widget name.
     *
     * Retrieve Elementor widget name.
     *
     * @return string Widget name.
     * @since 1.0.0
     * @access public
     *
     */
    public function get_name()
    {
        return 'int-service-v6';
    }

    /**
     * Get widget title.
     *
     * Retrieve Elementor widget title.
     *
     * @return string Widget title.
     * @since 1.0.0
     * @access public
     *
     */
    public function get_title()
    {
        return esc_html__('Service V6', 'auxa-core');
    }

    /**
     * Get widget icon.
     *
     * Retrieve Elementor widget icon.
     *
     * @return string Widget icon.
     * @since 1.0.0
     * @access public
     *
     */
    public function get_icon()
    {
        return 'auxa-custom-icon';
    }

    /**
     * Get widget categories.
     *
     * Retrieve the list of categories the Elementor widget belongs to.
     *
     * @return array Widget categories.
     * @since 1.0.0
     * @access public
     *
     */
    public function get_categories()
    {
        return ['auxa_widgets'];
    }


    protected function register_controls()
    {
        $this->start_controls_section(
            'service_option',
            [
                'label' => esc_html__('Service', 'auxa-core'),
                'tab' => Controls_Manager::TAB_CONTENT,
            ]
        );

        $this->add_control(
            'bg_image',
            [
                'label' => esc_html__('Image', 'ovix-core'),
                'type' => \Elementor\Controls_Manager::MEDIA,
            ]
        );

        $repeater = new \Elementor\Repeater();

        $repeater->add_control(
            'template',
            [
                'type' => Controls_Manager::SELECT2,
                'options' => $this->template_select(),
                'multiple' => false,
                'label' => esc_html__('Service', 'auxa-core'),
                'label_block' => true,
            ]
        );

        $repeater->add_control(
            'desc', [
                'label' => esc_html__('Description', 'auxa-core'),
                'type' => Controls_Manager::TEXTAREA,
                'label_block' => true,
            ]
        );
        $repeater->add_control(
            'image',
            [
                'label' => esc_html__('Image', 'ovix-core'),
                'type' => \Elementor\Controls_Manager::MEDIA,
            ]
        );

        $this->add_control(
            'lists',
            [
                'type' => Controls_Manager::REPEATER,
                'fields' => $repeater->get_controls(),
                'prevent_empty' => false,
            ]
        );
        $this->add_control(
            'btn_label',
            [
                'type' => Controls_Manager::TEXT,
                'label' => esc_html__('Button Label', 'purefit-core'),
                'default' => esc_html__( 'Learn More', 'textdomain' ),
                'label_block' => true,
            ]
        );
        $this->add_control(
            'note_label',
            [
                'type' => Controls_Manager::RAW_HTML,
                'raw' => sprintf(
                    '<div class="elementor-panel-alert elementor-panel-alert-info">
                <p>%s</p>
            </div>',
                    sprintf(
                        __('Please note! Customize your selected Service using Elementor. You can find it under <a href="%s" target="_blank">Services</a>.', 'auxa-core'),
                        admin_url('edit.php?post_type=auxa_service')
                    )
                ),
                'content_classes' => 'elementor-notice-container',
            ]
        );

        $this->end_controls_section();


        $this->start_controls_section(
            'color_option',
            [
                'label' => esc_html__('Style', 'auxa-core'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );
        $this->add_group_control(
            Group_Control_Background::get_type(),
            [
                'name' => 'hover_overlay_color',
                'types' => ['gradient'],
                'exclude' => ['image'],
                'selector' => '{{WRAPPER}} .dm-service::before',
                'fields_options' => [
                    'background' => [
                        'label' => esc_html__('Hover Overlay Color', 'xpress-core'),
                    ]
                ]
            ]
        );
        $this->add_control(
            'border_c',
            [
                'label' => esc_html__('Border Color', 'ovix-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .dm-service' => 'border-color: {{VALUE}}',
                ],
            ]
        );
        $this->add_control(
            'title_hr',
            [
                'type' => \Elementor\Controls_Manager::DIVIDER,
            ]
        );
        $this->add_control(
            'title-c',
            [
                'label' => esc_html__('Title Color', 'auxa-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .dm-service .xb-item--title' => 'color: {{VALUE}}',
                ],
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'title_typography',
                'selector' => '{{WRAPPER}} .dm-service .xb-item--title',
            ]
        );
        $this->add_control(
            'content_hr',
            [
                'type' => \Elementor\Controls_Manager::DIVIDER,
            ]
        );
        $this->add_control(
            'content-c',
            [
                'label' => esc_html__('Content Color', 'auxa-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .dm-service .xb-item--content' => 'color: {{VALUE}}',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'content_typography',
                'selector' => '{{WRAPPER}} .dm-service .xb-item--content',
            ]
        );
        $this->add_control(
            'image_hr',
            [
                'type' => \Elementor\Controls_Manager::DIVIDER,
            ]
        );
        $this->add_control(
            'filter-img',
            [
                'label' => esc_html__('Filter Image', 'auxa-core'),
                'type' => \Elementor\Controls_Manager::SLIDER,
                'size_units' => ['%'],
                'range' => [
                    '%' => [
                        'min' => 0,
                        'max' => 100,
                    ],
                ],
                'default' => [
                    'unit' => '%',
                    'size' => 100,
                ],
                'selectors' => [
                    '{{WRAPPER}} .dm-service .xb-item--image' => 'filter: grayscale({{SIZE}}{{UNIT}});',
                ],
            ]
        );
        $this->add_control(
            'filter-hover-img',
            [
                'label' => esc_html__('Filter Hover Image', 'auxa-core'),
                'type' => \Elementor\Controls_Manager::SLIDER,
                'size_units' => ['%'],
                'range' => [
                    '%' => [
                        'min' => 0,
                        'max' => 100,
                    ],
                ],
                'default' => [
                    'unit' => '%',
                    'size' => 0,
                ],
                'selectors' => [
                    '{{WRAPPER}} .dm-service:hover .xb-item--image' => 'filter: grayscale({{SIZE}}{{UNIT}});',
                ],
            ]
        );
        $this->add_control(
            'margin',
            [
                'label' => esc_html__('Margin', 'ovix-core'),
                'type' => \Elementor\Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em', 'rem', 'custom'],
                'selectors' => [
                    '{{WRAPPER}} .dm-service .xb-item--image' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );
        $this->add_control(
            'learn_more_hr',
            [
                'type' => \Elementor\Controls_Manager::DIVIDER,
            ]
        );
        $this->add_control(
            'learnmore-c',
            [
                'label' => esc_html__('Learn More Color', 'purefit-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .dm-service .xb-item--srv_link a' => 'color: {{VALUE}}',
                ],
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'learnmore_typography',
                'selector' => '{{WRAPPER}} .dm-service .xb-item--srv_link a',
            ]
        );
        $this->add_control(
            'lm_icon-c',
            [
                'label' => esc_html__('Icon Border Color', 'auxa-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .dm-service .xb-item--srv_link a span' => 'border-color: {{VALUE}}',
                ],
            ]
        );

        $this->end_controls_section();


    }

    protected function render() {
        $settings = $this->get_settings_for_display();
        $arrow_icon = AUXA_DIR_URL . 'assets/img/dm-srv.png';

        if (!empty($settings['lists'])) :
            ?>
            <div class="services-inner pos-rel">
                <div class="services-bg bg_img" <?php if (!empty($settings['bg_image']['url'])): ?>
                     style="background-image: url('<?php echo esc_url($settings['bg_image']['url']); ?>') <?php endif; ?>"></div>
                <div class="dm-service-slider">
                    <div class="swiper-wrapper">
                        <?php
                        $counter = 1;
                        foreach ($settings['lists'] as $a) {
                            if (isset($a['template']) && !empty($a['template'])) {
                                $service_post = get_post($a['template']);

                                if ($service_post instanceof \WP_Post) {
                                    $service_title = esc_html($service_post->post_title);
                                    $service_permalink = esc_url(get_permalink($service_post));
                                    ?>
                                    <div class="swiper-slide dm-service">
                                        <div class="xb-item--holder">
                                            <h2 class="xb-item--title"><a href="<?php echo $service_permalink; ?>">.<?php echo sprintf('%02d', $counter); ?>
                                                    <br> <?php echo $service_title; ?></a></h2>
                                            <div class="xb-item--content"><?php echo wp_kses($a['desc'], true); ?></div>
                                        </div>
                                        <div class="xb-item--image"><?php echo wp_get_attachment_image($a['image']['id'], 'full'); ?></div>
                                        <div class="xb-item--srv_link">
                                            <a href="<?php echo $service_permalink; ?>"><?php echo esc_html($settings['btn_label']); ?>
                                                <span><img
                                                            src="<?php echo esc_url($arrow_icon); ?>" alt=""></span></a>
                                        </div>
                                    </div>
                                    <?php
                                    $counter++;
                                }
                            }
                        }
                        ?>
                    </div>
                </div>
            </div>
        <?php
        endif;
    }



    protected function template_select()
    {
        $type = 'auxa_service';
        global $post;
        $args = array('numberposts' => -1, 'post_type' => $type,);
        $posts = get_posts($args);
        $categories = array(
            '' => __('Select', 'auxa-core'),
        );
        foreach ($posts as $pn_cat) {
            $categories[$pn_cat->ID] = get_the_title($pn_cat->ID);
        }
        return $categories;
    }

    protected function render_template($id)
    {
        return Plugin::instance()->frontend->get_builder_content_for_display($id);
    }

}


Plugin::instance()->widgets_manager->register(new Auxa_Service_V6());