<?php

/**
 * Elementor Single Widget
 * @package auxa-core
 * @since 1.0.0
 */

namespace Elementor;

if (!defined('ABSPATH')) exit; // Exit if accessed directly.

class Auxa_Service extends Widget_Base
{

    /**
     * Get widget name.
     *
     * Retrieve Elementor widget name.
     *
     * @return string Widget name.
     * @since 1.0.0
     * @access public
     *
     */
    public function get_name()
    {
        return 'int-service';
    }

    /**
     * Get widget title.
     *
     * Retrieve Elementor widget title.
     *
     * @return string Widget title.
     * @since 1.0.0
     * @access public
     *
     */
    public function get_title()
    {
        return esc_html__('Service', 'auxa-core');
    }

    /**
     * Get widget icon.
     *
     * Retrieve Elementor widget icon.
     *
     * @return string Widget icon.
     * @since 1.0.0
     * @access public
     *
     */
    public function get_icon()
    {
        return 'auxa-custom-icon';
    }

    /**
     * Get widget categories.
     *
     * Retrieve the list of categories the Elementor widget belongs to.
     *
     * @return array Widget categories.
     * @since 1.0.0
     * @access public
     *
     */
    public function get_categories()
    {
        return ['auxa_widgets'];
    }


    protected function register_controls()
    {
        $this->start_controls_section(
            'service_option',
            [
                'label' => esc_html__('Service', 'auxa-core'),
                'tab' => Controls_Manager::TAB_CONTENT,
            ]
        );

        $repeater = new \Elementor\Repeater();

        $repeater->add_control(
            'template',
            [
                'type' => Controls_Manager::SELECT2,
                'options' => $this->template_select(),
                'multiple' => false,
                'label' => esc_html__('Service', 'thepack'),
                'label_block' => true,
            ]
        );

        $repeater->add_control(
            'desc', [
                'label' => esc_html__('Description', 'auxa-core'),
                'type' => Controls_Manager::TEXTAREA,
                'label_block' => true,
            ]
        );
        $repeater->add_control(
			'icon',
			[
				'label' => esc_html__( 'Icon', 'auxa-core' ),
				'type' => \Elementor\Controls_Manager::ICONS,
			]
		);
        $repeater->add_control(
            'shape',
            [
                'label' => esc_html__( 'Hover Shape', 'auxa-core' ),
                'type' => \Elementor\Controls_Manager::MEDIA,
            ]
        );

        $this->add_control(
            'lists',
            [
                'type' => Controls_Manager::REPEATER,
                'fields' => $repeater->get_controls(),
                'prevent_empty' => false,
            ]
        );
        $this->add_control(
            'note_label',
            [
                'type' => Controls_Manager::RAW_HTML,
                'raw' => sprintf(
                    '<div class="elementor-panel-alert elementor-panel-alert-info">
                <p>%s</p>
            </div>',
                    sprintf(
                        __('Please note! Customize your selected Service using Elementor. You can find it under <a href="%s" target="_blank">Services</a>.', 'auxa-core'),
                        admin_url('edit.php?post_type=auxa_service')
                    )
                ),
                'content_classes' => 'elementor-notice-container',
            ]
        );
        $this->end_controls_section();


        $this->start_controls_section(
            'color_option',
            [
                'label' => esc_html__('Style', 'auxa-core'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );
        $this->add_control(
            'icon_bg-c',
            [
                'label' => esc_html__('Icon BG Color', 'auxa-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .xb-service-box .xb-item--icon' => 'background-color: {{VALUE}}',
                ],
            ]
        );
        $this->start_controls_tabs(
			'style_tabs'
		);

		$this->start_controls_tab(
			'style_normal_tab',
			[
				'label' => esc_html__( 'Normal', 'textdomain' ),
			]
		);
        $this->add_control(
            'service-bg-c',
            [
                'label' => esc_html__('Background Color', 'auxa-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .xb-service-box' => 'background-color: {{VALUE}}',
                ],
            ]
        );
        $this->add_control(
			'title_hr',
			[
				'type' => \Elementor\Controls_Manager::DIVIDER,
			]
		);
        $this->add_control(
            'title-c',
            [
                'label' => esc_html__('Title Color', 'auxa-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .xb-service-box .xb-item--title' => 'color: {{VALUE}}',
                ],
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'title_typography',
                'selector' => '{{WRAPPER}} .xb-service .xb-item--title',
            ]
        );
        $this->add_control(
			'content_hr',
			[
				'type' => \Elementor\Controls_Manager::DIVIDER,
			]
		);
        $this->add_control(
            'content-c',
            [
                'label' => esc_html__('Content Color', 'auxa-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .xb-service-box .xb-item--content' => 'color: {{VALUE}}',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'content_typography',
                'selector' => '{{WRAPPER}} .xb-service-box .xb-item--content',
            ]
        );

		$this->end_controls_tab();

		$this->start_controls_tab(
			'style_hover_tab',
			[
				'label' => esc_html__( 'Hover', 'textdomain' ),
			]
		);

        $this->add_control(
            'hservice-bg-c',
            [
                'label' => esc_html__('Background Color', 'auxa-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .xb-service-box:hover' => 'background-color: {{VALUE}}',
                ],
            ]
        );
        $this->add_control(
            'htitle_hr',
            [
                'type' => \Elementor\Controls_Manager::DIVIDER,
            ]
        );
        $this->add_control(
            'htitle-c',
            [
                'label' => esc_html__('Title Color', 'auxa-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .xb-service-box:hover .xb-item--title' => 'color: {{VALUE}}',
                ],
            ]
        );
        $this->add_control(
            'hcontent_hr',
            [
                'type' => \Elementor\Controls_Manager::DIVIDER,
            ]
        );
        $this->add_control(
            'hcontent-c',
            [
                'label' => esc_html__('Content Color', 'auxa-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .xb-service-box:hover .xb-item--content' => 'color: {{VALUE}}',
                ],
            ]
        );

		$this->end_controls_tab();

		$this->end_controls_tabs();
        
        

        $this->end_controls_section();


    }

    protected function render()
    {
        $settings = $this->get_settings_for_display();
    
        // Check if 'lists' is not empty
        if (!empty($settings['lists'])) {
            echo '<div class="row mt-none-30">';
    
            foreach ($settings['lists'] as $a) {
                // Check if 'template' key is set in the array and is not empty
                if (isset($a['template']) && !empty($a['template'])) {
                    $service_post = get_post($a['template']);
    
                    // Check if $service_post is not empty and is a valid post object
                    if ($service_post instanceof \WP_Post) {
                        $service_title = esc_html($service_post->post_title);
                        $service_permalink = esc_url(get_permalink($service_post));
    
                        ?>
                        <div class="col-lg-6 mt-30">
                            <div class="xb-service-box">
                                <div class="xb-item--inner ul_li">
                                    <div class="xb-item--icon">
                                    <?php \Elementor\Icons_Manager::render_icon( $a['icon'], [ 'aria-hidden' => 'true' ] ); ?>
                                    </div>
                                    <div class="xb-item--holder">
                                        <h3 class="xb-item--title"><?php echo $service_title; ?></h3>
                                        <p class="xb-item--content"><?php echo wp_kses($a['desc'], true); ?></p>
                                    </div>
                                    <span class="xb-item--shape">
                                        <?php echo wp_get_attachment_image($a['shape']['id'], 'full'); ?>
                                    </span>
                                    <a class="xb-overlay" href="<?php echo $service_permalink; ?>"></a>
                                </div>
                            </div>
                        </div>
                        <?php
                    }
                }
            }
    
            echo '</div>';
        }
    }

    protected function template_select()
    {
        $type = 'auxa_service';
        global $post;
        $args = array('numberposts' => -1, 'post_type' => $type,);
        $posts = get_posts($args);
        $categories = array(
            '' => __('Select', 'auxa-core'),
        );
        foreach ($posts as $pn_cat) {
            $categories[$pn_cat->ID] = get_the_title($pn_cat->ID);
        }
        return $categories;
    }

    protected function render_template($id)
    {
        return Plugin::instance()->frontend->get_builder_content_for_display($id);
    }

}


Plugin::instance()->widgets_manager->register(new Auxa_Service());