<?php

/**
 * Elementor Single Widget
 * @package auxa-core
 * @since 1.0.0
 */

namespace Elementor;

if (!defined('ABSPATH')) exit; // Exit if accessed directly.

class Auxa_Story extends Widget_Base
{

    /**
     * Get widget name.
     *
     * Retrieve Elementor widget name.
     *
     * @return string Widget name.
     * @since 1.0.0
     * @access public
     *
     */
    public function get_name()
    {
        return 'int-story';
    }

    /**
     * Get widget title.
     *
     * Retrieve Elementor widget title.
     *
     * @return string Widget title.
     * @since 1.0.0
     * @access public
     *
     */
    public function get_title()
    {
        return esc_html__('Story', 'auxa-core');
    }

    /**
     * Get widget icon.
     *
     * Retrieve Elementor widget icon.
     *
     * @return string Widget icon.
     * @since 1.0.0
     * @access public
     *
     */
    public function get_icon()
    {
        return 'auxa-custom-icon';
    }

    /**
     * Get widget categories.
     *
     * Retrieve the list of categories the Elementor widget belongs to.
     *
     * @return array Widget categories.
     * @since 1.0.0
     * @access public
     *
     */
    public function get_categories()
    {
        return ['auxa_widgets'];
    }

    protected function register_controls()
    {

        $this->start_controls_section(
            'story_option',
            [
                'label' => esc_html__('Story', 'auxa-core'),
                'tab' => Controls_Manager::TAB_CONTENT,
            ]
        );
        $repeater = new \Elementor\Repeater();

        $repeater->add_control(
            'image',
            [
                'label' => esc_html__('Image', 'auxa-core'),
                'type' => \Elementor\Controls_Manager::MEDIA,
            ]
        );
        $repeater->add_control(
            'content', [
                'label' => esc_html__('Content', 'xpress-core'),
                'type' => Controls_Manager::TEXTAREA,
                'label_block' => true,
            ]
        );
        $repeater->add_control(
            'btn_label',
            [
                'type' => Controls_Manager::TEXT,
                'label' => esc_html__('Button Label', 'auxa-core'),
                'label_block' => true,
            ]
        );
        $repeater->add_control(
            'link',
            [
                'label' => esc_html__('Link', 'xprss-core'),
                'type' => \Elementor\Controls_Manager::URL,
                'options' => ['url'],
                'default' => [
                    'url' => '#',
                ],
                'label_block' => true,
            ]
        );

        $this->add_control(
            'lists',
            [
                'label' => esc_html__('Add Story Item', 'xpress-core'),
                'type' => \Elementor\Controls_Manager::REPEATER,
                'fields' => $repeater->get_controls(),
            ],
        );
        $this->end_controls_section();

        $this->start_controls_section(
            'story_style',
            [
                'label' => esc_html__('Style', 'auxa-core'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );
        $this->add_control(
            'padding',
            [
                'label' => esc_html__('Padding', 'auxa-core'),
                'type' => \Elementor\Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em', 'rem', 'custom'],
                'selectors' => [
                    '{{WRAPPER}} .xb-story' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );
        $this->add_control(
            'content_hr',
            [
                'type' => \Elementor\Controls_Manager::DIVIDER,
            ]
        );
        $this->add_control(
            'content-c',
            [
                'label' => esc_html__('Content Color', 'auxa-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .xb-story .xb-item--title' => 'color: {{VALUE}}',
                ],
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'content_typography',
                'selector' => '{{WRAPPER}} .xb-story .xb-item--title',
            ]
        );
        $this->add_control(
            'link_style',
            [
                'label' => esc_html__('Link Style', 'auxa-core'),
                'type' => \Elementor\Controls_Manager::HEADING,
                'separator' => 'before',
            ]
        );
        $this->start_controls_tabs(
            'style_tabs'
        );

        $this->start_controls_tab(
            'style_normal_tab',
            [
                'label' => esc_html__('Normal', 'auxa-core'),
            ]
        );

        $this->add_control(
            'link_border-c',
            [
                'label' => esc_html__('Link Border Color', 'auxa-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .xb-story .xb-item--link svg path' => 'stroke: {{VALUE}}',
                ],
            ]
        );
        $this->add_control(
            'link_icon-c',
            [
                'label' => esc_html__('Link Icon Color', 'auxa-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .xb-story .xb-item--link i' => 'color: {{VALUE}}',
                ],
            ]
        );
        $this->add_control(
            'link_label-c',
            [
                'label' => esc_html__('Link Label Color', 'auxa-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .xb-story .xb-item--readmore' => 'color: {{VALUE}}',
                ],
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'link_label_typography',
                'selector' => '{{WRAPPER}} .xb-story .xb-item--readmore',
            ]
        );

        $this->end_controls_tab();

        $this->start_controls_tab(
            'style_hover_tab',
            [
                'label' => esc_html__('Hover', 'auxa-core'),
            ]
        );

        $this->add_control(
            'hlink_border-c',
            [
                'label' => esc_html__('Link Border Color', 'auxa-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .xb-story:hover .xb-item--link svg path' => 'stroke: {{VALUE}}',
                ],
            ]
        );
        $this->add_control(
            'hlink_icon-c',
            [
                'label' => esc_html__('Link Icon Color', 'auxa-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .xb-story:hover .xb-item--link i' => 'color: {{VALUE}}',
                ],
            ]
        );
        $this->add_control(
            'hlink_label-c',
            [
                'label' => esc_html__('Link Label Color', 'auxa-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .xb-story:hover .xb-item--readmore' => 'color: {{VALUE}}',
                ],
            ]
        );

        $this->end_controls_tab();

        $this->end_controls_tabs();
        $this->end_controls_section();

    }


    protected function render()
    {
        $settings = $this->get_settings_for_display();
        $shape = AUXA_DIR_URL . 'assets/img/str_shape.png';
        ?>
        <div class="row justify-content-center mt-none-30">
            <?php
            foreach ($settings['lists'] as $index =>  $list):
                $str_bg_id = 'str_bg_' . $index;
                ?>
                <div class="col-xl-4 col-lg-6 col-md-6 mt-30">
                    <div class="xb-story text-center wow fadeInUp" data-wow-duration=".7s" data-wow-delay="<?php echo esc_attr($index * 2); ?>00ms">
                        <div class="xb-item--shape xb-svg">
                            <svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 410 598" fill="none"
                                 preserveAspectRatio="none">
                                <path d="M0 54.2449C0 45.6582 5.49251 38.0084 13.6594 35.3564C160.806 -12.4259 249.083 -11.1632 396.187 35.425C404.432 38.0361 410 45.7236 410 54.3717V545.835C410 554.596 404.292 562.355 395.9 564.871C249.109 608.878 160.852 609.202 14.0593 564.89C5.68765 562.363 0 554.613 0 545.869V54.2449Z"
                                      fill="url(#<?php echo esc_attr($str_bg_id); ?>)"/>
                                <path d="M0.5 54.2449C0.5 45.8721 5.85555 38.4162 13.8139 35.8319C87.3579 11.9503 146.158 0.335542 204.938 0.501758C263.718 0.667978 322.509 12.6156 396.036 35.9017C404.071 38.4462 409.5 45.9391 409.5 54.3717V545.835C409.5 554.378 403.934 561.94 395.757 564.392C322.387 586.387 263.676 597.457 204.98 597.5C146.284 597.543 87.5736 586.559 14.2038 564.411C6.04582 561.948 0.5 554.396 0.5 545.869V54.2449Z"
                                      stroke="url(#paint1_linear_144_245)" stroke-opacity="0.1"/>
                                <defs>
                                    <linearGradient id="<?php echo esc_attr($str_bg_id); ?>" x1="205" y1="0" x2="205" y2="598"
                                                    gradientUnits="userSpaceOnUse">
                                        <stop offset="0" stop-color="#060613"/>
                                        <stop offset="1" stop-color="#151521"/>
                                    </linearGradient>
                                    <linearGradient id="<?php echo esc_attr($str_bg_id); ?>" x1="205" y1="0" x2="205" y2="598"
                                                    gradientUnits="userSpaceOnUse">
                                        <stop offset="0" stop-color="white"/>
                                        <stop offset="1" stop-color="white" stop-opacity="0"/>
                                    </linearGradient>
                                </defs>
                            </svg>
                        </div>
                        <div class="xb-item--line-shape">
                            <img src="<?php echo esc_url($shape); ?>" alt="">
                        </div>
                        <div class="xb-item--holder">
                            <?php if (!empty($list['image']['id'])): ?>
                                <div class="xb-item--image">
                                    <?php echo wp_get_attachment_image($list['image']['id'], 'medium'); ?>
                                </div>
                            <?php endif; ?>
                            <?php if (!empty($list['content'])): ?>
                                <h3 class="xb-item--title border-effect-2"><a
                                            href="<?php echo esc_url($list['link']['url']); ?>"><?php echo wp_kses($list['content'], true); ?></a></h3>
                            <?php endif; ?>
                            <?php if (!empty($list['btn_label'])): ?>
                                <div class="xb-item--link-inner">
                                    <a href="<?php echo esc_url($list['link']['url']); ?>" class="xb-item--link"><i class="far fa-long-arrow-up"></i><span
                                                class="xb-svg"><svg xmlns="http://www.w3.org/2000/svg"
                                                                    viewBox="0 0 59 48"
                                                                    fill="none" preserveAspectRatio="none">
                                        <path d="M5.02153 4.43458C5.96248 2.03868 8.31753 0.5 10.9116 0.5H49.3176C52.0998 0.5 54.5817 2.26162 55.3669 4.9041C59.4723 18.7196 59.1586 28.358 55.2626 42.8516C54.5201 45.6138 51.9784 47.5 49.101 47.5H10.777C8.24614 47.5 5.93564 46.0375 4.96528 43.7247C2.01951 36.7035 0.516219 30.7738 0.500131 24.6691C0.484037 18.5621 1.95611 12.24 5.02153 4.43458Z"
                                              stroke="white"/>
                                      </svg></span></a>
                                    <div class="clearfix"></div>
                                    <a href="<?php echo esc_url($list['link']['url']); ?>" class="xb-item--readmore"><?php echo esc_html($list['btn_label']); ?></a>
                                </div>
                            <?php endif; ?>
                        </div>
                    </div>
                </div>
            <?php endforeach; ?>
        </div>
        <?php
    }

}


Plugin::instance()->widgets_manager->register(new Auxa_Story());