<?php

/**
 * Elementor Single Widget
 * @package auxa-core
 * @since 1.0.0
 */

namespace Elementor;

if (!defined('ABSPATH')) exit; // Exit if accessed directly.

class Auxa_Team_V3 extends Widget_Base
{

    /**
     * Get widget name.
     *
     * Retrieve Elementor widget name.
     *
     * @return string Widget name.
     * @since 1.0.0
     * @access public
     *
     */
    public function get_name()
    {
        return 'int-team-v3';
    }

    /**
     * Get widget title.
     *
     * Retrieve Elementor widget title.
     *
     * @return string Widget title.
     * @since 1.0.0
     * @access public
     *
     */
    public function get_title()
    {
        return esc_html__('Team V3', 'auxa-core');
    }

    /**
     * Get widget icon.
     *
     * Retrieve Elementor widget icon.
     *
     * @return string Widget icon.
     * @since 1.0.0
     * @access public
     *
     */
    public function get_icon()
    {
        return 'auxa-custom-icon';
    }

    /**
     * Get widget categories.
     *
     * Retrieve the list of categories the Elementor widget belongs to.
     *
     * @return array Widget categories.
     * @since 1.0.0
     * @access public
     *
     */
    public function get_categories()
    {
        return ['auxa_widgets'];
    }


    protected function register_controls()
    {

        $this->start_controls_section(
            'section_title_option',
            [
                'label' => esc_html__('Section Title', 'auxa-core'),
                'tab' => Controls_Manager::TAB_CONTENT,
            ]
        );
        $this->add_control(
            'shape',
            [
                'label' => esc_html__('Shape', 'auxa-core'),
                'type' => \Elementor\Controls_Manager::MEDIA,
            ]
        );
        $this->add_control(
            'sub_title_hr',
            [
                'type' => \Elementor\Controls_Manager::DIVIDER,
            ]
        );
        $this->add_control(
            'sub_title',
            [
                'type' => Controls_Manager::TEXT,
                'label' => esc_html__('Sub Title', 'auxa-core'),
                'label_block' => true,
            ]
        );
        $this->add_control(
            'title',
            [
                'type' => Controls_Manager::TEXTAREA,
                'label' => esc_html__('Title', 'auxa-core'),
                'label_block' => true,
            ]
        );
        $this->add_control(
            'button_hr',
            [
                'type' => \Elementor\Controls_Manager::DIVIDER,
            ]
        );
        $this->add_control(
            'btn_label',
            [
                'type' => Controls_Manager::TEXT,
                'label' => esc_html__('Button Label', 'auxa-core'),
                'label_block' => true,
            ]
        );
        $this->add_control(
            'btn_icon',
            [
                'label' => esc_html__('Button Icon', 'auxa-core'),
                'type' => \Elementor\Controls_Manager::ICONS,
            ]
        );
        $this->add_control(
            'btn_link',
            [
                'label' => esc_html__('Button Link', 'xprss-core'),
                'type' => \Elementor\Controls_Manager::URL,
                'options' => ['url'],
                'default' => [
                    'url' => '#',
                ],
                'label_block' => true,
            ]
        );

        $this->end_controls_section();

        $this->start_controls_section(
            'team_option',
            [
                'label' => esc_html__('Team', 'auxa-core'),
                'tab' => Controls_Manager::TAB_CONTENT,
            ]
        );

        $repeater = new \Elementor\Repeater();
        $repeater->add_control(
            'avatar',
            [
                'label' => esc_html__('Avatar', 'auxa-core'),
                'type' => \Elementor\Controls_Manager::MEDIA,
            ]
        );
        $repeater->add_control(
            'name',
            [
                'type' => Controls_Manager::TEXT,
                'label' => esc_html__('Name', 'auxa-core'),
                'label_block' => true,
            ]
        );
        $repeater->add_control(
            'content',
            [
                'type' => Controls_Manager::TEXTAREA,
                'label' => esc_html__('Content', 'auxa-core'),
                'label_block' => true,
            ]
        );
        $repeater->add_control(
            'skill_title',
            [
                'type' => Controls_Manager::TEXT,
                'label' => esc_html__('Skill Title', 'auxa-core'),
                'label_block' => true,
            ]
        );
        $repeater->add_control(
            'skill1',
            [
                'type' => Controls_Manager::TEXT,
                'label' => esc_html__('Skill 1', 'auxa-core'),
                'label_block' => true,
            ]
        );
        $repeater->add_control(
            'skill2',
            [
                'type' => Controls_Manager::TEXT,
                'label' => esc_html__('Skill 2', 'auxa-core'),
                'label_block' => true,
            ]
        );
        $this->add_control(
            'lists',
            [
                'type' => Controls_Manager::REPEATER,
                'fields' => $repeater->get_controls(),
                'title_field' => '{{{ name }}}',
            ]
        );

        $this->add_control(
            'active',
            [
                'label' => esc_html__('Show Pagination', 'auxa-core'),
                'type' => \Elementor\Controls_Manager::SWITCHER,
                'label_on' => esc_html__('Show', 'auxa-core'),
                'label_off' => esc_html__('Hide', 'auxa-core'),
                'return_value' => 'yes',
                'default' => 'yes',
            ]
        );
        $this->end_controls_section();


        $this->start_controls_section(
            'section_title_style',
            [
                'label' => esc_html__('Section Title', 'auxa-core'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );
        $this->add_control(
            'sub_title-c',
            [
                'label' => esc_html__('Sub Title Color', 'auxa-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .team-sec-title .xb-item--sub-title' => 'color: {{VALUE}}',
                ],
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'sub_title_typography',
                'selector' => '{{WRAPPER}} .team-sec-title .xb-item--sub-title',
            ]
        );
        $this->add_control(
            'title_hr',
            [
                'type' => \Elementor\Controls_Manager::DIVIDER,
            ]
        );
        $this->add_control(
            'title-c',
            [
                'label' => esc_html__('Title Color', 'auxa-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .team-sec-title .xb-item--title' => 'color: {{VALUE}}',
                ],
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'title_typography',
                'selector' => '{{WRAPPER}} .team-sec-title .xb-item--sub-title',
            ]
        );
        $this->add_control(
            'btn_style',
            [
                'label' => esc_html__('Button Style', 'auxa-core'),
                'type' => \Elementor\Controls_Manager::HEADING,
                'separator' => 'before',
            ]
        );
        $this->add_control(
            'btn_padding',
            [
                'label' => esc_html__('Padding', 'auxa-core'),
                'type' => \Elementor\Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em', 'rem', 'custom'],
                'selectors' => [
                    '{{WRAPPER}} .thm-btn' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'btn_typography',
                'selector' => '{{WRAPPER}} .thm-btn',
            ]
        );

        $this->start_controls_tabs(
            'style_tabs'
        );

        $this->start_controls_tab(
            'style_normal_tab',
            [
                'label' => esc_html__('Normal', 'auxa-core'),
            ]
        );

        $this->add_control(
            'btn_color',
            [
                'label' => esc_html__('Button Color', 'auxa-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .thm-btn' => 'color: {{VALUE}}',
                    '{{WRAPPER}} .thm-btn .icon svg path' => 'fill: {{VALUE}}',
                ],
            ]
        );
        $this->add_control(
            'btn_bg_color',
            [
                'label' => esc_html__('Button BG Color', 'auxa-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .thm-btn .btn-shape svg path' => 'fill: {{VALUE}}',
                ],
            ]
        );

        $this->end_controls_tab();

        $this->start_controls_tab(
            'style_hover_tab',
            [
                'label' => esc_html__('Hover', 'auxa-core'),
            ]
        );

        $this->add_control(
            'h_btn_color',
            [
                'label' => esc_html__('Button Color', 'auxa-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .thm-btn .btn-anim-wrap .button-text:nth-child(2)' => 'color: {{VALUE}}',
                    '{{WRAPPER}} .thm-btn:hover .icon svg path' => 'fill: {{VALUE}}',
                ],
            ]
        );
        $this->add_control(
            'h_btn_bg_color',
            [
                'label' => esc_html__('Button BG Color', 'auxa-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .thm-btn:hover .btn-shape svg path' => 'fill: {{VALUE}}',
                ],
            ]
        );
        $this->end_controls_tab();
        $this->end_controls_tabs();
        $this->end_controls_section();

        $this->start_controls_section(
            'team_style',
            [
                'label' => esc_html__('Team Style', 'auxa-core'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );
        $this->add_control(
            'name-c',
            [
                'label' => esc_html__('Title Color', 'auxa-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .xb-service-box .xb-item--title' => 'color: {{VALUE}}',
                ],
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'name_typography',
                'selector' => '{{WRAPPER}} .xb-service-box .xb-item--title',
            ]
        );
        $this->add_control(
            't_content_hr',
            [
                'type' => \Elementor\Controls_Manager::DIVIDER,
            ]
        );
        $this->add_control(
            't_content-c',
            [
                'label' => esc_html__('Content Color', 'auxa-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .xb-team-two .xb-item--sub-title' => 'color: {{VALUE}}',
                ],
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 't_content_typography',
                'selector' => '{{WRAPPER}} .xb-team-two .xb-item--sub-title',
            ]
        );
        $this->add_control(
            't_skill_title_hr',
            [
                'type' => \Elementor\Controls_Manager::DIVIDER,
            ]
        );
        $this->add_control(
            't_skill_title-c',
            [
                'label' => esc_html__('Skill Title Color', 'auxa-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .xb-team-two .xb-item--skill-tilte' => 'color: {{VALUE}}',
                ],
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 't_skill_title_typography',
                'selector' => '{{WRAPPER}} .xb-team-two .xb-item--skill-tilte',
            ]
        );
        $this->add_control(
            't_skill_hr',
            [
                'type' => \Elementor\Controls_Manager::DIVIDER,
            ]
        );
        $this->add_control(
            't_skill-c',
            [
                'label' => esc_html__('Skill Color', 'auxa-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .xb-team-two .xb-item--skill li' => 'color: {{VALUE}}',
                ],
            ]
        );
        $this->add_control(
            't_skill_bg-c',
            [
                'label' => esc_html__('Skill BG Color', 'auxa-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .xb-team-two .xb-item--skill li' => 'background: {{VALUE}}',
                ],
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 't_skill_typography',
                'selector' => '{{WRAPPER}} .xb-team-two .xb-item--skill li',
            ]
        );
        $this->add_control(
            'dot_style_hr',
            [
                'type' => \Elementor\Controls_Manager::DIVIDER,
            ]
        );
        $this->add_control(
            'dot-c',
            [
                'label' => esc_html__('Pagination Color', 'auxa-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .swiper-pagination-bullet' => 'background-color: {{VALUE}}',
                ],
            ]
        );
        $this->add_control(
            'dot-active-c',
            [
                'label' => esc_html__('Pagination Active Color', 'auxa-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .swiper-pagination-bullet.swiper-pagination-bullet-active' => 'background-color: {{VALUE}}',
                ],
            ]
        );
        $this->end_controls_section();

    }


    protected function render()
    {
        $settings = $this->get_settings_for_display();
        $target = $settings['btn_link']['is_external'] ? ' target="_blank"' : '';
        $nofollow = $settings['btn_link']['nofollow'] ? ' rel="nofollow"' : '';
        $pagination_active = $settings['active'] === 'yes';
        ?>
        <div class="xb-team-inner pos-rel">
            <?php if (!empty($settings['shape']['id'])): ?>
                <div class="xb-team-shape">
                    <?php echo wp_get_attachment_image($settings['shape']['id'], 'full'); ?>
                </div>
            <?php endif; ?>
            <div class="row align-items-center mt-none-40">
                <div class="col-lg-6 mt-40">
                    <div class="team-sec-title">
                        <?php if (!empty($settings['sub_title'])): ?>
                            <p class="xb-item--sub-title"><?php echo esc_html($settings['sub_title']); ?></p>
                        <?php endif; ?>
                        <?php if (!empty($settings['title'])): ?>
                            <h2 class="xb-item--title mb-40"><?php echo wp_kses($settings['title'], true); ?></h2>
                        <?php endif; ?>
                        <?php if (!empty($settings['btn_label'])): ?>
                            <a href="<?php echo esc_url($settings['btn_link']['url']); ?>" <?php echo $target . $nofollow; ?>
                               class="thm-btn thm-btn--anim">
                                    <span class="btn-shape">
                                      <svg xmlns="http://www.w3.org/2000/svg" width="203" height="68"
                                           viewBox="0 0 203 68" fill="none" preserveAspectRatio="none">
                                        <path d="M5.16873 4.91568C5.692 2.06786 8.17444 0 11.0699 0H192.577C195.559 0 198.089 2.19074 198.515 5.14266L201.893 28.5403C202.324 31.5288 202.331 34.5632 201.912 37.5534L198.497 61.9251C198.081 64.8882 195.547 67.0925 192.555 67.0925H11.0966C8.18925 67.0925 5.70023 65.0081 5.18979 62.1459L1.01714 38.7489C0.344515 34.9773 0.354618 31.1156 1.04697 27.3476L5.16873 4.91568Z"
                                              fill="#C4EF17"/>
                                      </svg>
                                    </span>
                                <div class="btn-anim-wrap">
                                    <span class="button-text"><?php echo esc_html($settings['btn_label']); ?></span>
                                    <span class="button-text"><?php echo esc_html($settings['btn_label']); ?></span>
                                </div>
                                <span class="icon"><?php \Elementor\Icons_Manager::render_icon($settings['btn_icon'], ['aria-hidden' => 'true']); ?></span>
                            </a>
                        <?php endif; ?>
                    </div>
                </div>
                <div class="col-lg-6 mt-40">
                    <div class="team-slider-two swiper-container">
                        <div class="swiper-wrapper">
                            <?php
                            foreach ($settings['lists'] as $list):
                                ?>
                                <div class="swiper-slide">
                                    <div class="xb-team-two ul_li">
                                        <?php if (!empty($list['avatar']['id'])): ?>
                                            <div class="xb-item--img">
                                                <?php echo wp_get_attachment_image($list['avatar']['id'], 'thumbnail'); ?>
                                            </div>
                                        <?php endif; ?>
                                        <div class="xb-item--content">
                                            <?php if (!empty($list['name'])): ?>
                                                <h3 class="xb-item--title"><?php echo esc_html($list['name']); ?></h3>
                                            <?php endif; ?>
                                            <?php if (!empty($list['content'])): ?>
                                                <h6 class="xb-item--sub-title"><?php echo wp_kses($list['content'], true); ?></h6>
                                            <?php endif; ?>
                                        </div>
                                        <div>
                                            <?php if (!empty($list['skill_title'])): ?>
                                                <h6 class="xb-item--skill-tilte"><?php echo esc_html($list['skill_title']); ?></h6>
                                            <?php endif; ?>
                                            <ul class="xb-item--skill">
                                                <li><?php echo esc_html($list['skill1']); ?></li>
                                                <li><?php echo esc_html($list['skill2']); ?></li>
                                            </ul>
                                        </div>
                                    </div>
                                </div>
                            <?php endforeach; ?>
                        </div>
                        <?php if ($pagination_active): ?>
                            <div class="swiper-pagination"></div>
                        <?php endif; ?>
                    </div>
                </div>
            </div>
        </div>
        <?php
    }


}


Plugin::instance()->widgets_manager->register(new Auxa_Team_V3());