<?php

/**
 * Elementor Single Widget
 * @package auxa-core
 * @since 1.0.0
 */

namespace Elementor;

if (!defined('ABSPATH')) exit; // Exit if accessed directly.

class Auxa_Team_V5 extends Widget_Base
{

    /**
     * Get widget name.
     *
     * Retrieve Elementor widget name.
     *
     * @return string Widget name.
     * @since 1.0.0
     * @access public
     *
     */
    public function get_name()
    {
        return 'int-team-v5';
    }

    /**
     * Get widget title.
     *
     * Retrieve Elementor widget title.
     *
     * @return string Widget title.
     * @since 1.0.0
     * @access public
     *
     */
    public function get_title()
    {
        return esc_html__('Team V5', 'auxa-core');
    }

    /**
     * Get widget icon.
     *
     * Retrieve Elementor widget icon.
     *
     * @return string Widget icon.
     * @since 1.0.0
     * @access public
     *
     */
    public function get_icon()
    {
        return 'auxa-custom-icon';
    }

    /**
     * Get widget categories.
     *
     * Retrieve the list of categories the Elementor widget belongs to.
     *
     * @return array Widget categories.
     * @since 1.0.0
     * @access public
     *
     */
    public function get_categories()
    {
        return ['auxa_widgets'];
    }


    protected function register_controls()
    {

        $this->start_controls_section(
            'content_option',
            [
                'label' => esc_html__('Content', 'auxa-core'),
                'tab' => Controls_Manager::TAB_CONTENT,
            ]
        );
        $repeater = new \Elementor\Repeater();

        $repeater->add_control(
            'template',
            [
                'type' => Controls_Manager::SELECT2,
                'options' => $this->template_select(),
                'multiple' => false,
                'label' => esc_html__('Team', 'auxa-core'),
                'label_block' => true,
            ]
        );

        $this->add_control(
            'lists',
            [
                'type' => Controls_Manager::REPEATER,
                'fields' => $repeater->get_controls(),
                'prevent_empty' => false,
            ]
        );

        $this->end_controls_section();


        $this->start_controls_section(
            'color_option',
            [
                'label' => esc_html__('Style', 'auxa-core'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );
        $this->add_group_control(
            Group_Control_Background::get_type(),
            [
                'name' => 'overlay_color',
                'types' => ['gradient'],
                'exclude' => ['image'],
                'selector' => '{{WRAPPER}} .xb-team .xb-item--img::before',
                'fields_options' => [
                    'background' => [
                        'label' => esc_html__('Overlay Color', 'xpress-core'),
                    ]
                ]
            ]
        );
        $this->start_controls_tabs(
            'style_tabs'
        );

        $this->start_controls_tab(
            'style_normal_tab',
            [
                'label' => esc_html__( 'Normal', 'auxa-core' ),
            ]
        );
        $this->add_control(
            'filter-img',
            [
                'label' => esc_html__('Filter Image', 'auxa-core'),
                'type' => \Elementor\Controls_Manager::SLIDER,
                'size_units' => ['%'],
                'range' => [
                    '%' => [
                        'min' => 0,
                        'max' => 100,
                    ],
                ],
                'default' => [
                    'unit' => '%',
                    'size' => 100,
                ],
                'selectors' => [
                    '{{WRAPPER}} .xb-team .xb-item--img img' => 'filter: grayscale({{SIZE}}{{UNIT}});',
                ],
            ]
        );
        $this->add_control(
            'title-c',
            [
                'label' => esc_html__('Title Color', 'auxa-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .xb-team .xb-item--title' => 'color: {{VALUE}}',
                ],
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'title_typography',
                'selector' => '{{WRAPPER}} .xb-team .xb-item--title',
            ]
        );
        $this->add_control(
            'desig_hr',
            [
                'type' => \Elementor\Controls_Manager::DIVIDER,
            ]
        );
        $this->add_control(
            'desig-c',
            [
                'label' => esc_html__('Designation Color', 'auxa-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .xb-team .xb-item--desig' => 'color: {{VALUE}}',
                ],
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'desig_typography',
                'selector' => '{{WRAPPER}} .xb-team .xb-item--desig',
            ]
        );

        $this->end_controls_tab();

        $this->start_controls_tab(
            'style_hover_tab',
            [
                'label' => esc_html__( 'Hover', 'auxa-core' ),
            ]
        );
        $this->add_control(
            'hfilter-img',
            [
                'label' => esc_html__('Filter Image', 'auxa-core'),
                'type' => \Elementor\Controls_Manager::SLIDER,
                'size_units' => ['%'],
                'range' => [
                    '%' => [
                        'min' => 0,
                        'max' => 100,
                    ],
                ],
                'default' => [
                    'unit' => '%',
                    'size' => 0,
                ],
                'selectors' => [
                    '{{WRAPPER}} .xb-team:hover .xb-item--img img' => 'filter: grayscale({{SIZE}}{{UNIT}});',
                ],
            ]
        );
        $this->add_control(
            'h_title_hr',
            [
                'type' => \Elementor\Controls_Manager::DIVIDER,
            ]
        );
        $this->add_control(
            'htitle-c',
            [
                'label' => esc_html__('Title Color', 'auxa-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .xb-team:hover .xb-item--title' => 'color: {{VALUE}}',
                ],
            ]
        );
        $this->add_control(
            'hdesig_hr',
            [
                'type' => \Elementor\Controls_Manager::DIVIDER,
            ]
        );
        $this->add_control(
            'hdesig-c',
            [
                'label' => esc_html__('Designation Color', 'auxa-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .xb-team:hover .xb-item--desig' => 'color: {{VALUE}}',
                ],
            ]
        );

        $this->add_control(
            'social_hr',
            [
                'label' => esc_html__('Social Style', 'auxa-core'),
                'type' => \Elementor\Controls_Manager::HEADING,
                'separator' => 'before',
            ]
        );
        $this->add_control(
            'social-c',
            [
                'label' => esc_html__('Social Icon Color', 'auxa-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .xb-team .xb-item--icon li a' => 'color: {{VALUE}}',
                    '{{WRAPPER}} .xb-team .xb-item--icon li a svg path' => 'fill: {{VALUE}}',
                ],
            ]
        );
        $this->add_control(
            'social-bg-c',
            [
                'label' => esc_html__('Social BG Color', 'auxa-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .xb-team .xb-item--icon li a' => 'background-color: {{VALUE}}',
                ],
            ]
        );

        $this->end_controls_tab();

        $this->end_controls_tabs();
        $this->end_controls_section();

    }


    protected function render()
    {
        $settings = $this->get_settings_for_display();

        // Check if 'lists' is not empty
        if (!empty($settings['lists'])) {
            echo '<div class="team-inner">';
                echo '<div class="row mt-none-30">';

            foreach ($settings['lists'] as $a) {
                // Check if 'template' key is set in the array and is not empty
                if (isset($a['template']) && !empty($a['template'])) {
                    $team_post = get_post($a['template']);

                    // Check if $team_post is not empty and is a valid post object
                    if ($team_post instanceof \WP_Post) {
                        $team_name = esc_html($team_post->post_title);
                        $team_permalink = esc_url(get_permalink($team_post));

                        // Use $team_post->ID instead of get_the_ID()
                        $idd = $team_post->ID;

                        if (get_post_meta($idd, 'auxa_team_meta', true)) {
                            $team_meta = get_post_meta($idd, 'auxa_team_meta', true);
                        } else {
                            $team_meta = array();
                        }
                        if (array_key_exists('designation', $team_meta)) {
                            $designation = $team_meta['designation'];
                        } else {
                            $designation = '';
                        }
                        if (array_key_exists('team-social', $team_meta)) {
                            $team_social = $team_meta['team-social'];
                        } else {
                            $team_social = '';
                        }
                        $featured_image_url = get_the_post_thumbnail_url($team_post, 'auxa-team');
                        ?>
                        <div class="col-lg-3 col-md-6 mt-30">
                            <div class="xb-team pos-rel">
                                <div class="xb-item--img">
                                    <img src="<?php echo esc_url($featured_image_url); ?>" alt="">
                                </div>
                                <div class="xb-item--holder text-center">
                                    <h3 class="xb-item--title"><a href="<?php echo $team_permalink; ?>"><?php echo $team_name; ?></a></h3>
                                    <p class="xb-item--desig"><?php echo esc_html($designation); ?></p>
                                    <ul class="xb-item--icon ul_li_center">
                                        <?php if(!empty($team_social['facebook'])): ?>
                                        <li><a href="<?php echo esc_url($team_social['facebook']); ?>"><i class="fab fa-facebook-f"></i></a></li>
                                        <?php endif;
                                        if(!empty($team_social['twitter'])): ?>
                                            <li><a href="<?php echo esc_url($team_social['twitter']); ?>"><svg width="16" height="16" viewBox="0 0 16 16" fill="none" xmlns="http://www.w3.org/2000/svg"><g><path d="M9.4893 6.77491L15.3176 0H13.9365L8.87577 5.88256L4.8338 0H0.171875L6.28412 8.89547L0.171875 16H1.55307L6.8973 9.78782L11.1659 16H15.8278L9.48896 6.77491H9.4893ZM7.59756 8.97384L6.97826 8.08805L2.05073 1.03974H4.17217L8.14874 6.72795L8.76804 7.61374L13.9371 15.0075H11.8157L7.59756 8.97418V8.97384Z" fill="black"></path></g><defs><clipPath><rect width="16" height="16" fill="white"></rect></clipPath></defs></svg></a></li>
                                        <?php endif;
                                        if(!empty($team_social['linkedin'])): ?>
                                        <li><a href="<?php echo esc_url($team_social['linkedin']); ?>"><i class="fab fa-linkedin-in"></i></a></li>
                                        <?php endif;
                                        if(!empty($team_social['instagram'])): ?>
                                        <li><a href="<?php echo esc_url($team_social['instagram']); ?>"><i class="fab fa-instagram"></i></a></li>
                                        <?php endif; ?>
                                    </ul>
                                </div>
                            </div>
                        </div>
                        <?php
                    }
                }
            }
            echo '</div>';
            echo '</div>';
        }
    }


    protected function template_select()
    {
        $type = 'auxa_team';
        global $post;
        $args = array('numberposts' => -1, 'post_type' => $type,);
        $posts = get_posts($args);
        $categories = array(
            '' => __('Select', 'auxa-core'),
        );
        foreach ($posts as $pn_cat) {
            $categories[$pn_cat->ID] = get_the_title($pn_cat->ID);
        }
        return $categories;
    }

    protected function render_template($id)
    {
        return Plugin::instance()->frontend->get_builder_content_for_display($id);
    }

}


Plugin::instance()->widgets_manager->register(new Auxa_Team_V5());