<?php

/**
 * Elementor Single Widget
 * @package auxa-core
 * @since 1.0.0
 */

namespace Elementor;

if (!defined('ABSPATH')) exit; // Exit if accessed directly.

class Auxa_Testimonial_V2 extends Widget_Base
{

    /**
     * Get widget name.
     *
     * Retrieve Elementor widget name.
     *
     * @return string Widget name.
     * @since 1.0.0
     * @access public
     *
     */
    public function get_name()
    {
        return 'int-testimonial-v2';
    }

    /**
     * Get widget title.
     *
     * Retrieve Elementor widget title.
     *
     * @return string Widget title.
     * @since 1.0.0
     * @access public
     *
     */
    public function get_title()
    {
        return esc_html__('Testimonial V2', 'auxa-core');
    }

    /**
     * Get widget icon.
     *
     * Retrieve Elementor widget icon.
     *
     * @return string Widget icon.
     * @since 1.0.0
     * @access public
     *
     */
    public function get_icon()
    {
        return 'auxa-custom-icon';
    }

    /**
     * Get widget categories.
     *
     * Retrieve the list of categories the Elementor widget belongs to.
     *
     * @return array Widget categories.
     * @since 1.0.0
     * @access public
     *
     */
    public function get_categories()
    {
        return ['auxa_widgets'];
    }


    protected function register_controls()
    {

        $this->start_controls_section(
            'content_option',
            [
                'label' => esc_html__('Content', 'auxa-core'),
                'tab' => Controls_Manager::TAB_CONTENT,
            ]
        );
        $this->add_control(
            'quote',
            [
                'label' => esc_html__('Quote', 'auxa-core'),
                'type' => \Elementor\Controls_Manager::MEDIA,
            ]
        );
        $this->add_control(
            'title',
            [
                'type' => Controls_Manager::TEXT,
                'label' => esc_html__('Title', 'auxa-core'),
                'label_block' => true,
            ]
        );
        $repeater = new \Elementor\Repeater();

        $repeater->add_control(
            'avatar',
            [
                'label' => esc_html__('Avatar', 'auxa-core'),
                'type' => \Elementor\Controls_Manager::MEDIA,
            ]
        );
        $repeater->add_control(
            'name',
            [
                'type' => Controls_Manager::TEXT,
                'label' => esc_html__('Name', 'auxa-core'),
                'label_block' => true,
            ]
        );
        $repeater->add_control(
            'desig',
            [
                'type' => Controls_Manager::TEXT,
                'label' => esc_html__('Designation', 'auxa-core'),
                'label_block' => true,
            ]
        );
        $repeater->add_control(
            'title',
            [
                'type' => Controls_Manager::TEXT,
                'label' => esc_html__('Title', 'auxa-core'),
                'label_block' => true,
            ]
        );
        $repeater->add_control(
            'content',
            [
                'type' => Controls_Manager::TEXTAREA,
                'label' => esc_html__('Content', 'auxa-core'),
                'label_block' => true,
            ]
        );
        $this->add_control(
            'lists',
            [
                'type' => Controls_Manager::REPEATER,
                'fields' => $repeater->get_controls(),
                'title_field' => '{{{ name }}}',
            ]
        );
        $this->end_controls_section();


        $this->start_controls_section(
            'color_option',
            [
                'label' => esc_html__('Style', 'auxa-core'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );
        $this->add_control(
            'quote_border_c',
            [
                'label' => esc_html__('Quote Border Color', 'auxa-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .testimonial-quote' => 'border-color: {{VALUE}}',
                ],
            ]
        );
        $this->add_control(
            'title_hr',
            [
                'type' => \Elementor\Controls_Manager::DIVIDER,
            ]
        );
        $this->add_control(
            'title-c',
            [
                'label' => esc_html__('Title Color', 'auxa-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .section-title .title' => 'color: {{VALUE}}',
                ],
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'title_typography',
                'selector' => '{{WRAPPER}} .section-title .title',
            ]
        );
        $this->add_control(
            'testimonial_style',
            [
                'label' => esc_html__('Testimonial Style', 'auxa-core'),
                'type' => \Elementor\Controls_Manager::HEADING,
                'separator' => 'before',
            ]
        );
        $this->add_control(
            'tst_title-c',
            [
                'label' => esc_html__('Title Color', 'auxa-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .xb-testimonial .xb-item--title' => 'color: {{VALUE}}',
                ],
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'sst_title_typography',
                'selector' => '{{WRAPPER}} .xb-testimonial .xb-item--title',
            ]
        );
        $this->add_control(
            'content_hr',
            [
                'type' => \Elementor\Controls_Manager::DIVIDER,
            ]
        );
        $this->add_control(
            'content-c',
            [
                'label' => esc_html__('Content Color', 'auxa-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .xb-testimonial .xb-item--content' => 'color: {{VALUE}}',
                ],
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'content_typography',
                'selector' => '{{WRAPPER}} .xb-testimonial .xb-item--content',
            ]
        );
        $this->add_control(
            'avatar_hr',
            [
                'type' => \Elementor\Controls_Manager::DIVIDER,
            ]
        );
        $this->add_control(
            'filter-img',
            [
                'label' => esc_html__('Avatar Filter Image', 'auxa-core'),
                'type' => \Elementor\Controls_Manager::SLIDER,
                'size_units' => ['%'],
                'range' => [
                    '%' => [
                        'min' => 0,
                        'max' => 100,
                    ],
                ],
                'default' => [
                    'unit' => '%',
                    'size' => 100,
                ],
                'selectors' => [
                    '{{WRAPPER}} .xb-testimonial .xb-item--avatar img' => 'filter: grayscale({{SIZE}}{{UNIT}});',
                ],
            ]
        );
        $this->add_control(
            'avatar_border_c',
            [
                'label' => esc_html__('Avatar Border Color', 'auxa-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .xb-testimonial .xb-item--avatar' => 'border-color: {{VALUE}}',
                ],
            ]
        );
        $this->add_control(
            'name_hr',
            [
                'type' => \Elementor\Controls_Manager::DIVIDER,
            ]
        );
        $this->add_control(
            'name-c',
            [
                'label' => esc_html__('Name Color', 'auxa-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .xb-testimonial .xb-item--name' => 'color: {{VALUE}}',
                ],
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'name_typography',
                'selector' => '{{WRAPPER}} .xb-testimonial .xb-item--name',
            ]
        );
        $this->add_control(
            'desig_hr',
            [
                'type' => \Elementor\Controls_Manager::DIVIDER,
            ]
        );
        $this->add_control(
            'desig-c',
            [
                'label' => esc_html__('Designation Color', 'auxa-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .xb-testimonial .xb-item--desig' => 'color: {{VALUE}}',
                ],
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'desig_typography',
                'selector' => '{{WRAPPER}} .xb-testimonial .xb-item--desig',
            ]
        );
        $this->add_control(
            'nav_style',
            [
                'label' => esc_html__('Nav Style', 'auxa-core'),
                'type' => \Elementor\Controls_Manager::HEADING,
                'separator' => 'before',
            ]
        );
        $this->start_controls_tabs(
            'style_tabs'
        );

        $this->start_controls_tab(
            'style_normal_tab',
            [
                'label' => esc_html__('Normal', 'auxa-core'),
            ]
        );

        $this->add_control(
            'nav-bg-c',
            [
                'label' => esc_html__('Background Color', 'auxa-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .testimonial-carousel .xb-swiper-arrow' => 'background-color: {{VALUE}}',
                ],
            ]
        );

        $this->end_controls_tab();

        $this->start_controls_tab(
            'style_hover_tab',
            [
                'label' => esc_html__('Hover', 'auxa-core'),
            ]
        );

        $this->add_control(
            'h-nav-bg-c',
            [
                'label' => esc_html__('Background Color', 'auxa-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .testimonial-carousel .xb-swiper-arrow:hover' => 'background-color: {{VALUE}}',
                ],
            ]
        );

        $this->end_controls_tab();

        $this->end_controls_tabs();
        $this->end_controls_section();

    }

    protected function render()
    {
        $settings = $this->get_settings_for_display();
        $arrow_left = AUXA_DIR_URL . 'assets/img/arrow-left.svg';
        $arrow_right = AUXA_DIR_URL . 'assets/img/arrow-right.svg';
        ?>
        <div class="row mt-none-40">
            <?php
            if (!empty($settings['quote']['id'])):
                ?>
                <div class="col-lg-4 mt-40">
                    <div class="testimonial-quote">
                        <?php echo wp_get_attachment_image($settings['quote']['id'], 'medium'); ?>
                    </div>
                </div>
            <?php endif; ?>
            <div class="col-lg-8 mt-40">
                <div class="testimonial-inner">
                    <?php
                    if (!empty($settings['title'])):
                        ?>
                        <div class="section-title mb-55">
                            <h3 class="title wow skewIn"><?php echo wp_kses($settings['title'], true); ?></h3>
                        </div>
                    <?php endif; ?>
                    <div class="testimonial-slider pos-rel">
                        <div class="swiper-wrapper">
                            <?php
                            foreach ($settings['lists'] as $list):
                                ?>
                                <div class="swiper-slide xb-testimonial">
                                    <div class="xb-item--holder">
                                        <?php
                                        if (!empty($list['title'])):
                                            ?>
                                            <h3 class="xb-item--title"><?php echo esc_html($list['title']); ?></h3>
                                        <?php endif; ?>
                                        <?php
                                        if (!empty($list['content'])):
                                            ?>
                                            <p class="xb-item--content"><?php echo wp_kses($list['content'], true); ?></p>
                                        <?php endif; ?>
                                    </div>
                                    <div class="xb-item--author">
                                        <?php
                                        if (!empty($list['avatar']['id'])):
                                            ?>
                                            <div class="xb-item--avatar">
                                                <?php echo wp_get_attachment_image($list['avatar']['id'], 'thumbnail'); ?>
                                            </div>
                                        <?php
                                        endif;
                                        if (!empty($list['name'])):
                                            ?>
                                            <h3 class="xb-item--name"><?php echo esc_html($list['name']); ?></h3>
                                        <?php endif;
                                        if (!empty($list['desig'])):
                                            ?>
                                            <span class="xb-item--desig"><?php echo esc_html($list['desig']); ?></span>
                                        <?php endif; ?>
                                    </div>
                                </div>
                            <?php endforeach; ?>
                        </div>
                        <div class="testimonial-carousel ul_li">
                            <div class="xb-swiper-arrow xb-swiper-arrow-prev"><img
                                        src="<?php echo esc_url($arrow_left); ?>"
                                        alt=""></div>
                            <div class="xb-swiper-arrow xb-swiper-arrow-next"><img
                                        src="<?php echo esc_url($arrow_right); ?>"
                                        alt=""></div>
                        </div>
                    </div>
                </div>
            </div>
        </div>
        <?php
    }

}


Plugin::instance()->widgets_manager->register(new Auxa_Testimonial_V2());